<?php

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 *
 * @package    ConsentMagic
 * @subpackage ConsentMagic/includes
 */

namespace ConsentMagicPro;

class ConsentMagic {

	/**
	 * $_instance
	 */
	private static $_instance = null;

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 */
	public $plugin_name;

	/**
	 * The current version of the plugin.
	 */
	protected $version;

	/**
	 * Options values
	 *
	 * @var array
	 */
	private $values = array();

	/**
	 * Options values
	 *
	 * @var array
	 */
	private $values_design = array();

	/**
	 * Database option key
	 *
	 * @var string
	 */
	private $option_key = '';

	/**
	 * Database option key
	 *
	 * @var string
	 */
	private $option_key_design = '';

	private $defaults_json_path;

	private $defaults_json_path_design;

	/**
	 * List of all options
	 *
	 * @var array
	 */
	private $options = array();

	/**
	 * List of all options
	 *
	 * @var array
	 */
	private $options_design = array();

	/**
	 * Default options values
	 *
	 * @var array
	 */
	private $defaults = array();

	/**
	 * Default options values
	 *
	 * @var array
	 */
	private $defaults_design = array();

	private $translations_path = '';

	public $cs_options = array();

	public $status = array();

	private $ad_storage = false;

	private $analytics_storage = false;

	private $ad_user_data = false;

	private $ad_personalization = false;

	public $cs_track_analytics = 0;

	private $active_rule_id;

	public static $unblocked_user_ip = array();

	public static $check_unblocked_crawlers;

	public static $check_disable_cm = false;

	private $current_lang;

	private $current_general_lang;

	public $containers_names;

	public static $run = null;

	/**
	 * $_instance ConsentMagic
	 *
	 * @return ConsentMagic|null
	 *
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Define the core functionality of the plugin.
	 */
	public function __construct() {

		if ( defined( 'CMPRO_LATEST_VERSION_NUMBER' ) ) {
			$this->version = CMPRO_LATEST_VERSION_NUMBER;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'consent-magic';
		$this->option_key = 'cs' . $this->plugin_name;
		$this->option_key_design = CMPRO_SETTINGS_DESIGN_FIELD;

		$this->load_dependencies();

		$this->containers_names = array(
			'cs_cookie_bar_container' => generate_name(),
		);

		if ( is_plugin_activated() ) {

			if ( is_multisite() && !defined( 'COOKIEHASH' ) ) {
				wp_cookie_constants();
			}

			$this->current_lang = get_locale();
			$this->current_general_lang = get_general_language( $this->current_lang );

			$cs_check_tables = get_option( 'cs_check_unblock_ip_tables' );
			if ( !$cs_check_tables ) {
				$this->check_tables();
			}

			$this->get_unblocked_user_ip();
			$this->check_unblocked_crawlers();
			$this->set_active_rule_id();
			$this->define_plugin_options();
		}

		$this->set_locale();
		$this->define_admin_hooks();
	}

	public function define_plugin_options() {
		$this->cs_options[ 'active_rule_id' ] = $this->get_active_rule_id();
		$this->cs_options[ 'cs_test_mode' ] = $this->getOption( 'cs_test_mode' );
		$this->cs_options[ 'test_prefix' ] = '';
		$this->cs_options[ 'cs_track_analytics' ] = 0;
		$this->cs_options[ 'analytics_cat_id' ] = get_option( 'analytics_cat_id' );
		$this->cs_options[ 'cs_type' ] = get_post_meta( $this->cs_options[ 'active_rule_id' ], '_cs_type', true );
		$this->cs_options[ 'cs_plugin_activation' ] = $this->getOption( 'cs_plugin_activation' );
		$this->cs_options[ 'allowed_roles' ] = get_option( 'cs_admin_permissions' );
		$this->cs_options[ 'cs_block_pre_defined_scripts' ] = $this->getOption( 'cs_block_pre_defined_scripts' );
		$this->cs_options[ 'cs_script_blocking_enabled' ] = $this->getOption( 'cs_script_blocking_enabled' );

		if ( $this->cs_options[ 'cs_test_mode' ] ) {
			$this->cs_options[ 'test_prefix' ] = '_test';
		}

		$this->cs_options[ 'viewed_cookie' ] = "cs_viewed_cookie_policy" . $this->cs_options[ 'test_prefix' ];

		if ( $this->cs_options[ 'cs_block_pre_defined_scripts' ] == 1 && !isset( $_COOKIE[ $this->cs_options[ 'viewed_cookie' ] ] ) ) {
			$this->cs_options[ 'cs_track_analytics' ] = get_post_meta( $this->cs_options[ 'active_rule_id' ], '_cs_track_analytics', true );
		}
		$this->cs_track_analytics = $this->cs_options[ 'cs_track_analytics' ];

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - CS_Loader. Orchestrates the hooks of the plugin.
	 * - CS_i18n. Defines internationalization functionality.
	 * - CS_Admin. Defines all hooks for the admin area.
	 * - CS_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/CS_Loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/CS_i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/CS_Admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/CS_Public.php';

		/**
		 * The class responsible for defining all actions that occur in the integrations
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/modules/geoip2/CS_Geoip2_Module.php';

		$this->loader = new CS_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the CS_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 */
	private function set_locale() {

		$plugin_i18n = new CS_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 */
	private function define_admin_hooks() {

		$plugin_admin = new CS_Admin( $this->get_plugin_name(), $this->get_version(), $this );

		/**
		 * loading admin modules
		 */
		$this->loader->add_action( 'init', $this, 'manageAdminPermissions' );
		$this->loader->add_action( 'init', $plugin_admin, 'create_taxonomy', 1 );
		$this->loader->add_action( 'init', $plugin_admin, 'register_custom_post_type', 1 );

		$this->loader->add_action( 'init', $plugin_admin, 'cs_insert_templates_lists', 1 );
		$this->loader->add_action( 'init', $plugin_admin, 'cs_insert_cookie_lists', 1 );

		if ( (int) $this->getOption( 'cs_free' ) === 1 && is_plugin_activated() ) {
			$this->loader->add_action( 'init', $plugin_admin, 'cs_migrate_to_pro', 1 );
		}

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'admin_menu', 11 ); /* Adding admin menu */

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );


		if ( is_plugin_activated() ) {

			//if bot - script not working
			if ( !self::$check_unblocked_crawlers ) {
				if ( !is_active_supreme_modules_pro_for_divi() ) {
					$priority = 11;
				} else {
					$priority = 30;
				}
				$plugin_public = new CS_Public( $this->getOption( 'cs_enable_site_cache' ) );
				$this->loader->add_action( 'init', $plugin_public, 'public_init' );
				$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
				$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts', $priority );
				$this->loader->add_action( 'admin_notices', $plugin_admin, 'cs_admin_messages' );
				$this->loader->add_action( 'admin_init', $plugin_admin, 'cs_close_messages' );
				$this->loader->add_action( 'init', $this, 'check_policy_page', 1 );

				if ( $this->getOption( 'cs_google_consent_mode' ) ) {
					$this->loader->add_action( 'init', $this, 'add_google_consent_mode', 2 );
				}

				if ( self::$unblocked_user_ip !== false ) {
					self::$check_disable_cm = $plugin_public->cs_check_disable_cm( self::$unblocked_user_ip );
				} else {
					self::$check_disable_cm = $plugin_public->cs_check_disable_cm( array() );
				}
			}
		}

		// initialize options
		$this->locateOptions( CMPRO_PLUGIN_PATH . '/includes/options_fields.json', CMPRO_PLUGIN_PATH . '/includes/options_defaults.json' );
		// initialize options
		$this->locateOptionsDesign( CMPRO_PLUGIN_PATH . '/includes/design_options_fields.json', CMPRO_PLUGIN_PATH . '/includes/design_options_default.json' );

		$this->translations_path = CMPRO_PLUGIN_PATH . '/includes/translations.json';

		$this->cs_check_settings( $plugin_admin );
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 */
	public function get_plugin_name() {

		return $this->plugin_name;
	}

	/**
	 * Retrieve the version number of the plugin.
	 */
	public function get_version() {

		return $this->version;
	}

	/**
	 * Get ad_storage mode option
	 *
	 * @return int
	 */
	public function get_ad_storage_option() {
		return $this->ad_storage;
	}

	/**
	 * Get analytics_storage mode option
	 *
	 * @return int
	 */
	public function get_analytics_storage_option() {
		return $this->analytics_storage;
	}

	/**
	 * Get ad_user_data mode option
	 *
	 * @return int
	 */
	public function get_ad_user_data_option() {
		return $this->ad_user_data;
	}

	/**
	 * Get ad_personalization mode option
	 *
	 * @return int
	 */
	public function get_ad_personalization_option() {
		return $this->ad_personalization;
	}

	/**
	 * Set active rule ID
	 *
	 * @return void
	 */
	private function set_active_rule_id() {

		if ( empty( $this->active_rule_id ) ) {
			if ( ( (int) $this->getOption( 'cs_geolocation' ) === 0 || (int) $this->getOption( 'cs_geo_activated' ) === 0 ) ) {
				$args_posts = array(
					'post_type'      => CMPRO_POST_TYPE,
					'post_status'    => 'publish',
					'meta_query'     => [
						[
							'key'   => '_cs_enable_rule',
							'value' => 1,
						]
					],
					'posts_per_page' => 1,
					'order'          => 'ASC',
					'meta_key'       => '_cs_order',
					'orderby'        => 'meta_value_num',
					'meta_type'      => 'NUMERIC',
				);
			} else {

				$cs_geo = new CS_Geoip();
				$user_country = $cs_geo->cs_check_country();
				$user_city = $cs_geo->cs_check_city();

				if ( $user_city == 'California' ) {
					$user_country = 'CCPA';
				}

				if ( empty( $user_country ) ) {
					$args_posts = array(
						'post_type'      => CMPRO_POST_TYPE,
						'post_status'    => 'publish',
						'meta_query'     => array(
							'relation' => 'AND',
							array(
								'key'   => '_cs_no_ip_rule',
								'value' => 1,
							),
							array(
								'key'   => '_cs_enable_rule',
								'value' => 1,
							)
						),
						'posts_per_page' => 1,
						'order'          => 'ASC',
						'meta_key'       => '_cs_order',
						'orderby'        => 'meta_value_num',
						'meta_type'      => 'NUMERIC',
					);
					$the_post = get_posts( $args_posts );
					if ( empty( $the_post ) ) {
						$args_posts = array(
							'post_type'      => CMPRO_POST_TYPE,
							'post_status'    => 'publish',
							'meta_query'     => array(
								array(
									'key'   => '_cs_enable_rule',
									'value' => 1,
								)
							),
							'posts_per_page' => 1,
							'order'          => 'ASC',
							'meta_key'       => '_cs_order',
							'orderby'        => 'meta_value_num',
							'meta_type'      => 'NUMERIC',
						);
					}
				} else {
					$args_posts = array(
						'post_type'      => CMPRO_POST_TYPE,
						'post_status'    => 'publish',
						'meta_query'     => array(
							'relation' => 'AND',
							array(
								'key'     => '_cs_target',
								'value'   => $user_country,
								'compare' => 'LIKE'
							),
							array(
								'key'   => '_cs_enable_rule',
								'value' => 1,
							)
						),
						'posts_per_page' => 1,
						'order'          => 'ASC',
						'meta_key'       => '_cs_order',
						'orderby'        => 'meta_value_num',
						'meta_type'      => 'NUMERIC',
					);
				}
			}

			$rule = get_posts( $args_posts );

			if ( !empty( $rule ) ) {
				$post_id = $rule[ 0 ]->ID;
			} else {
				$post_id = '';
			}

			update_option( 'cs_active_rule_id', $post_id );

			$this->active_rule_id = $post_id;
		}
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 */
	public function run() {
		$this->loader->run();
		if ( $this->getOption( 'cs_store_consent_for_wc_orders' ) ) {
			add_action( 'add_meta_boxes', array(
				$this,
				'woo_add_order_meta_boxes'
			) );

			add_action( 'edd_view_order_details_main_after', array(
				$this,
				'add_edd_order_details'
			) );
		}
		add_action( 'woocommerce_email_customer_details', array(
			$this,
			'cs_send_admin_order_consent'
		), 80, 4 );
	}

	/**
	 * checking necessary tables are installed
	 */
	public function check_tables() {
		global $wpdb;
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		//creating unlock users ip list table ========================
		$table_name_ip = $wpdb->prefix . 'cs_unblock_ip';
		$like = '%' . $wpdb->esc_like( $table_name_ip ) . '%';
		$search_query = $wpdb->prepare( "SHOW TABLES LIKE %s", $like );
		if ( !$wpdb->get_results( $search_query, ARRAY_N ) ) {
			$create_table_sql = "CREATE TABLE `$table_name_ip`(
			    `id` INT NOT NULL AUTO_INCREMENT,
			    `ip` VARCHAR(250) NOT NULL,
			    `created_at` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
			    PRIMARY KEY(`id`)
			);";
			dbDelta( $create_table_sql );
		}
		add_option( 'cs_check_unblock_ip_tables', true );

		return true;
	}

	public function cs_send_admin_order_consent( $order, $sent_to_admin, $plain_text, $email ) {

		if ( in_array( $email->id, [ 'customer_processing_order' ] ) ) {
			if ( $this->getOption( "cs_customer_email_consent_for_wc_orders" ) ) {
				$orderId = $order->get_id();
				echo "<h2 style='text-align: center'>" . esc_html( $this->getOption( "cs_admin_email_privacy_title" ) ) . "</h2>";
				include_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/order/html-order-meta-box.php';
			}
		}
		if ( $sent_to_admin ) {
			if ( $this->getOption( "cs_admin_email_consent_for_wc_orders" ) ) {
				$orderId = $order->get_id();
				echo "<h2 style='text-align: center'>" . esc_html__( 'ConsentMagic', 'consent-magic' ) . "</h2>";
				echo sprintf( esc_html__( 'We only send the consent related data in the New Order email that you get. You can remove it by opening the ConsentMagic plugin\'s %s settings page %s', 'consent-magic' ), "<a href='" . esc_url( admin_url( "admin.php?page=cs-settings" ) ) . "' target='_blank'>", '</a>' );
				echo '<br>';
				echo sprintf( esc_html__( 'You can also send this privacy info to your clients. It can increase their confidence in your brand and build trust. Turin it on from the ConsentMagic %s settings page %s', 'consent-magic' ), "<a href='" . esc_url( admin_url( "admin.php?page=cs-settings" ) ) . "' target='_blank'>", '</a>.' );

				include_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/order/html-order-meta-box.php';
			}
		}

		return false;
	}

	public function woo_render_order_fields( $order ) {

		$orderId = ( $order instanceof \WP_Post ) ? $order->ID : $order->get_id();

		include_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/order/html-order-box.php';
	}

	public function woo_add_order_meta_boxes() {

		$screen = isWooUseHPStorage() ? wc_get_page_screen_id( 'shop-order' ) : 'shop_order';

		add_meta_box( 'cs_enrich_fields_woo', esc_html__( 'ConsentMagic', 'consent-magic' ), array(
			$this,
			"woo_render_order_fields"
		), $screen );
	}

	function manageAdminPermissions() {
		global $wp_roles;

		$roles = get_option( 'cs_admin_permissions', array( 'administrator' ) );

		foreach ( $wp_roles->roles as $role => $options ) {

			if ( in_array( $role, $roles ) || $role == 'administrator' ) {
				$wp_roles->add_cap( $role, 'manage_cs' );
			} else {
				$wp_roles->remove_cap( $role, 'manage_cs' );
			}
		}
	}

	function check_policy_page() {
		$privacy_option = get_option( 'cs_policy_existing_page' );
		if ( !$privacy_option || $privacy_option == '' ) {
			$privacy_policy_page = get_option( 'wp_page_for_privacy_policy' );
			if ( $privacy_policy_page ) {
				update_option( 'cs_policy_existing_page', $privacy_policy_page );
			} else {
				update_option( 'cs_policy_existing_page', '1' );
			}
		}
	}

	public function getCSOptions() {

		if ( !file_exists( $this->defaults_json_path ) ) {
			return;
		}

		$content = file_get_contents( $this->defaults_json_path );
		$values = json_decode( $content, true );
		return $values;
	}

	/**
	 * Gets an option value or its default value
	 *
	 * @param string $key Option key
	 * @param mixed $fallback Option fallback value if no default is set
	 *
	 * @return mixed The value specified for the option or a default value for the option.
	 */
	public function getOptionBack( $key, $fallback = null ) {

		$this->maybeLoad();

		// get option default if unset
		if ( !isset( $this->values[ $key ] ) ) {
			$this->values[ $key ] = isset( $this->defaults[ $key ] ) ? $this->defaults[ $key ] : null;
		}

		// use fall back value if default is not set
		if ( null === $this->values[ $key ] && !is_null( $fallback ) ) {
			$this->values[ $key ] = $fallback;
		}

		if ( isset( $this->values[ $key ] ) ) {
			return $this->values[ $key ];
		} else {

			$this->maybeLoadDesign();

			// get option default if unset
			if ( !isset( $this->values_design[ $key ] ) ) {
				$this->values_design[ $key ] = isset( $this->defaults_design[ $key ] ) ? $this->defaults_design[ $key ] : null;
			}

			// use fall back value if default is not set
			if ( null === $this->values_design[ $key ] && !is_null( $fallback ) ) {
				$this->values_design[ $key ] = $fallback;
			}

			return $this->values_design[ $key ];
		}
	}

	public function getOption( $key ) {

		$data = $this->getOptionBack( $key );

		if ( !is_array( $data ) && empty( $data ) && stripos( $key, '_' . CMPRO_DEFAULT_LANGUAGE ) !== false ) {
			$data = $this->renderDefaultText( $key );
		}

		return $data;
	}

	public function getLangOption( $key, $lang, $meta = false ) {

		if ( $meta ) {
			$data = get_post_meta( $this->get_active_rule_id(), $key . '_' . $lang, true );
			if ( empty( $data ) ) {
				$data = get_post_meta( $this->get_active_rule_id(), $key . '_' . $this->current_general_lang, true );
			}
		} else {
			$data = $this->getOption( $key . '_' . $lang );
			if ( empty( $data ) ) {
				$data = $this->getOption( $key . '_' . $this->current_general_lang );
			}
		}

		return $data;
	}

	public function getLangOptionTerm( $id, $key, $lang ) {

		$data = get_term_meta( $id, $key . '_' . $lang, true );
		if ( empty( $data ) ) {
			$data = get_term_meta( $id, $key . '_' . $this->current_general_lang, true );
		}

		return $data;
	}

	/**
	 * Load values from database
	 *
	 * @param bool $force Force options load
	 */
	private function maybeLoad( $force = false ) {
		if ( $force || empty( $this->values ) ) {
			$options = get_option( $this->option_key, null );
			if ( !is_array( $options ) ) {
				$this->values = json_decode( $options, true );
			} else {
				$this->values = $options;
			}
		}

		// if there are no settings defined, use default values
		if ( !is_array( $this->values ) ) {
			$this->values = $this->defaults;
		}
	}

	/**
	 * Load options fields and options defaults from specified files
	 *
	 * @param string $fields Path to options fields file
	 * @param string $defaults Path to options defaults file
	 */
	public function locateOptions( $fields, $defaults ) {

		$this->loadJSON( $fields, false );
		$this->loadJSON( $defaults, true );

		$this->defaults_json_path = $defaults;
	}

	public function resetToDefaults() {

		if ( !file_exists( $this->defaults_json_path ) ) {
			return;
		}

		$content = file_get_contents( $this->defaults_json_path );
		$values = json_decode( $content, true );

		$this->updateOptions( $values );
	}

	/**
	 * Load options fields or options defaults from specified file
	 *
	 * @param string $file
	 * @param bool $is_defaults
	 */
	private function loadJSON( $file, $is_defaults ) {

		if ( !file_exists( $file ) ) {
			return;
		}

		$content = file_get_contents( $file );
		$values = json_decode( $content, true );

		if ( null === $values ) {
			return;
		}

		if ( $is_defaults ) {
			$this->defaults = $values;
		} else {
			$this->options = $values;
		}
	}

	public function reloadOptions() {
		$this->maybeLoad( true );
	}

	/**
	 * Sanitize and save options
	 *
	 * @param null|array $values Optional. If set, options values will be received from param instead of $_POST.
	 */
	public function updateOptions( $values = null ) {

		$this->maybeLoad();

		if ( is_array( $values ) ) {
			$form_data = $values;
		} else {
			$form_data = ( isset( $_POST[ 'cs' ][ $this->get_plugin_name() ] ) && is_array( $_POST[ 'cs' ][ $this->get_plugin_name() ] ) ) ? $_POST[ 'cs' ][ $this->get_plugin_name() ] : array();
		}

		// save posted fields
		foreach ( $form_data as $key => $value ) {

			if ( isset( $this->options[ $key ] ) ) {
				$this->values[ sanitize_text_field( $key ) ] = $this->sanitize_form_field( $key, $value );
			}
		}

		update_option( $this->option_key, json_encode( $this->values ) );
	}

	public function updateLangOptions( $values, $key_lang ) {
		$this->maybeLoad();

		if ( is_array( $values ) ) {
			$form_data = $values;
		} else {
			return;
		}

		// save posted fields
		foreach ( $form_data as $key => $value ) {
			$isset_key = str_replace( '_' . $key_lang, '', $key );
			if ( isset( $this->options[ $isset_key ] ) ) {
				$this->values[ $isset_key . '_' . $key_lang ] = $this->sanitize_text_field( $value );
			}
		}

		update_option( $this->option_key, json_encode( $this->values ) );
	}

	public function deleteOption( $key_input, $lang = false ) {

		$this->maybeLoad();
		$options_out = array();

		if ( $lang !== false ) {
			foreach ( $this->values as $key_option => $option ) {
				if ( $key_option != $key_input . '_' . $lang ) {
					$options_out[ $key_option ] = $option;
				}
			}

			$langs = $this->values[ $key_input . '_lang' ];
			$langs = array_flip( $langs );
			unset ( $langs[ $lang ] );
			$langs = array_flip( $langs );
			$options_out[ $key_input . '_lang' ] = $langs;

		} else {
			foreach ( $this->values as $key_option => $option ) {
				if ( $key_option != $key_input ) {
					$options_out[ $key_option ] = $option;
				}
			}
		}

		update_option( $this->option_key, $options_out );
		$this->values = $options_out;
	}

	public function getCSOptionsDesign() {

		if ( !file_exists( $this->defaults_json_path_design ) ) {
			return;
		}

		$content = file_get_contents( $this->defaults_json_path_design );
		$values = json_decode( $content, true );
		return $values;
	}

	/**
	 * Load values from database
	 *
	 * @param bool $force Force options load
	 */
	private function maybeLoadDesign( $force = false ) {

		if ( $force || empty( $this->values_design ) ) {
			$this->values_design = get_option( $this->option_key_design, null );
		}

		// if there are no settings defined, use default values
		if ( !is_array( $this->values_design ) ) {
			$this->values_design = $this->defaults_design;
		}
	}

	/**
	 * Load options fields and options defaults from specified files
	 *
	 * @param string $fields Path to options fields file
	 * @param string $defaults Path to options defaults file
	 */
	public function locateOptionsDesign( $fields, $defaults ) {

		$this->loadJSONDesign( $fields, false );
		$this->loadJSONDesign( $defaults, true );

		$this->defaults_json_path_design = $defaults;
	}

	public function resetToDefaultsDesign() {

		if ( !file_exists( $this->defaults_json_path_design ) ) {
			return;
		}

		$content = file_get_contents( $this->defaults_json_path_design );
		$values = json_decode( $content, true );

		$this->updateOptionsDesign( $values );
	}

	/**
	 * Load options fields or options defaults from specified file
	 *
	 * @param string $file
	 * @param bool $is_defaults
	 */
	private function loadJSONDesign( $file, $is_defaults ) {

		if ( !file_exists( $file ) ) {
			return;
		}

		$content = file_get_contents( $file );
		$values = json_decode( $content, true );

		if ( null === $values ) {
			return;
		}

		if ( $is_defaults ) {
			$this->defaults_design = $values;
		} else {
			$this->options_design = $values;
		}
	}

	/**
	 * Sanitize and save options
	 *
	 * @param null|array $values Optional. If set, options values will be received from param instead of $_POST.
	 */
	public function updateOptionsDesign( $values = null ) {

		$this->maybeLoadDesign();

		if ( is_array( $values ) ) {
			$form_data = $values;
		} else {
			$form_data = ( isset( $_POST[ 'cs_d' ][ $this->get_plugin_name() ] ) && is_array( $_POST[ 'cs_d' ][ $this->get_plugin_name() ] ) ) ? $_POST[ 'cs_d' ][ $this->get_plugin_name() ] : array();
		}

		// save posted fields
		foreach ( $form_data as $key => $value ) {

			if ( isset( $this->options_design[ $key ] ) ) {
				$this->values_design[ $this->sanitize_text_field( $key ) ] = $this->sanitize_form_field_design( $key, $value );
			}

		}

		update_option( CMPRO_SETTINGS_DESIGN_FIELD, $this->values_design );
	}

	/**
	 * Sanitize form field
	 *
	 * @param string $key Field key
	 * @param array $value Field value
	 *
	 * @return mixed Sanitized field value
	 */
	private function sanitize_form_field( $key, $value ) {

		$type = $this->options[ $key ];

		// look for very specific sanitization filter
		$filter_name = "{$this->option_key}_settings_sanitize_{$key}_field";

		if ( has_filter( $filter_name ) ) {
			return apply_filters( $filter_name, $value );
		}

		// look for a sanitize_FIELDTYPE_field method
		if ( is_callable( array(
			$this,
			'sanitize_' . $type . '_field'
		) ) ) {
			return $this->{'sanitize_' . $type . '_field'}( $value );
		}

		// fallback to text
		return $this->sanitize_text_field( $value );
	}

	/**
	 * Sanitize form field
	 *
	 * @param string $key Field key
	 * @param array $value Field value
	 *
	 * @return mixed Sanitized field value
	 */
	private function sanitize_form_field_design( $key, $value ) {

		$type = $this->options_design[ $key ];

		// look for very specific sanitization filter
		$filter_name = "{$this->option_key_design}_settings_sanitize_{$key}_field";
		if ( has_filter( $filter_name ) ) {
			return apply_filters( $filter_name, $value );
		}

		// look for a sanitize_FIELDTYPE_field method
		if ( is_callable( array(
			$this,
			'sanitize_' . $type . '_field'
		) ) ) {
			return $this->{'sanitize_' . $type . '_field'}( $value );
		}

		// fallback to text
		return $this->sanitize_text_field( $value );
	}

	/**
	 * Sanitize text field value
	 *
	 * @param $value
	 *
	 * @return string
	 */
	public function sanitize_text_field( $value ) {

		$value = is_null( $value ) ? '' : $value;

		if ( is_array( $value ) ) {
			foreach ( $value as $key => $val ) {
				$value[ $key ] = wp_kses_post( trim( stripslashes( $val ) ) );
			}
			return $value;
		} else {
			return wp_kses_post( trim( stripslashes( $value ) ) );
		}
	}

	/**
	 * Sanitize array field value
	 *
	 * @param $values
	 *
	 * @return array
	 */
	public function sanitize_array_field( $values ) {

		$values = is_array( $values ) ? $values : array();
		$sanitized = array();

		foreach ( $values as $key => $value ) {

			$new_value = $this->sanitize_text_field( $value );

			if ( !empty( $new_value ) && !in_array( $new_value, $sanitized ) ) {
				$sanitized[ $key ] = $new_value;
			}

		}

		return $sanitized;
	}

	/**
	 * Get consent version for renewing consent
	 *
	 * @since    1.0.0
	 * @access   public
	 */
	public function cs_get_consent_version() {
		$current_consent_version = 1;
		$consent_version = get_option( 'wt_cs_consent_version' );
		if ( !empty( $consent_version ) ) {
			$current_consent_version = (int) $consent_version;
		}
		return $current_consent_version;
	}

	/**
	 * Get consent version for renewing consent test
	 *
	 * @since    1.0.0
	 * @access   public
	 */
	public function cs_get_consent_version_test() {
		$current_consent_version = 1;
		$consent_version = get_option( 'wt_cs_consent_version_test' );
		if ( !empty( $consent_version ) ) {
			$current_consent_version = (int) $consent_version;
		}

		return $current_consent_version;
	}

	function cs_get_post_by_geo() {

		if ( ( (int) $this->getOption( 'cs_geolocation' ) === 0 || (int) $this->getOption( 'cs_geo_activated' ) === 0 ) ) {
			$args_posts = array(
				'post_type'      => CMPRO_POST_TYPE,
				'post_status'    => 'publish',
				'meta_query'     => array(
					array(
						'key'   => '_cs_enable_rule',
						'value' => 1,
					)
				),
				'posts_per_page' => 1,
				'order'          => 'ASC',
				'meta_key'       => '_cs_order',
				'orderby'        => 'meta_value_num',
				'meta_type'      => 'NUMERIC',
			);
		} else {
			$cs_geo = ( new CS_Geoip() );

			$user_country = $cs_geo->cs_check_country();
			$user_city = $cs_geo->cs_check_city();

			$p_id = null;

			if ( $user_city == 'California' ) {
				$user_country = 'CCPA';
			}

			$args_posts = array(
				'post_type'      => CMPRO_POST_TYPE,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => '_cs_target',
						'value'   => $user_country,
						'compare' => 'LIKE'
					),
					array(
						'key'   => '_cs_enable_rule',
						'value' => 1,
					)
				),
				'posts_per_page' => 1,
				'order'          => 'ASC',
				'meta_key'       => '_cs_order',
				'orderby'        => 'meta_value_num',
				'meta_type'      => 'NUMERIC',
			);
		}

		$loop_posts = new \WP_Query( $args_posts );
		if ( !$loop_posts->have_posts() ) {
			return false;
		} else {
			while ( $loop_posts->have_posts() ) {
				$loop_posts->the_post();
				$p_id = get_the_ID();
			}
		}
		wp_reset_postdata();

		return $p_id;
	}

	function cs_get_template_list( $post_slug = false ) {
		$cs_light_theme_id = get_page_id_by_path( 'cs_light_theme', '', CMPRO_TEMPLATE_POST_TYPE );
		$cs_dark_theme = get_page_id_by_path( 'cs_dark_theme', '', CMPRO_TEMPLATE_POST_TYPE );
		$cs_orange_theme = get_page_id_by_path( 'cs_orange_theme', '', CMPRO_TEMPLATE_POST_TYPE );

		$p_id = $this->cs_get_post_by_geo();

		if ( $post_slug ) {
			$args_posts = array(
				'post_type'      => CMPRO_TEMPLATE_POST_TYPE,
				'post_status'    => 'any',
				'name'           => $post_slug,
				'posts_per_page' => 1,
			);
		} else {
			$args_posts = array(
				'post_type'      => CMPRO_TEMPLATE_POST_TYPE,
				'post_status'    => 'any',
				'posts_per_page' => -1,
				'post__not_in'   => [
					$cs_light_theme_id,
					$cs_dark_theme,
					$cs_orange_theme
				]
			);
		}

		$output = '';
		$loop_posts = new \WP_Query( $args_posts );
		if ( !$loop_posts->have_posts() ) {
			return false;
		} else {
			$active_rule_id = $this->get_active_rule_id();
			if ( !empty( $active_rule_id ) ) {
				$metas = get_post_meta( $active_rule_id );
				$cs_deny_all_btn = $metas[ '_cs_deny_all_btn' ][ 0 ];
				$cs_custom_button_btn = $metas[ '_cs_custom_button' ][ 0 ];
				$cs_hide_close_btn = $metas[ '_cs_hide_close_btn' ][ 0 ];
			}

			while ( $loop_posts->have_posts() ) {
				$loop_posts->the_post();
				$id = $loop_posts->post->ID;
				$cs_privacy_link = '1';
				$cs_bars_position = 'bottom';
				$cs_type = 'ask_before_tracking';

				$edit_link = get_admin_url( null, 'admin.php?page=consent-magic' ) . '&design_template=edit&template_id=' . $id;
				$output .= '<div class="rules-wrap row headline align-items-center">';
				$output .= '<div class="col-12">';
				$output .= '<div class="row align-items-center">';
				$output .= '<div class="col-2">';
				$output .= '<h2>' . get_the_title( $id ) . '</h2>';
				$output .= '</div>';
				if ( !$post_slug ) {
					$output .= '<div class="col right-aligned">';
					$output .= '<a href="' . esc_url( $edit_link ) . '" class="btn btn-blue"><i class="icon-edit"></i> ';
					$output .= esc_html__( 'Edit', 'consent-magic' );
					$output .= '</a>';
					$output .= '<button type="button" data-id="' . $id . '" class="btn btn-blue template_delete_btn"><i class="icon-delete"></i> ';
					$output .= esc_html__( 'Delete', 'consent-magic' );
					$output .= '</button>';
					$output .= '</div>';
				}
				$output .= '</div>';
				$output .= '</div>';
				$output .= '<div class="col-12">';
				$output .= '<div class="row">';
				$output .= '<div class="col-2">';
				$output .= '<h3>' . esc_html__( 'Preview:', 'consent-magic' ) . '</h3>';
				$output .= '</div>';
				$output .= '<div class="col">';
				$output .= '<div class="preview_container cs_preview_container" style="display: inline-block">';
				$output .= '<button type="button" class="btn btn-link preview_action_btn" data-template="bar_small">';
				$output .= esc_html__( 'Small bar', 'consent-magic' );
				$output .= '</button>';
				$output .= '<div class="preview_wrap preview_wrap_showing">';
				ob_start();
				$active_rule_id = $p_id;
				$cs_bars_type = 'bar_small';
				include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs-bar.php';
				$data = ob_get_clean();
				$output .= $data;
				$output .= '</div>';
				$output .= '</div>';
				$output .= '<div class="preview_container cs_preview_container" style="display: inline-block">';
				$output .= '<button type="button" class="btn btn-link preview_action_btn" data-template="bar_large">';
				$output .= esc_html__( 'Large bar', 'consent-magic' );
				$output .= '</button>';
				$output .= '<div class="preview_wrap preview_wrap_showing">';
				ob_start();
				$post_id = $p_id;
				$cs_bars_type = 'bar_large';
				include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs-bar.php';
				$data = ob_get_clean();
				$output .= $data;
				$output .= '</div>';
				$output .= '</div>';
				$output .= '<div class="preview_container cs_preview_container" style="display: inline-block">';
				$output .= '<button type="button" class="btn btn-link preview_action_btn" data-template="popup_small">';
				$output .= esc_html__( 'Small popup', 'consent-magic' );
				$output .= '</button>';
				$output .= '<div class="preview_wrap preview_wrap_showing">';
				ob_start();
				$post_id = $p_id;
				$cs_bars_type = 'popup_small';
				$cs_bars_position = '';
				include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs_popup.php';
				$data = ob_get_clean();
				$output .= $data;
				$output .= '</div>';
				$output .= '</div>';
				$output .= '<div class="preview_container cs_preview_container" style="display: inline-block">';
				$output .= '<button type="button" class="btn btn-link preview_action_btn" data-template="popup_large">';
				$output .= esc_html__( 'Large popup', 'consent-magic' );
				$output .= '</button>';
				$output .= '<div class="preview_wrap preview_wrap_showing">';
				ob_start();
				$post_id = $p_id;
				$cs_bars_type = 'popup_large';
				$cs_bars_position = '';
				include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs_popup.php';
				$data = ob_get_clean();
				$output .= $data;
				$output .= '</div>';
				$output .= '</div>';
				$output .= '</div>';
				$output .= '</div>';
				$output .= '</div>';
				$output .= '</div>';
			}
			return $output;
		}
	}

	public function get_active_rule_id() {

		if ( empty( $this->active_rule_id ) ) {
			$this->set_active_rule_id();
		}

		return $this->active_rule_id;
	}

	public function get_preview_rule_id() {

		if ( ( (int) $this->getOption( 'cs_geolocation' ) === 0 || (int) $this->getOption( 'cs_geo_activated' ) === 0 ) ) {
			$args_posts = array(
				'post_type'      => CMPRO_POST_TYPE,
				'post_status'    => 'publish',
				'meta_query'     => array(
					array(
						'key'   => '_cs_enable_rule',
						'value' => 1,
					)
				),
				'posts_per_page' => 1,
				'order'          => 'ASC',
				'meta_key'       => '_cs_order',
				'orderby'        => 'meta_value_num',
				'meta_type'      => 'NUMERIC',
			);
		} else {

			$cs_geo = ( new CS_Geoip() );
			$user_country = $cs_geo->cs_check_country();
			$user_city = $cs_geo->cs_check_city();

			if ( $user_city == 'California' ) {
				$user_country = 'CCPA';
			}

			$args_posts = array(
				'post_type'      => CMPRO_POST_TYPE,
				'post_status'    => 'publish',
				'meta_query'     => array(
					'relation' => 'AND',
					array(
						'key'     => '_cs_target',
						'value'   => $user_country,
						'compare' => 'LIKE'
					)
				),
				'posts_per_page' => 1,
				'order'          => 'ASC',
				'meta_key'       => '_cs_order',
				'orderby'        => 'meta_value_num',
				'meta_type'      => 'NUMERIC',
			);
		}

		$rule = new \WP_Query( $args_posts );
		if ( !$rule->have_posts() ) {
			return false;
		} else {
			$rule->the_post();
			$id = $rule->post->ID;
			return $id;
		}
	}

	public function loadDefaultTranslations() {

		if ( !file_exists( $this->translations_path ) ) {
			return;
		}

		$content = file_get_contents( $this->translations_path );
		$values = json_decode( $content, true );

		if ( null === $values ) {
			return;
		} else {
			return $values;
		}
	}

	public function renderDefaultText( $key, $meta = false ) {

		$translations = $this->loadDefaultTranslations();

		$replaced = stripos( $key, '_' . CMPRO_DEFAULT_LANGUAGE );
		$key = str_replace( '_' . CMPRO_DEFAULT_LANGUAGE, '', $key );

		if ( !empty( $translations ) && is_array( $translations ) ) {
			if ( $meta ) {
				if ( isset( $translations[ 'categories' ][ $key ][ CMPRO_DEFAULT_LANGUAGE ] ) ) {
					return $translations[ 'categories' ][ $key ][ CMPRO_DEFAULT_LANGUAGE ];
				}
			} else {
				if ( $replaced !== false && isset( $translations[ 'text' ][ $key ][ CMPRO_DEFAULT_LANGUAGE ] ) ) {
					return $translations[ 'text' ][ $key ][ CMPRO_DEFAULT_LANGUAGE ];
				}
			}
		}

		return false;
	}

	public function get_unblocked_user_ip() {

		if ( self::$unblocked_user_ip !== false && empty( self::$unblocked_user_ip ) ) {
			global $wpdb;
			$table_name = $wpdb->prefix . 'cs_unblock_ip';

			$ip_list = $wpdb->get_results( $wpdb->prepare( 'SELECT `ip` FROM %1$s ', $table_name ), ARRAY_N );
			$ip_list_new = array();

			if ( $ip_list ) {
				foreach ( $ip_list as $ip ) {
					array_push( $ip_list_new, $ip[ 0 ] );
				}
			} else {
				$ip_list_new = false;
			}

			self::$unblocked_user_ip = $ip_list_new;
		} else {
			return self::$unblocked_user_ip;
		}
	}

	//check for unblocked knonw crawlers
	public function check_unblocked_crawlers() {

		if ( self::$check_unblocked_crawlers === null ) {
			$enabled_option = $this->getOption( 'cs_disable_for_knonw_crawlers' );
			if ( (int) $enabled_option === 1 ) {

				$bots = array(
					'YandexBot',
					'YandexAccessibilityBot',
					'YandexMobileBot',
					'YandexDirectDyn',
					'YandexScreenshotBot',
					'YandexImages',
					'YandexVideo',
					'YandexVideoParser',
					'YandexMedia',
					'YandexBlogs',
					'YandexFavicons',
					'YandexWebmaster',
					'YandexPagechecker',
					'YandexImageResizer',
					'YandexAdNet',
					'YandexDirect',
					'YaDirectFetcher',
					'YandexCalendar',
					'YandexSitelinks',
					'YandexMetrika',
					'YandexNews',
					'YandexNewslinks',
					'YandexCatalog',
					'YandexAntivirus',
					'YandexMarket',
					'YandexVertis',
					'YandexForDomain',
					'YandexSpravBot',
					'YandexSearchShop',
					'YandexMedianaBot',
					'YandexOntoDB',
					'YandexOntoDBAPI',
					'Googlebot',
					'Googlebot-Image',
					'Googlebot-News',
					'Googlebot-Video',
					'Mediapartners-Google',
					'AdsBot-Google',
					'Chrome-Lighthouse',
					'Lighthouse',
					'Mail.RU_Bot',
					'bingbot',
					'Accoona',
					'ia_archiver',
					'Ask Jeeves',
					'OmniExplorer_Bot',
					'W3C_Validator',
					'WebAlta',
					'YahooFeedSeeker',
					'Yahoo!',
					'Ezooms',
					'Tourlentabot',
					'MJ12bot',
					'AhrefsBot',
					'SearchBot',
					'SiteStatus',
					'Nigma.ru',
					'Baiduspider',
					'Statsbot',
					'SISTRIX',
					'AcoonBot',
					'findlinks',
					'proximic',
					'OpenindexSpider',
					'statdom.ru',
					'Exabot',
					'Spider',
					'SeznamBot',
					'oBot',
					'C-T bot',
					'Updownerbot',
					'Snoopy',
					'heritrix',
					'Yeti',
					'DomainVader',
					'DCPbot',
					'PaperLiBot',
					'APIs-Google',
					'AdsBot-Google-Mobile',
					'AdsBot-Google-Mobile',
					'AdsBot-Google-Mobile-Apps',
					'FeedFetcher-Google',
					'Google-Read-Aloud',
					'DuplexWeb-Google',
					'Storebot-Google'
				);

				foreach ( $bots as $bot ) {
					if ( isset( $_SERVER[ 'HTTP_USER_AGENT' ] ) && stripos( $this->sanitize_text_field( $_SERVER[ 'HTTP_USER_AGENT' ] ), $bot ) !== false ) {
						self::$check_unblocked_crawlers = true; //if bot - blocker not working
					}
				}
			} else {
				self::$check_unblocked_crawlers = false; //if disabled option - run standart blocker
			}
		}
	}

	/**
	 * Get unblocked crawlers
	 * @return mixed
	 */
	public function get_unblocked_crawlers() {
		return self::$check_unblocked_crawlers;
	}

	/**
	 * Check settings for force updating
	 * @return void
	 */
	private function cs_check_settings( $plugin_admin ) {

		$current_version = $this->getOption( 'cs_check_settings' );
		if ( $this->getOption( 'cs_check_settings' ) != CMPRO_LATEST_VERSION_NUMBER ) {

			//migrate to the only one setting of Google consent mode v2
			if ( version_compare( $this->version, '2.0.6.2', '<=' ) ) {
				if ( $this->getOption( 'cs_google_analytics_consent_mode' ) || $this->getOption( 'cs_google_ads_consent_mode' ) ) {
					$this->updateOptions( array( 'cs_google_consent_mode' => 1 ) );
					$this->deleteOption( 'cs_google_analytics_consent_mode' );
					$this->deleteOption( 'cs_google_ads_consent_mode' );
				}
			}

			//set Google consent mode v2 to true by default
			if ( version_compare( $current_version, '3.0.2', '<=' ) ) {
				$this->updateOptions( array( 'cs_google_consent_mode' => true ) );
			}

			//Force set admin permissions
			$admin = get_option( 'cs_admin_permissions' );
			if ( empty( $admin ) || ( isset( $admin[ 0 ] ) && empty( $admin[ 0 ] ) ) ) {
				update_option( 'cs_admin_permissions', array( 'administrator' ) );
			}

			//Update geolocation
			if ( ( (int) $this->getOption( 'cs_geolocation' ) === 1 || (int) $this->getOption( 'cs_geo_activated' ) === 1 ) ) {
				if ( !defined( 'DISABLE_WP_CRON' ) || !DISABLE_WP_CRON ) {
					db_cron_update_one_time();
				} else {
					$this->loader->add_action( 'admin_init', $plugin_admin, 'cs_force_update_runner' );
				}
			}

			$this->updateOptions( array( 'cs_check_settings' => CMPRO_LATEST_VERSION_NUMBER ) );
		}
	}

	public function cs_sanitize_array( &$value, $key ) {
		if ( is_array( $value ) ) {
			array_walk( $value, array(
				$this,
				'cs_sanitize_array'
			) );
		} else {
			$value = sanitize_text_field( $value );
		}
	}

	public function get_minimum_recommended_options() {
		$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
		$unassigned_id = $unassigned->term_id;
		$options = get_cookies_terms_objects( null, false, $unassigned_id );
		$active_rule_id = $this->get_active_rule_id();
		$minimum_recommended = array();

		if ( !empty( $options ) ) {
			foreach ( $options as $option ) {
				$ignore_category = get_term_meta( $option->term_id, 'cs_ignore_this_category', true );
				if ( !$ignore_category ) {
					$value = (int) get_post_meta( $active_rule_id, '_cs_custom_button_' . $option->term_id, true );
					$minimum_recommended[ $option->term_id ] = $value;

					if ( $option->slug === 'marketing' ) {
						$minimum_recommended[ 'cs_enabled_server_side' ] = $minimum_recommended[ 'cs_enabled_advanced_matching' ] = $value;
					}
				}
			}
		}

		return $minimum_recommended;
	}

	public function get_containers_names() {
		return $this->containers_names;
	}

	/**
	 * Add google consent mode
	 * @return void
	 */
	public function add_google_consent_mode() {

		if ( $this->getOption( 'cs_google_consent_mode' ) ) {

			if ( $this->ready_to_run() && !empty( $this->get_active_rule_id() ) ) {

				$analytics_storage = $ad_storage = $ad_user_data = $ad_personalization = 'granted';
				$analytics_storage_ignore = $ad_storage_ignore = $ad_user_data_ignore = $ad_personalization_ignore = false;

				$category = get_term_by( 'slug', $this->getOption( 'cs_block_analytics_storage_scripts_cat' ), 'cs-cookies-category' );
				if ( $category ) {
					$analytics_storage = $this->get_advanced_consent_mode_value( $category->term_id );
					$analytics_storage_ignore = get_term_meta( $category->term_id, 'cs_ignore_this_category', true ) == 1;
				}

				$category = get_term_by( 'slug', $this->getOption( 'cs_block_ad_storage_scripts_cat' ), 'cs-cookies-category' );
				if ( $category ) {
					$ad_storage = $this->get_advanced_consent_mode_value( $category->term_id );
					$ad_storage_ignore = get_term_meta( $category->term_id, 'cs_ignore_this_category', true ) == 1;
				}

				$category = get_term_by( 'slug', $this->getOption( 'cs_block_ad_user_data_scripts_cat' ), 'cs-cookies-category' );
				if ( $category ) {
					$ad_user_data = $this->get_advanced_consent_mode_value( $category->term_id );
					$ad_user_data_ignore = get_term_meta( $category->term_id, 'cs_ignore_this_category', true ) == 1;
				}

				$category = get_term_by( 'slug', $this->getOption( 'cs_block_ad_personalization_scripts_cat' ), 'cs-cookies-category' );
				if ( $category ) {
					$ad_personalization = $this->get_advanced_consent_mode_value( $category->term_id );
					$ad_personalization_ignore = get_term_meta( $category->term_id, 'cs_ignore_this_category', true ) == 1;
				}

				$blocking_enabled = $this->ready_to_run() && self::$check_disable_cm && $this->getOption( 'cs_block_pre_defined_scripts' ) && $this->getOption( 'cs_plugin_activation' ) && $this->getOption( 'cs_script_blocking_enabled' );
				$this->ad_storage = (bool) apply_filters( 'cm_ad_storage_mode', $blocking_enabled && !$ad_storage_ignore && $this->getOption( 'cs_block_ad_storage_scripts' ) );
				$this->analytics_storage = (bool) apply_filters( 'cm_analytics_storage_mode', $blocking_enabled && !$analytics_storage_ignore && $this->getOption( 'cs_block_analytics_storage_scripts' ) );
				$this->ad_user_data = (bool) apply_filters( 'cm_ad_user_data_mode', $blocking_enabled && !$ad_user_data_ignore && $this->getOption( 'cs_block_ad_user_data_scripts' ) );
				$this->ad_personalization = (bool) apply_filters( 'cm_ad_personalization_mode', $blocking_enabled && !$ad_personalization_ignore && $this->getOption( 'cs_block_ad_personalization_scripts' ) );

			} else {
				$this->ad_storage = true;
				$this->analytics_storage = true;
				$this->ad_user_data = true;
				$this->ad_personalization = true;
				$analytics_storage = $ad_storage = $ad_user_data = $ad_personalization = 'granted';
			}

			add_filter( 'cm_google_consent_mode', function () use ( $analytics_storage, $ad_storage, $ad_user_data, $ad_personalization ) {
				return array(
					'analytics_storage'  => array(
						'enabled' => $this->analytics_storage,
						'value'   => $analytics_storage,
					),
					'ad_storage'         => array(
						'enabled' => $this->ad_storage,
						'value'   => $ad_storage,
					),
					'ad_user_data'       => array(
						'enabled' => $this->ad_user_data,
						'value'   => $ad_user_data,
					),
					'ad_personalization' => array(
						'enabled' => $this->ad_personalization,
						'value'   => $ad_personalization,
					),
				);
			} );
		}
	}

	/**
	 * Get advanced consent mode value for PYS
	 *
	 * @param $cat_id
	 * @return string
	 */
	public function get_advanced_consent_mode_value( $cat_id ) {

		$active_rule_id = $this->get_active_rule_id();
		$ignore = get_term_meta( $cat_id, 'cs_ignore_this_category', true );
		if ( empty( $active_rule_id ) || $ignore == 1 ) {
			return 'granted';
		}

		$cs_type = get_post_meta( $active_rule_id, '_cs_type', true );
		$analytics_cat_id = get_option( 'analytics_cat_id' );
		$cs_track_analytics = get_post_meta( $active_rule_id, '_cs_track_analytics', true );
		$test_prefix = false;
		$check = true;

		if ( $this->getOption( 'cs_test_mode' ) ) {
			$test_prefix = '_test';
		}
		$viewed_cookie = "cs_viewed_cookie_policy" . $test_prefix;

		$category_cookie = "cs_enabled_cookie_term" . $test_prefix . '_' . $cat_id;

		if ( isset( $_COOKIE[ $category_cookie ] ) && isset( $_COOKIE[ $viewed_cookie ] ) ) {
			if ( $_COOKIE[ $category_cookie ] == 'yes' && $_COOKIE[ $viewed_cookie ] == 'yes' ) {
				$check = false; //allowed by user then false
			}
		} else {
			if ( $cs_type != 'just_inform' && $cs_type != 'inform_and_opiout' ) {
				if ( (int) $cs_track_analytics === 1 && $analytics_cat_id == $cat_id ) {
					$check = false; //track analytics
				}
			} else {
				$check = false; //this is rule "inform_and_opiout" OR "just_inform"
			}
		}

		return $check ? 'denied' : 'granted';
	}


	function add_edd_order_details( $order_id ) {
		echo '<div class="postbox" style="padding: 15px;">
    		<h3 class="hndle"><span>' . esc_html__( 'Consent Magic Pro', 'consent-magic' ) . '</span></h3>';
		include_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/order/html-edd-order-box.php';

		echo '</div>';
	}

	/**
	 * Check ready to run the plugin
	 * @return bool
	 */
	public function ready_to_run() {

		if ( self::$run === null ) {
			if ( ( isset( $_GET[ 'et_fb' ] ) && sanitize_text_field( $_GET[ 'et_fb' ] ) == 1 ) || ( isset( $_GET[ 'bricks' ] ) && sanitize_text_field( $_GET[ 'bricks' ] ) == 'run' ) ) {
				return self::$run = false;
			}
			if ( ConsentMagic()->getOption( 'cs_test_mode' ) ) {
				$user = wp_get_current_user();
				$allowed_roles = get_option( 'cs_admin_permissions' );
				if ( empty( array_intersect( $allowed_roles, $user->roles ) ) ) {
					return self::$run = false;
				}
			}
		} else {
			return self::$run;
		}

		return self::$run = true;
	}
}

/**
 * @return ConsentMagic
 */
function ConsentMagic() {
	return ConsentMagic::instance();
}