<?php

namespace ConsentMagicPro;

function renderUpgradeBlock( $url = null, $text = null, $label = null ) {

	if ( !$url ) {
		$url = 'https://www.pixelyoursite.com/plugins/consentmagic';
	}

	if ( !$text ) {
		$text = __( 'With the PRO version you can have multiple rules with Geo-Targeting, including pre-defined rules', 'consent-magic' );;
	}

	if ( !$label ) {
		$label = __( 'Upgrade', 'consent-magic' );
	}

	$url = untrailingslashit( $url ) . '/?utm_source=pys-free-plugin&utm_medium=pro-badge&utm_campaign=pro-feature';

	$output = '';

	$output .= '<div class="upgrade-block-wrap">';
	$output .= '<div class="row align-items-center">';
	$output .= '<div class="col">';
	$output .= '<p>' . esc_html__( $text ) . '</p>';
	$output .= '</div>';
	$output .= '<div class="col-3 right-aligned">';
	$output .= '<a href="' . esc_url( $url ) . '" target="_blank" rel="nofollow" class="btn btn-pro"><i class="icon-upgrade"></i> ' . esc_html__( $label ) . '</a>';
	$output .= '</div>';
	$output .= '</div>';
	$output .= '</div>';

	return $output;
}

/**
 * Output number input
 *
 * @param      $key
 * @param null $placeholder
 * @param bool $disabled
 */
function render_number_input( $key, $placeholder = null, $disabled = false, $design = false, $meta = false, $id = null ) {
	$unic = uniqid();
	if ( $design ) {
		$attr_name = "cs_d[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_d_' . ConsentMagic()->get_plugin_name() . '_' . $key . '_' . $unic;
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );
	} else {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . ConsentMagic()->get_plugin_name() . '_' . $key . '_' . $unic;
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );
	}

	?>

    <input <?php disabled( $disabled ); ?>
            type="number"
            name="<?php esc_attr_e( $attr_name ); ?>"
            id="<?php esc_attr_e( $attr_id ); ?>"
            value="<?php esc_attr_e( $attr_value ); ?>"
            placeholder="<?php esc_attr_e( $placeholder ); ?>"
            min="0" class="form-control">
	<?php
}

/**
 * Output checkbox input stylized as switcher
 *
 * @param      $key
 * @param bool $collapse
 * @param bool $disabled
 */
function render_switcher_input( $key, $json = true, $meta = false, $id = null, $collapse = false, $disabled = false, $label = false, $default = false, $custom_classes = false ) {
	$unic = uniqid();
	if ( $json ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . ConsentMagic()->get_plugin_name() . '_' . $unic;
		$attr_value = ConsentMagic()->getOption( $key );
	} else {
		$attr_name = $key;
		$attr_id = $key . '_' . $unic;
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : get_option( $key );
	}

	$classes = array( 'custom-switch' );

	if ( $collapse ) {
		$classes[] = 'collapse-control';
	}

	if ( $custom_classes ) {
		$classes[] = $custom_classes;
	}

	$classes = implode( ' ', $classes );

	$output = '';

	if ( $default === false ) {
		$default = $attr_value;
	}

	$output .= '<div class="' . esc_attr( $classes ) . '">';
	if ( !$disabled ) :
		$output .= '<input type="hidden" name="' . esc_attr( $attr_name ) . '" value="0" class="' . esc_attr( $key ) . '">';
	endif;
	if ( $collapse ) :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . '
					   id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input ' . esc_attr( $key ) . '"
					   data-target="cs_' . esc_attr( ConsentMagic()->get_plugin_name() ) . '_' . esc_attr( $key ) . '_panel">';
	else :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . ' id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input ' . esc_attr( $key ) . '">';
	endif;
	$output .= '<label class="custom-switch custom-switch-btn" for="' . esc_attr( $attr_id ) . '"></label>';
	if ( $label ) {
		$output .= '<label class="indicator-label switcher-label custom-label">' . esc_html( $label ) . '</label>';
	}

	$output .= '</div>';

	return $output;
}

/**
 * Output checkbox input stylized as switcher
 *
 * @param      $key
 * @param bool $collapse
 * @param bool $disabled
 */
function render_subcheckbox_input( $key, $json = true, $meta = false, $id = null, $collapse = false, $disabled = false, $label = false, $default = false, $custom_classes = false ) {
	$unic = uniqid();
	if ( $json ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . ConsentMagic()->get_plugin_name() . '_' . $unic;
		$attr_value = ConsentMagic()->getOption( $key );
	} else {
		$attr_name = $key;
		$attr_id = $key . '_' . $unic;
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : get_option( $key );
	}

	$classes = array( 'custom-switch d-flex align-items-center' );

	if ( $collapse ) {
		$classes[] = 'collapse-control';
	}

	if ( $custom_classes ) {
		$classes[] = $custom_classes;
	}

	$classes = implode( ' ', $classes );

	$output = '';

	if ( $default === false ) {
		$default = $attr_value;
	}

	$output .= '<div class="' . esc_attr( $classes ) . '">';
	if ( !$disabled ) :
		$output .= '<input type="hidden" name="' . esc_attr( $attr_name ) . '" value="0" class="' . esc_attr( $key ) . '">';
	endif;
	if ( $collapse ) :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . '
					   id="' . esc_attr( $attr_id ) . '"
					   class="custom-sub-switch-input ' . esc_attr( $key ) . '"
					   data-target="cs_' . esc_attr( ConsentMagic()->get_plugin_name() ) . '_' . esc_attr( $key ) . '_panel">';
	else :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . ' id="' . esc_attr( $attr_id ) . '"
					   class="custom-sub-switch-input ' . esc_attr( $key ) . '">';
	endif;
	$output .= '<label class="custom-sub-switch custom-switch-btn" for="' . esc_attr( $attr_id ) . '"></label>';
	if ( $label ) {
		$output .= '<label class="indicator-label switcher-label custom-label">' . esc_html( $label ) . '</label>';
	}

	$output .= '</div>';

	return $output;
}

function render_hidden_checkbox( $key, $value = null, $class = null ) {
	$key = "cs[" . ConsentMagic()->plugin_name . "][$key]";

	$output = '<input type="hidden" name="' . esc_attr( $key ) . '" value="' . esc_attr( $value ) . '" class="' . esc_attr( $class ) . '">';

	return $output;
}

/**
 * Output checkbox input stylized as switcher
 *
 * @param      $key
 * @param bool $collapse
 * @param bool $disabled
 */
function render_switcher_input_front( $key, $json = true, $meta = false, $id = null, $collapse = false, $disabled = false, $label = false, $default = false, $additional_styles = null ) {
	if ( $json ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . ConsentMagic()->get_plugin_name();
		$attr_value = ConsentMagic()->getOption( $key );
	} else {
		$attr_name = $key;
		$attr_id = $key;
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : get_option( $key );
	}

	$classes = array( 'custom-switch' );

	if ( $collapse ) {
		$classes[] = 'collapse-control';
	}

	$classes = implode( ' ', $classes );

	$output = '';

	if ( !$default ) {
		$default = $attr_value;
	}

	$output .= '<div class="' . esc_attr( $classes ) . '">';
	if ( !$disabled ) :
		$output .= '<input type="hidden" name="' . esc_attr( $attr_name ) . '" value="0" class="' . esc_attr( $key ) . '">';
	endif;
	if ( $collapse ) :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . '
					   id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input ' . esc_attr( $key ) . '"
					   data-target="cs_' . esc_attr( ConsentMagic()->get_plugin_name() ) . '_' . esc_attr( $key ) . '_panel">';
	else :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . ' id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input ' . esc_attr( $key ) . '">';
	endif;
	$output .= '<label class="custom-switch custom-switch-btn" for="' . esc_attr( $attr_id ) . '" style="' . $additional_styles . '"></label>';
	if ( $label ) {
		$output .= '<label class="indicator-label switcher-label custom-label">' . esc_html( $label ) . '</label>';
	}

	$output .= '</div>';

	return $output;
}

/**
 * Output checkbox input stylized as switcher
 *
 * @param      $key
 * @param bool $collapse
 * @param bool $disabled
 */
function render_switcher_term_input( $key, $id = null, $collapse = false, $disabled = false, $label = false, $default = false ) {
	$attr_name = $key . '_' . $id;
	$attr_id = $key . '_' . $id;
	$attr_value = get_term_meta( $id, $key, true );

	$classes = array( 'custom-switch' );

	if ( $collapse ) {
		$classes[] = 'collapse-control';
	}

	$classes = implode( ' ', $classes );

	$output = '';

	if ( !$default ) {
		$default = $attr_value;
	}

	$output .= '<div class="' . esc_attr( $classes ) . '">';
	if ( !$disabled ) :
		$output .= '<input type="hidden" name="' . esc_attr( $attr_name ) . '" value="0">';
	endif;
	if ( $collapse ) :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . '
					   id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input"
					   data-target="cs_' . esc_attr( ConsentMagic()->get_plugin_name() ) . '_' . esc_attr( $key ) . '_panel">';
	else :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . ' id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input">';
	endif;
	$output .= '<label class="custom-switch custom-switch-btn" for="' . esc_attr( $attr_id ) . '"></label>';
	if ( $label ) {
		$output .= '<label class="indicator-label switcher-label custom-label">' . esc_html( $label ) . '</label>';
	}

	$output .= '</div>';

	return $output;
}

/**
 * Output checkbox input stylized as checkbox
 *
 * @param      $key
 * @param bool $collapse
 * @param bool $disabled
 */
function render_checkbox_input( $key, $id = null, $disabled = false, $default = false ) {
	$attr_name = "cs[consent-magic][" . $key . "]";
	$attr_id = $key;
	$attr_value = ConsentMagic()->getOption( $key );

	$output = '';

	if ( !$default ) {
		$default = $attr_value;
	}

	$output .= '<input type="hidden" name="' . esc_attr( $attr_name ) . '" value="0">';

	$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $default, true, false ) . ' id="' . esc_attr( $attr_id ) . '"
					   class="custom-checkbox">';

	return $output;
}

/**
 * Output checkbox input stylized as switcher
 *
 * @param      $key
 * @param bool $collapse
 * @param bool $disabled
 */
function render_several_switcher_input( $key, $json = true, $meta = false, $id = null, $collapse = false, $disabled = false, $label = false ) {
	if ( $json ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . ConsentMagic()->get_plugin_name() . '_' . $key;
		$attr_value = ConsentMagic()->getOption( $key );
	} else {
		$attr_name = $key . '_' . $id;
		$attr_id = $key . '_' . $id;
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : get_option( $key );
	}

	$classes = array( 'custom-switch' );

	if ( $collapse ) {
		$classes[] = 'collapse-control';
	}

	$classes = implode( ' ', $classes );

	$output = '';

	$output .= '<div class="' . esc_attr( $classes ) . '">';
	if ( !$disabled ) :
		$output .= '<input type="hidden" name="' . esc_attr( $attr_name ) . '" value="0">';
	endif;
	if ( $collapse ) :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $attr_value, true, false ) . '
					   id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input"
					   data-target="cs_' . esc_attr( ConsentMagic()->get_plugin_name() ) . '_' . esc_attr( $key ) . '_panel">';
	else :
		$output .= '<input type="checkbox" name="' . esc_attr( $attr_name ) . '" value="1" ' . disabled( $disabled, true, false ) . ' ' . checked( $attr_value, true, false ) . ' id="' . esc_attr( $attr_id ) . '"
					   class="custom-switch-input">';
	endif;
	$output .= '<label class="custom-switch custom-switch-btn" for="' . esc_attr( $attr_id ) . '"></label>';
	if ( $label ) {
		$output .= '<label class="indicator-label switcher-label custom-label">' . esc_html( $label ) . '</label>';
	}

	$output .= '</div>';

	return $output;
}

/**
 * Output radio input
 *
 * @param      $key
 * @param      $value
 * @param      $label
 * @param bool $disabled
 */
function render_radio_input( $key, $value, $label, $disabled = false ) {

	if ( get_option( $key ) ) {
		$attr_name = $key;
		$attr_value = get_option( $key );
	} else {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_value = ConsentMagic()->getOption( $key );
	}
	?>

    <label class="custom-control custom-radio">
        <input type="radio" name="<?php esc_attr_e( $attr_name ); ?>" <?php disabled( $disabled, true ); ?>
               class="custom-control-input" <?php echo ( $attr_value == $value ) ? 'checked="checked"' : ''; ?>
               value="<?php esc_attr_e( $value ); ?>">
        <span class="custom-control-indicator"></span>
        <span class="custom-control-description"><?php echo esc_html( $label ); ?></span>
    </label>

	<?php
}

function renderCollapseTargetAttributes( $key ) {
	echo 'class="cs_' . ConsentMagic()->get_plugin_name() . '_' . esc_attr( $key ) . '_panel"';
}

/**
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderTextarea( $key, $placeholder = '', $class = '', $full_width = false, $meta = false, $id = null ) {

	$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
	$attr_id = 'cs_' . $key;
	$attr_value = $meta ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );
	$attr_width = $full_width ? 'width: 100%;' : '';
	?>

    <textarea name="<?php esc_attr_e( $attr_name ); ?>"
              id="<?php esc_attr_e( $attr_id ); ?>"
              placeholder="<?php esc_attr_e( $placeholder ); ?>"
              style="<?php esc_attr_e( $attr_width ); ?>"
              class="form-control <?php echo esc_attr( $class ); ?>"><?php esc_attr_e( $attr_value ); ?></textarea>

	<?php
}

/**
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderWpEditor( $key, $lang, $class = '', $meta = false, $id = null ) {

	if ( !class_exists( '_WP_Editors', false ) ) {
		wp_enqueue_editor();
	}

	$langOptions = renderLanguageOptions( $key, $lang, $meta, $id );

	wp_editor(  wp_kses_post( $langOptions[ 'attr_value' ] ), esc_attr( $langOptions[ 'attr_id' ] ), array(
		'wpautop'          => 1,
		'media_buttons'    => 0,
		'textarea_name'    => esc_attr( $langOptions[ 'attr_name' ] ),
		'textarea_rows'    => 5,
		'tabindex'         => null,
		'editor_css'       => '',
		'editor_class'     => esc_attr( $class ),
		'teeny'            => 1,
		'dfw'              => 0,
		'tinymce'          => 1,
		'quicktags'        => 1,
		'drag_drop_upload' => false
	) );
}

/**
 * It uses for nolang editors
 *
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderSimpleWpEditor( $key, $class = '', $meta = false, $id = null ) {

	if ( !class_exists( '_WP_Editors', false ) ) {
		wp_enqueue_editor();
	}

	if ( $meta ) {
		$attr_name = $key;
		$attr_id = $key;
	} else {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . $key;
	}

	if ( get_option( $key ) ) {
		$attr_value = get_option( $key );
	} else {
		$attr_value = $meta ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );
	}

	wp_editor( wp_kses_post( $attr_value ), esc_attr( $attr_id ), array(
		'wpautop'          => 1,
		'media_buttons'    => 0,
		'textarea_name'    => esc_attr( $attr_name ),
		'textarea_rows'    => 10,
		'tabindex'         => null,
		'editor_css'       => '',
		'editor_class'     => esc_attr( $class ),
		'teeny'            => 1,
		'dfw'              => 0,
		'tinymce'          => 1,
		'quicktags'        => 1,
		'drag_drop_upload' => false
	) );
}

/**
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderWpEditorByTerm( $description, $lang = '', $class = '', $id = null ) {

	if ( !class_exists( '_WP_Editors', false ) ) {
		wp_enqueue_editor();
	}

	if ( $id ) {
		wp_editor( wp_kses_post( $description ), 'cs_edit_cat_description_' . esc_attr( $id ) . uniqid(), array(
			'wpautop'          => 1,
			'media_buttons'    => 0,
			'textarea_rows'    => 5,
			'textarea_name'    => 'cs_edit_cat_description_' . esc_attr( $lang ),
			'tabindex'         => null,
			'editor_css'       => '',
			'editor_class'     => esc_attr( $class ),
			'teeny'            => 1,
			'dfw'              => 0,
			'tinymce'          => 1,
			'quicktags'        => 1,
			'drag_drop_upload' => false
		) );
	} else {
		wp_editor( wp_kses_post( $description ), 'cs_new_cat_description', array(
			'wpautop'          => 1,
			'media_buttons'    => 0,
			'textarea_rows'    => 5,
			'textarea_name'    => 'cs_edit_cat_description_' . esc_attr( $lang ),
			'tabindex'         => null,
			'editor_css'       => '',
			'editor_class'     => esc_attr( $class ),
			'teeny'            => 1,
			'dfw'              => 0,
			'tinymce'          => 1,
			'quicktags'        => 1,
			'drag_drop_upload' => false
		) );
	}
}

/**
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderTextInput( $key, $id = null, $lang = CMPRO_DEFAULT_LANGUAGE, $meta = false, $placeholder = '', $class = '', $required = false, $disabled = false ) {

	$langOptions = renderLanguageOptions( $key, $lang, $meta, $id );

	?>
    <input type="text" name="<?php echo esc_attr( $langOptions[ 'attr_name' ] ); ?>"
           id="<?php echo esc_attr( $langOptions[ 'attr_id' ] ); ?>"
           placeholder="<?php esc_attr_e( $placeholder ); ?>"
           class="form-control <?php echo esc_attr( $class ); ?>"
           value="<?php esc_attr_e( $langOptions[ 'attr_value' ] ); ?>" <?php esc_attr_e( $required ); ?> <?php disabled( $disabled ); ?> />
	<?php
}

/**
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderProofDeletingEmail( $key = 'cs_send_proof_deleting_email', $full_width = false ) {
	$attr_id = 'cs_' . $key;
	$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
	if ( ConsentMagic()->getOption( $key ) ) {
		$attr_value = ConsentMagic()->getOption( $key );
	} else {
		$attr_value = get_option( 'cs_autodetect_email' );
	}

	$attr_width = $full_width ? 'width: 100%;' : '';

	?>

    <input type="text" name="<?php esc_attr_e( $attr_name ); ?>"
           id="<?php esc_attr_e( $attr_id ); ?>"
           class="form-control" value="<?php esc_attr_e( $attr_value ); ?>"
           style="<?php esc_attr_e( $attr_width ); ?>"/>
	<?php
}

/**
 * @param string $key
 * @param string $placeholder
 * @param string $class
 */
function renderColorPickerInput( $key, $id = null, $placeholder = '', $class = '' ) {
	$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
	$attr_id = 'cs_' . $key;
	$attr_value = $id ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );

	?>

    <input name="<?php esc_attr_e( $attr_name ); ?>"
           id="<?php esc_attr_e( $attr_id ); ?>"
           placeholder="<?php esc_attr_e( $placeholder ); ?>"
           class="form-control color-field <?php echo esc_attr( $class ); ?>"
           value="<?php esc_attr_e( $attr_value ); ?>"/>

	<?php
}

/**
 * @param string $key
 * @param array $options
 * @param string $full_width
 */
function renderSelectInput( $key, $options = array(), $full_width = false, $design = false ) {
	if ( $design ) {
		$attr_name = "cs_d[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_d_' . ConsentMagic()->get_plugin_name() . '_' . $key;
		$attr_value = ConsentMagic()->getOption( $key );
		$attr_width = $full_width ? 'width: 100%;' : '';
	} else {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . $key;
		$attr_value = ConsentMagic()->getOption( $key );
		$attr_width = $full_width ? 'width: 100%;' : '';
	}

	if ( !$design && get_option( $key ) ) {
		$attr_name = $key;
		$attr_id = $key;
		$attr_value = get_option( $key );
	}

	?>

    <select class="form-control-sm" id="<?php esc_attr_e( $attr_id ); ?>"
            name="<?php esc_attr_e( $attr_name ); ?>" autocomplete="off" style="<?php esc_attr_e( $attr_width ); ?>">
		<?php foreach ( $options as $option_key => $option_value ) : ?>
			<?php if ( is_array( $option_value ) ) {
				?>
                <option value="<?php echo esc_attr( $option_value[ 'option_value' ] ); ?>" <?php selected( $option_value[ 'option_value' ], esc_attr( $attr_value ) ); ?>><?php echo esc_attr( $option_value[ 'option_name' ] ); ?></option>
			<?php } else { ?>
                <option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $option_key, is_array( $attr_value ) ? esc_attr( $attr_value[ mb_strtolower( $option_value ) ] ) : esc_attr( $attr_value ) ); ?>><?php echo esc_attr( $option_value ); ?></option>
			<?php } endforeach; ?>
    </select>

	<?php
}

/**
 * @param string $key
 * @param array $options
 * @param string $full_width
 */
function get_renderSelectInput( $key, $options = array(), $full_width = false, $design = false ) {
	if ( $design ) {
		$attr_name = "cs_d[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_d_' . ConsentMagic()->get_plugin_name() . '_' . $key;
		$attr_value = ConsentMagic()->getOption( $key );
		$attr_width = $full_width ? 'width: 100%;' : '';
	} else {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . $key;
		$attr_value = ConsentMagic()->getOption( $key );
		$attr_width = $full_width ? 'width: 100%;' : '';
	}

	if ( !$design && get_option( $key ) ) {
		$attr_name = $key;
		$attr_id = $key;
		$attr_value = get_option( $key );
	}

	$output = '';

	$output .= '<select class="form-control-sm" id="' . esc_attr( $attr_id ) . '"
	        name="' . esc_attr( $attr_name ) . '" autocomplete="off" style="' . esc_attr( $attr_width ) . '">'; ?>
	<?php foreach ( $options as $option_key => $option_value ) : ?>
		<?php if ( is_array( $option_value ) ) {
			$output .= '<option value="' . esc_attr( $option_value[ 'option_value' ] ) . '" ' . selected( $option_value[ 'option_value' ], esc_attr( $attr_value ) ) . '>' . esc_attr( $option_value[ 'option_name' ] ) . '</option>'; ?>
		<?php } else {
			$output .= '<option value="' . esc_attr( $option_key ) . '" ' . selected( $option_key, is_array( $attr_value ) ? esc_attr( $attr_value[ mb_strtolower( $option_value ) ] ) : esc_attr( $attr_value ) ) . '>' . esc_attr( $option_value ) . '</option>';
		} endforeach; ?>

	<?php
	$output .= '</select>';
	return $output;
}

/**
 * @param string $key
 * @param array $options
 * @param string $full_width
 */
function renderSelectInput_meta( $key, $id, $options, $full_width = false, $design = false ) {
	if ( $design ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . $key;
		$attr_value = get_post_meta( $id, $key, true ) ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );
		$attr_width = $full_width ? 'width: 100%;' : '';
	} else {
		$attr_name = $key;
		$attr_id = $key;
		$attr_value = get_post_meta( $id, $key, true );
		$attr_width = $full_width ? 'width: 100%;' : '';
	}

	?>

    <select class="form-control-sm <?php echo esc_attr( $key ); ?>" id="<?php esc_attr_e( $attr_id ); ?>"
            name="<?php esc_attr_e( $attr_name ); ?>" autocomplete="off" style="<?php esc_attr_e( $attr_width ); ?>">
		<?php foreach ( $options as $option_key => $option_value ) : ?>
			<?php if ( is_array( $option_value ) ) {
				?>
                <option value="<?php echo esc_attr( $option_value[ 'option_value' ] ); ?>" <?php selected( $option_value[ 'option_value' ], esc_attr( $attr_value ) ); ?>><?php echo esc_attr( $option_value[ 'option_name' ] ); ?></option>
			<?php } else { ?>
                <option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $option_key, is_array( $attr_value ) ? esc_attr( $attr_value[ mb_strtolower( $option_value ) ] ) : esc_attr( $attr_value ) ); ?>><?php echo esc_attr( $option_value ); ?></option>
			<?php } endforeach; ?>
    </select>

	<?php
}

/**
 * @param string $key
 * @param array $options
 * @param string $full_width
 */
function renderSelectLocation( $key, $id, $options, $full_width = false, $design = false ) {
	if ( $design ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
		$attr_id = 'cs_' . $key;
		$attr_width = $full_width ? 'width: 100%;' : '';
	} else {
		$attr_name = $key;
		$attr_id = $key;
		$attr_width = $full_width ? 'width: 100%;' : '';
	}

	$selected = explode( ",", get_meta_value_by_key( $id, $key ) );

	?>

    <select class="form-control-sm" id="<?php esc_attr_e( $attr_id ); ?>" multiple data-placeholder="Select Location"
            name="<?php esc_attr_e( $attr_name ); ?>" autocomplete="off" style="<?php esc_attr_e( $attr_width ); ?>">
        <option data-value="GDPR"
                value="GDPR" <?php selected( in_array( 'GDPR', $selected ) ); ?>><?php esc_html_e( 'Select GDPR countries', 'consent-magic' ); ?></option>
        <option data-value="NONGDPR"
                value="NONGDPR" <?php selected( in_array( 'NONGDPR', $selected ) ); ?>><?php esc_html_e( 'Select non - GDPR countries', 'consent-magic' ); ?></option>
        <option data-value="CCPA"
                value="CCPA" <?php selected( in_array( 'CCPA', $selected ) ); ?>><?php esc_html_e( 'California (CCPA)', 'consent-magic' ); ?></option>
		<?php foreach ( $options as $option_key => $option_value ) : ?>
            <option data-pid="<?php echo esc_attr( $option_value[ 1 ] ); ?>"
                    value="<?php echo esc_attr( $option_key ); ?>" <?php selected( in_array( $option_key, $selected ) ); ?>><?php echo esc_attr( $option_value[ 0 ] ); ?></option>
		<?php endforeach; ?>
    </select>

	<?php
}

/**
 * Output multi select input
 *
 * @param      $key
 * @param      $values
 * @param bool $disabled
 */
function render_multi_select_input( $key, $values, $disabled = false, $class = '', $id = null, $admin_check = false ) {
	$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
	$attr_id = 'cs_' . $key;

	if ( get_option( $key ) ) {
		$selected = get_option( $key );
	} else if ( $id ) {
		$selected = explode( ",", get_post_meta( $id, $key, true ) );
	} else {
		$selected = ConsentMagic()->getOption( $key );
	}
	?>

    <input type="hidden" name="<?php esc_attr_e( $attr_name ); ?>" value="">
    <select class="form-control <?php echo esc_attr( $class ); ?>" name="<?php esc_attr_e( $attr_name ); ?>"
            id="<?php esc_attr_e( $attr_id ); ?>" <?php disabled( $disabled ); ?> style="width: 100%;"
            multiple="multiple">

		<?php if ( $values ) { ?>
			<?php foreach ( $values as $option_key => $option_value ) : ?>
				<?php if ( $admin_check ) { ?>
                    <option value="<?php

					if ( $class == 'cs_multi_select_tags' ) {
						echo esc_attr( $option_value );
					} else {
						echo esc_attr( $option_key );
					}

					?>"
						<?php

						if ( $class == 'cs_multi_select_tags' ) {
							if ( $option_value != 'null' ) {
								selected( in_array( $option_value, $selected ) );
							}
						} else {
							if ( $option_key != 'null' ) {
								selected( in_array( $option_key, $selected ) );
							}
						}

						?>
						<?php disabled( $option_key, 'disabled' ); ?>
                    >
						<?php echo esc_attr( $option_value ); ?>
                    </option>
				<?php } else if ( $option_value !== 'Administrator' ) { ?>
                    <option value="<?php

					if ( $class == 'cs_multi_select_tags' ) {
						echo esc_attr( $option_value );
					} else {
						echo esc_attr( $option_key );
					}

					?>"
						<?php

						if ( $class == 'cs_multi_select_tags' ) {
							if ( $option_value != 'null' ) {
								selected( in_array( $option_value, $selected ) );
							}
						} else {
							if ( $option_key != 'null' ) {
								selected( in_array( $option_key, $selected ) );
							}
						}

						?>
						<?php disabled( $option_key, 'disabled' ); ?>
                    >
						<?php echo esc_attr( $option_value ); ?>
                    </option>
				<?php } ?>
			<?php endforeach; ?>
		<?php } ?>
		<?php if ( $admin_check ) { ?>
            <option value="visitor">Visitor</option>
		<?php } ?>
    </select>

	<?php
}

function renderCSTypeOptions() {

	$options = array(
		'just_inform'         => esc_html__( 'Just inform', 'consent-magic' ),
		'ask_before_tracking' => esc_html__( 'Ask before tracking', 'consent-magic' ),
		'inform_and_opiout'   => esc_html__( 'Inform and Opt-out', 'consent-magic' )
	);

	return $options;
}

function renderCSTypeLocations() {

	$options = array(
		'AD' => array(
			__( 'Andorra', 'consent-magic' ),
			'GDPR'
		),
		'AF' => array(
			__( 'Afghanistan', 'consent-magic' ),
			'NONGDPR'
		),
		'AG' => array(
			__( 'Antigua and Barbuda', 'consent-magic' ),
			'NONGDPR'
		),
		'AI' => array(
			__( 'Anguilla', 'consent-magic' ),
			'NONGDPR'
		),
		'AL' => array(
			__( 'Albania', 'consent-magic' ),
			'NONGDPR'
		),
		'DZ' => array(
			__( 'Algeria', 'consent-magic' ),
			'NONGDPR'
		),
		'AM' => array(
			__( 'Armenia', 'consent-magic' ),
			'NONGDPR'
		),
		'AO' => array(
			__( 'Angola', 'consent-magic' ),
			'NONGDPR'
		),
		'AQ' => array(
			__( 'Antarctica', 'consent-magic' ),
			'NONGDPR'
		),
		'AR' => array(
			__( 'Argentina', 'consent-magic' ),
			'NONGDPR'
		),
		'AS' => array(
			__( 'American Samoa', 'consent-magic' ),
			'NONGDPR'
		),
		'AT' => array(
			__( 'Austria', 'consent-magic' ),
			'GDPR'
		),
		'AU' => array(
			__( 'Australia', 'consent-magic' ),
			'NONGDPR'
		),
		'AW' => array(
			__( 'Aruba', 'consent-magic' ),
			'NONGDPR'
		),
		'AX' => array(
			__( 'Åland Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'AZ' => array(
			__( 'Azerbaijan', 'consent-magic' ),
			'NONGDPR'
		),
		'BA' => array(
			__( 'Bosnia and Herzegovina', 'consent-magic' ),
			'NONGDPR'
		),
		'BB' => array(
			__( 'Barbados', 'consent-magic' ),
			'NONGDPR'
		),
		'BD' => array(
			__( 'Bangladesh', 'consent-magic' ),
			'NONGDPR'
		),
		'BE' => array(
			__( 'Belgium', 'consent-magic' ),
			'GDPR'
		),
		'BF' => array(
			__( 'Burkina Faso', 'consent-magic' ),
			'NONGDPR'
		),
		'BG' => array(
			__( 'Bulgaria', 'consent-magic' ),
			'GDPR'
		),
		'BH' => array(
			__( 'Bahrain', 'consent-magic' ),
			'NONGDPR'
		),
		'BI' => array(
			__( 'Burundi', 'consent-magic' ),
			'NONGDPR'
		),
		'BJ' => array(
			__( 'Benin', 'consent-magic' ),
			'NONGDPR'
		),
		'BL' => array(
			__( 'Saint Barthélemy', 'consent-magic' ),
			'NONGDPR'
		),
		'BM' => array(
			__( 'Bermuda', 'consent-magic' ),
			'NONGDPR'
		),
		'BN' => array(
			__( 'Brunei Darussalam', 'consent-magic' ),
			'NONGDPR'
		),
		'BO' => array(
			__( 'Bolivia (Plurinational State of)', 'consent-magic' ),
			'NONGDPR'
		),
		'BQ' => array(
			__( 'Bonaire, Sint Eustatius and Saba', 'consent-magic' ),
			'NONGDPR'
		),
		'BR' => array(
			__( 'Brazil', 'consent-magic' ),
			'NONGDPR'
		),
		'BS' => array(
			__( 'Bahamas', 'consent-magic' ),
			'NONGDPR'
		),
		'BT' => array(
			__( 'Bhutan', 'consent-magic' ),
			'NONGDPR'
		),
		'BV' => array(
			__( 'Bouvet Island', 'consent-magic' ),
			'NONGDPR'
		),
		'BW' => array(
			__( 'Botswana', 'consent-magic' ),
			'NONGDPR'
		),
		'BY' => array(
			__( 'Belarus', 'consent-magic' ),
			'NONGDPR'
		),
		'BZ' => array(
			__( 'Belize', 'consent-magic' ),
			'NONGDPR'
		),
		'CA' => array(
			__( 'Canada', 'consent-magic' ),
			'NONGDPR'
		),
		'CC' => array(
			__( 'Cocos (Keeling) Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'CD' => array(
			__( 'Congo, Democratic Republic of the', 'consent-magic' ),
			'NONGDPR'
		),
		'CF' => array(
			__( 'Central African Republic', 'consent-magic' ),
			'NONGDPR'
		),
		'CG' => array(
			__( 'Congo', 'consent-magic' ),
			'NONGDPR'
		),
		'CI' => array(
			__( "Côte d'Ivoire", 'consent-magic' ),
			'NONGDPR'
		),
		'CK' => array(
			__( 'Cook Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'CL' => array(
			__( 'Chile', 'consent-magic' ),
			'NONGDPR'
		),
		'CM' => array(
			__( 'Cameroon', 'consent-magic' ),
			'NONGDPR'
		),
		'CN' => array(
			__( 'China', 'consent-magic' ),
			'NONGDPR'
		),
		'CO' => array(
			__( 'Colombia', 'consent-magic' ),
			'NONGDPR'
		),
		'CR' => array(
			__( 'Costa Rica', 'consent-magic' ),
			'NONGDPR'
		),
		'CU' => array(
			__( 'Cuba', 'consent-magic' ),
			'NONGDPR'
		),
		'CV' => array(
			__( 'Cabo Verde', 'consent-magic' ),
			'NONGDPR'
		),
		'CW' => array(
			__( 'Curaçao', 'consent-magic' ),
			'NONGDPR'
		),
		'CX' => array(
			__( 'Christmas Island', 'consent-magic' ),
			'NONGDPR'
		),
		'CY' => array(
			__( 'Cyprus', 'consent-magic' ),
			'GDPR'
		),
		'HR' => array(
			__( 'Croatia', 'consent-magic' ),
			'NONGDPR'
		),
		'KH' => array(
			__( 'Cambodia', 'consent-magic' ),
			'NONGDPR'
		),
		'KM' => array(
			__( 'Comoros', 'consent-magic' ),
			'NONGDPR'
		),
		'TD' => array(
			__( 'Chad', 'consent-magic' ),
			'NONGDPR'
		),
		'CZ' => array(
			__( 'Czechia', 'consent-magic' ),
			'GDPR'
		),
		'KY' => array(
			__( 'Cayman Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'DJ' => array(
			__( 'Djibouti', 'consent-magic' ),
			'NONGDPR'
		),
		'DK' => array(
			__( 'Denmark', 'consent-magic' ),
			'GDPR'
		),
		'DM' => array(
			__( 'Dominica', 'consent-magic' ),
			'NONGDPR'
		),
		'DO' => array(
			__( 'Dominican Republic', 'consent-magic' ),
			'NONGDPR'
		),
		'EZ' => array(
			__( 'Ecuador', 'consent-magic' ),
			'NONGDPR'
		),
		'EE' => array(
			__( 'Estonia', 'consent-magic' ),
			'GDPR'
		),
		'SV' => array(
			__( 'El Salvador', 'consent-magic' ),
			'NONGDPR'
		),
		'SZ' => array(
			__( 'Eswatini', 'consent-magic' ),
			'NONGDPR'
		),
		'EG' => array(
			__( 'Egypt', 'consent-magic' ),
			'NONGDPR'
		),
		'ER' => array(
			__( 'Eritrea', 'consent-magic' ),
			'NONGDPR'
		),
		'GQ' => array(
			__( 'Equatorial Guinea', 'consent-magic' ),
			'NONGDPR'
		),
		'ET' => array(
			__( 'Ethiopia', 'consent-magic' ),
			'NONGDPR'
		),
		'FI' => array(
			__( 'Finland', 'consent-magic' ),
			'GDPR'
		),
		'FG' => array(
			__( 'Fiji', 'consent-magic' ),
			'NONGDPR'
		),
		'FK' => array(
			__( 'Falkland Islands (Malvinas)', 'consent-magic' ),
			'NONGDPR'
		),
		'FO' => array(
			__( 'Faroe Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'FR' => array(
			__( 'France', 'consent-magic' ),
			'GDPR'
		),
		'GF' => array(
			__( 'French Guiana', 'consent-magic' ),
			'NONGDPR'
		),
		'PF' => array(
			__( 'French Polynesia', 'consent-magic' ),
			'NONGDPR'
		),
		'TF' => array(
			__( 'French Southern Territories', 'consent-magic' ),
			'NONGDPR'
		),
		'DE' => array(
			__( 'Germany', 'consent-magic' ),
			'GDPR'
		),
		'GA' => array(
			__( 'Gabon', 'consent-magic' ),
			'NONGDPR'
		),
		'GD' => array(
			__( 'Grenada', 'consent-magic' ),
			'NONGDPR'
		),
		'GE' => array(
			__( 'Georgia', 'consent-magic' ),
			'NONGDPR'
		),
		'GG' => array(
			__( 'Guernsey', 'consent-magic' ),
			'NONGDPR'
		),
		'GH' => array(
			__( 'Ghana', 'consent-magic' ),
			'NONGDPR'
		),
		'GI' => array(
			__( 'Gibraltar', 'consent-magic' ),
			'NONGDPR'
		),
		'GL' => array(
			__( 'Greenland', 'consent-magic' ),
			'NONGDPR'
		),
		'GM' => array(
			__( 'Gambia', 'consent-magic' ),
			'NONGDPR'
		),
		'GN' => array(
			__( 'Guinea', 'consent-magic' ),
			'NONGDPR'
		),
		'GP' => array(
			__( 'Guadeloupe', 'consent-magic' ),
			'NONGDPR'
		),
		'GR' => array(
			__( 'Greece', 'consent-magic' ),
			'GDPR'
		),
		'GT' => array(
			__( 'Guatemala', 'consent-magic' ),
			'NONGDPR'
		),
		'GU' => array(
			__( 'Guam', 'consent-magic' ),
			'NONGDPR'
		),
		'GW' => array(
			__( 'Guinea-Bissau', 'consent-magic' ),
			'NONGDPR'
		),
		'GY' => array(
			__( 'Guyana', 'consent-magic' ),
			'NONGDPR'
		),
		'HK' => array(
			__( 'Hong Kong', 'consent-magic' ),
			'NONGDPR'
		),
		'VA' => array(
			__( 'Holy See', 'consent-magic' ),
			'NONGDPR'
		),
		'HM' => array(
			__( 'Heard Island and McDonald Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'HN' => array(
			__( 'Honduras', 'consent-magic' ),
			'NONGDPR'
		),
		'HT' => array(
			__( 'Haiti', 'consent-magic' ),
			'NONGDPR'
		),
		'HU' => array(
			__( 'Hungary', 'consent-magic' ),
			'GDPR'
		),
		'ID' => array(
			__( 'Indonesia', 'consent-magic' ),
			'NONGDPR'
		),
		'IE' => array(
			__( 'Ireland', 'consent-magic' ),
			'GDPR'
		),
		'IL' => array(
			__( 'Israel', 'consent-magic' ),
			'NONGDPR'
		),
		'IM' => array(
			__( 'Isle of Man', 'consent-magic' ),
			'NONGDPR'
		),
		'IN' => array(
			__( 'India', 'consent-magic' ),
			'NONGDPR'
		),
		'IO' => array(
			__( 'British Indian Ocean Territory', 'consent-magic' ),
			'NONGDPR'
		),
		'IQ' => array(
			__( 'Iraq', 'consent-magic' ),
			'NONGDPR'
		),
		'IR' => array(
			__( 'Iran (Islamic Republic of)', 'consent-magic' ),
			'NONGDPR'
		),
		'IS' => array(
			__( 'Iceland', 'consent-magic' ),
			'NONGDPR'
		),
		'IT' => array(
			__( 'Italy', 'consent-magic' ),
			'GDPR'
		),
		'JE' => array(
			__( 'Jersey', 'consent-magic' ),
			'NONGDPR'
		),
		'JM' => array(
			__( 'Jamaica', 'consent-magic' ),
			'NONGDPR'
		),
		'JO' => array(
			__( 'Jordan', 'consent-magic' ),
			'NONGDPR'
		),
		'JP' => array(
			__( 'Japan', 'consent-magic' ),
			'NONGDPR'
		),
		'KE' => array(
			__( 'Kenya', 'consent-magic' ),
			'NONGDPR'
		),
		'KG' => array(
			__( 'Kyrgyzstan', 'consent-magic' ),
			'NONGDPR'
		),
		'KI' => array(
			__( 'Kiribati', 'consent-magic' ),
			'NONGDPR'
		),
		'KN' => array(
			__( 'Saint Kitts and Nevis', 'consent-magic' ),
			'NONGDPR'
		),
		'KP' => array(
			__( "Korea (Democratic People's Republic of)", 'consent-magic' ),
			'NONGDPR'
		),
		'KR' => array(
			__( 'Korea, Republic of', 'consent-magic' ),
			'NONGDPR'
		),
		'KW' => array(
			__( 'Kuwait', 'consent-magic' ),
			'NONGDPR'
		),
		'KZ' => array(
			__( 'Kazakhstan', 'consent-magic' ),
			'NONGDPR'
		),
		'LA' => array(
			__( "Lao People's Democratic Republic", 'consent-magic' ),
			'NONGDPR'
		),
		'LB' => array(
			__( 'Lebanon', 'consent-magic' ),
			'NONGDPR'
		),
		'LI' => array(
			__( 'Liechtenstein', 'consent-magic' ),
			'NONGDPR'
		),
		'LR' => array(
			__( 'Liberia', 'consent-magic' ),
			'NONGDPR'
		),
		'LS' => array(
			__( 'Lesotho', 'consent-magic' ),
			'NONGDPR'
		),
		'LT' => array(
			__( 'Lithuania', 'consent-magic' ),
			'GDPR'
		),
		'LU' => array(
			__( 'Luxembourg', 'consent-magic' ),
			'GDPR'
		),
		'LV' => array(
			__( 'Latvia', 'consent-magic' ),
			'GDPR'
		),
		'LY' => array(
			__( 'Libya', 'consent-magic' ),
			'NONGDPR'
		),
		'MA' => array(
			__( 'Morocco', 'consent-magic' ),
			'NONGDPR'
		),
		'MC' => array(
			__( 'Monaco', 'consent-magic' ),
			'NONGDPR'
		),
		'MD' => array(
			__( 'Moldova, Republic of', 'consent-magic' ),
			'NONGDPR'
		),
		'ME' => array(
			__( 'Montenegro', 'consent-magic' ),
			'NONGDPR'
		),
		'MG' => array(
			__( 'Madagascar', 'consent-magic' ),
			'NONGDPR'
		),
		'MH' => array(
			__( 'Marshall Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'ML' => array(
			__( 'Mali', 'consent-magic' ),
			'NONGDPR'
		),
		'MM' => array(
			__( 'Myanmar', 'consent-magic' ),
			'NONGDPR'
		),
		'MN' => array(
			__( 'Mongolia', 'consent-magic' ),
			'NONGDPR'
		),
		'MO' => array(
			__( 'Macao', 'consent-magic' ),
			'NONGDPR'
		),
		'MQ' => array(
			__( 'Martinique', 'consent-magic' ),
			'NONGDPR'
		),
		'MR' => array(
			__( 'Mauritania', 'consent-magic' ),
			'NONGDPR'
		),
		'MS' => array(
			__( 'Montserrat', 'consent-magic' ),
			'NONGDPR'
		),
		'MT' => array(
			__( 'Malta', 'consent-magic' ),
			'GDPR'
		),
		'MU' => array(
			__( 'Mauritius', 'consent-magic' ),
			'NONGDPR'
		),
		'MV' => array(
			__( 'Maldives', 'consent-magic' ),
			'NONGDPR'
		),
		'MW' => array(
			__( 'Malawi', 'consent-magic' ),
			'NONGDPR'
		),
		'MX' => array(
			__( 'Mexico', 'consent-magic' ),
			'NONGDPR'
		),
		'MY' => array(
			__( 'Malaysia', 'consent-magic' ),
			'NONGDPR'
		),
		'FM' => array(
			__( 'Micronesia (Federated States of)', 'consent-magic' ),
			'NONGDPR'
		),
		'YT' => array(
			__( 'Mayotte', 'consent-magic' ),
			'NONGDPR'
		),
		'MZ' => array(
			__( 'Mozambique', 'consent-magic' ),
			'NONGDPR'
		),
		'NM' => array(
			__( 'Namibia', 'consent-magic' ),
			'NONGDPR'
		),
		'NC' => array(
			__( 'New Caledonia', 'consent-magic' ),
			'NONGDPR'
		),
		'NE' => array(
			__( 'Niger', 'consent-magic' ),
			'NONGDPR'
		),
		'NF' => array(
			__( 'Norfolk Island', 'consent-magic' ),
			'NONGDPR'
		),
		'NG' => array(
			__( 'Nigeria', 'consent-magic' ),
			'NONGDPR'
		),
		'NI' => array(
			__( 'Nicaragua', 'consent-magic' ),
			'NONGDPR'
		),
		'NL' => array(
			__( 'Netherlands', 'consent-magic' ),
			'GDPR'
		),
		'NO' => array(
			__( 'Norway', 'consent-magic' ),
			'GDPR'
		),
		'NP' => array(
			__( 'Nepal', 'consent-magic' ),
			'NONGDPR'
		),
		'NR' => array(
			__( 'Nauru', 'consent-magic' ),
			'NONGDPR'
		),
		'NU' => array(
			__( 'Niue', 'consent-magic' ),
			'NONGDPR'
		),
		'NZ' => array(
			__( 'New Zealand', 'consent-magic' ),
			'NONGDPR'
		),
		'MK' => array(
			__( 'North Macedonia', 'consent-magic' ),
			'NONGDPR'
		),
		'MP' => array(
			__( 'Northern Mariana Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'OM' => array(
			__( 'Oman', 'consent-magic' ),
			'NONGDPR'
		),
		'PA' => array(
			__( 'Panama', 'consent-magic' ),
			'NONGDPR'
		),
		'PE' => array(
			__( 'Peru', 'consent-magic' ),
			'NONGDPR'
		),
		'PG' => array(
			__( 'Papua New Guinea', 'consent-magic' ),
			'NONGDPR'
		),
		'PH' => array(
			__( 'Philippines', 'consent-magic' ),
			'NONGDPR'
		),
		'PK' => array(
			__( 'Pakistan', 'consent-magic' ),
			'NONGDPR'
		),
		'PL' => array(
			__( 'Poland', 'consent-magic' ),
			'GDPR'
		),
		'PN' => array(
			__( 'Pitcairn', 'consent-magic' ),
			'NONGDPR'
		),
		'PR' => array(
			__( 'Puerto Rico', 'consent-magic' ),
			'NONGDPR'
		),
		'PS' => array(
			__( 'Palestine, State of', 'consent-magic' ),
			'NONGDPR'
		),
		'PT' => array(
			__( 'Portugal', 'consent-magic' ),
			'GDPR'
		),
		'PW' => array(
			__( 'Palau', 'consent-magic' ),
			'NONGDPR'
		),
		'PY' => array(
			__( 'Paraguay', 'consent-magic' ),
			'NONGDPR'
		),
		'QA' => array(
			__( 'Qatar', 'consent-magic' ),
			'NONGDPR'
		),
		'RE' => array(
			__( "Réunion", 'consent-magic' ),
			'NONGDPR'
		),
		'RO' => array(
			__( 'Romania', 'consent-magic' ),
			'GDPR'
		),
		'RU' => array(
			__( 'Russian Federation', 'consent-magic' ),
			'NONGDPR'
		),
		'RW' => array(
			__( 'Rwanda', 'consent-magic' ),
			'NONGDPR'
		),
		'PM' => array(
			__( 'Saint Pierre and Miquelon', 'consent-magic' ),
			'NONGDPR'
		),
		'RS' => array(
			__( 'Serbia', 'consent-magic' ),
			'NONGDPR'
		),
		'SA' => array(
			__( 'Saudi Arabia', 'consent-magic' ),
			'NONGDPR'
		),
		'SB' => array(
			__( 'Solomon Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'SC' => array(
			__( 'Seychelles', 'consent-magic' ),
			'NONGDPR'
		),
		'SD' => array(
			__( 'Sudan', 'consent-magic' ),
			'NONGDPR'
		),
		'SE' => array(
			__( 'Sweden', 'consent-magic' ),
			'GDPR'
		),
		'SG' => array(
			__( 'Singapore', 'consent-magic' ),
			'NONGDPR'
		),
		'SH' => array(
			__( 'Saint Helena, Ascension and Tristan da Cunha', 'consent-magic' ),
			'NONGDPR'
		),
		'SI' => array(
			__( 'Slovenia', 'consent-magic' ),
			'GDPR'
		),
		'SJ' => array(
			__( 'Svalbard and Jan Mayen', 'consent-magic' ),
			'NONGDPR'
		),
		'SK' => array(
			__( 'Slovakia', 'consent-magic' ),
			'GDPR'
		),
		'SL' => array(
			__( 'Sierra Leone', 'consent-magic' ),
			'NONGDPR'
		),
		'SM' => array(
			__( 'San Marino', 'consent-magic' ),
			'NONGDPR'
		),
		'SN' => array(
			__( 'Senegal', 'consent-magic' ),
			'NONGDPR'
		),
		'SO' => array(
			__( 'Somalia', 'consent-magic' ),
			'NONGDPR'
		),
		'SR' => array(
			__( 'Suriname', 'consent-magic' ),
			'NONGDPR'
		),
		'SS' => array(
			__( 'South Sudan', 'consent-magic' ),
			'NONGDPR'
		),
		'ST' => array(
			__( 'Sao Tome and Principe', 'consent-magic' ),
			'NONGDPR'
		),
		'GS' => array(
			__( 'South Georgia and the South Sandwich Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'MF' => array(
			__( 'Saint Martin (French part)', 'consent-magic' ),
			'NONGDPR'
		),
		'ES' => array(
			__( 'Spain', 'consent-magic' ),
			'GDPR'
		),
		'CH' => array(
			__( 'Switzerland', 'consent-magic' ),
			'NONGDPR'
		),
		'LC' => array(
			__( 'Saint Lucia', 'consent-magic' ),
			'NONGDPR'
		),
		'LK' => array(
			__( 'Sri Lanka', 'consent-magic' ),
			'NONGDPR'
		),
		'SX' => array(
			__( 'Sint Maarten (Dutch part)', 'consent-magic' ),
			'NONGDPR'
		),
		'SY' => array(
			__( 'Syrian Arab Republic', 'consent-magic' ),
			'NONGDPR'
		),
		'VC' => array(
			__( 'Saint Vincent and the Grenadines', 'consent-magic' ),
			'NONGDPR'
		),
		'WS' => array(
			__( 'Samoa', 'consent-magic' ),
			'NONGDPR'
		),
		'ZA' => array(
			__( 'South Africa', 'consent-magic' ),
			'NONGDPR'
		),
		'TC' => array(
			__( 'Turks and Caicos Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'TG' => array(
			__( 'Togo', 'consent-magic' ),
			'NONGDPR'
		),
		'TH' => array(
			__( 'Thailand', 'consent-magic' ),
			'NONGDPR'
		),
		'TJ' => array(
			__( 'Tajikistan', 'consent-magic' ),
			'NONGDPR'
		),
		'TK' => array(
			__( 'Tokelau', 'consent-magic' ),
			'NONGDPR'
		),
		'TL' => array(
			__( 'Timor-Leste', 'consent-magic' ),
			'NONGDPR'
		),
		'TM' => array(
			__( 'Turkmenistan', 'consent-magic' ),
			'NONGDPR'
		),
		'TN' => array(
			__( 'Tunisia', 'consent-magic' ),
			'NONGDPR'
		),
		'TO' => array(
			__( 'Tonga', 'consent-magic' ),
			'NONGDPR'
		),
		'TR' => array(
			__( 'Turkey', 'consent-magic' ),
			'NONGDPR'
		),
		'TT' => array(
			__( 'Trinidad and Tobago', 'consent-magic' ),
			'NONGDPR'
		),
		'TV' => array(
			__( 'Tuvalu', 'consent-magic' ),
			'NONGDPR'
		),
		'TW' => array(
			__( 'Taiwan, Province of China', 'consent-magic' ),
			'NONGDPR'
		),
		'TZ' => array(
			__( 'Tanzania, United Republic of', 'consent-magic' ),
			'NONGDPR'
		),
		'UA' => array(
			__( 'Ukraine', 'consent-magic' ),
			'NONGDPR'
		),
		'UG' => array(
			__( 'Uganda', 'consent-magic' ),
			'NONGDPR'
		),
		'AE' => array(
			__( 'United Arab Emirates', 'consent-magic' ),
			'NONGDPR'
		),
		'UM' => array(
			__( 'United States Minor Outlying Islands', 'consent-magic' ),
			'NONGDPR'
		),
		'US' => array(
			__( 'United States of America', 'consent-magic' ),
			'NONGDPR'
		),
		'UY' => array(
			__( 'Uruguay', 'consent-magic' ),
			'NONGDPR'
		),
		'UZ' => array(
			__( 'Uzbekistan', 'consent-magic' ),
			'NONGDPR'
		),
		'GB' => array(
			__( 'United Kingdom of Great Britain and Northern Ireland', 'consent-magic' ),
			'GDPR'
		),
		'VE' => array(
			__( 'Venezuela (Bolivarian Republic of)', 'consent-magic' ),
			'NONGDPR'
		),
		'VG' => array(
			__( 'Virgin Islands (British)', 'consent-magic' ),
			'NONGDPR'
		),
		'VI' => array(
			__( 'Virgin Islands (U.S.)', 'consent-magic' ),
			'NONGDPR'
		),
		'VN' => array(
			__( 'Viet Nam', 'consent-magic' ),
			'NONGDPR'
		),
		'VU' => array(
			__( 'Vanuatu', 'consent-magic' ),
			'NONGDPR'
		),
		'EH' => array(
			__( 'Western Sahara', 'consent-magic' ),
			'NONGDPR'
		),
		'WF' => array(
			__( 'Wallis and Futuna', 'consent-magic' ),
			'NONGDPR'
		),
		'YE' => array(
			__( 'Yemen', 'consent-magic' ),
			'NONGDPR'
		),
		'ZM' => array(
			__( 'Zambia', 'consent-magic' ),
			'NONGDPR'
		),
		'ZW' => array(
			__( 'Zimbabwe', 'consent-magic' ),
			'NONGDPR'
		),
	);

	return $options;
}

function renderCSBarTypeOptions() {

	$options = array(
		'bar_small'   => 'Small bar',
		'bar_large'   => 'Large bar',
		'popup_small' => 'Small popup',
		'popup_large' => 'Large popup'
	);

	return $options;
}

function renderCSBarPositionOptions() {

	$options = array(
		'bottom' => 'Bottom',
		'top'    => 'Top'
	);

	return $options;
}

function renderUploadBtn( $id, $key ) {
	$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
	$attr_id = 'cs_' . $key;
	$img_id = get_post_meta( $id, 'cs_logo', true );
	$image = wp_get_attachment_image_src( $img_id, array(
		443,
		216
	) );
	if ( $img_id ) { ?>

        <div class="col-5 right-aligned">
            <a href="#" class="cs_img_upload btn btn-blue"><?php esc_html_e( 'Select', 'consent-magic' ); ?></a>
        </div>
        <div class="col-12">
            <div class="cs_logo_img_wrap">
                <p class="img_recommender"><?php esc_html_e( '500 kb max | JPEG, PNG', 'consent-magic' ); ?></p>
                <img src="<?php echo esc_url( $image[ 0 ] ); ?>" alt="img"/>
            </div>
            <input type="hidden" id="<?php echo esc_attr( $attr_id ); ?>" name="<?php echo esc_attr( $attr_name ); ?>"
                   value="<?php echo esc_attr( $img_id ); ?>">
            <a href="#" class="cs_img_upload_rmv btn-clear"
               style="display:block;"><?php esc_html_e( 'Remove image', 'consent-magic' ); ?></a>
        </div>

	<?php } else { ?>

        <div class="col-5 right-aligned">
            <a href="#" class="cs_img_upload btn btn-blue"><?php esc_html_e( 'Select', 'consent-magic' ); ?></a>
        </div>
        <div class="col-12">
            <div class="cs_logo_img_wrap">
                <p class="img_recommender"
                   style="display:none;"><?php esc_html_e( '500 kb max | JPEG, PNG', 'consent-magic' ); ?></p>
            </div>
            <input type="hidden" id="<?php echo esc_attr( $attr_id ); ?>" name="<?php echo esc_attr( $attr_name ); ?>"
                   value="">
            <a href="#" class="cs_img_upload_rmv btn-clear"
               style="display:none;"><?php esc_html_e( 'Remove image', 'consent-magic' ); ?></a>
        </div>
	<?php }
}

function renderSelectLanguages( $key = false, $key_field = false, $lang = CMPRO_DEFAULT_LANGUAGE, $id_rule = false, $data_render = false, $meta = false, $width = 'auto' ) {

	$attr_width = 'width:' . $width;

	if ( $key ) {
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";
	} elseif ( ( $key_field && $id_rule ) || ( $id_rule === null && $meta ) ) {
		$attr_name = $key . '_' . $lang;
	}

	$langs = get_language_list();

	?>
    <select class="form-control-lang" id="id-<?php echo uniqid() ?>"
            name="<?php echo esc_attr( $attr_name ?? null ); ?>"
            data-placeholder="<?php echo esc_html__( 'Select language', 'consent-magic' ) ?>"
            autocomplete="off" style="<?php esc_attr_e( $attr_width ); ?>"
            data-field="<?php echo esc_attr( $key_field ) ?>" data-rule="<?php echo esc_attr( $id_rule ) ?>"
            data-render="<?php echo esc_attr( $data_render ) ?>"
            data-option-type="<?php echo $meta ? 1 : 0 ?>"
            data-lang="<?php echo esc_attr( $lang ); ?>"
            data-plugin-name="<?php echo esc_attr( ConsentMagic()->get_plugin_name() ); ?>"">
	<?php foreach ( $langs as $lang_key => $lang_value ) : ?>
        <option data-pid="<?php echo esc_attr( $lang_key ); ?>"

                value="<?php echo esc_attr( $lang_key ); ?>" <?php selected( $lang, $lang_key ); ?>><?php echo esc_attr( $lang_value[ 1 ] ); ?></option>
	<?php endforeach; ?>
    </select>
	<?php
}


function renderSelectLanguagesNew( $key = false, $key_field = false, $id_rule = false, $data_render = false, $meta = false, $width = 'auto' ) {

	$attr_width = 'width:' . $width;

	$langs = get_language_list();

	?>
    <select class="form-control-lang-add"
            data-placeholder="<?php echo esc_html__( 'Select language', 'consent-magic' ) ?>"
            autocomplete="off" style="<?php esc_attr_e( $attr_width ); ?>"
            data-field="<?php echo esc_attr( $key_field ) ?>" data-rule="<?php echo esc_attr( $id_rule ) ?>"
            data-render="<?php echo esc_attr( $data_render ) ?>"
            data-option-type="<?php echo $meta ? 1 : 0 ?>"
            data-plugin-name="<?php echo esc_attr( ConsentMagic()->get_plugin_name() ); ?>"">
	<?php foreach ( $langs as $lang_key => $lang_value ) : ?>
        <option></option>
        <option data-pid="<?php echo esc_attr( $lang_key ); ?>"
                value="<?php echo esc_attr( $lang_key ); ?>"><?php echo esc_attr( $lang_value[ 1 ] ); ?></option>
	<?php endforeach; ?>
    </select>
	<?php
}

function renderSelectLanguagesByTermNew( $attr_name = null, $id = null, $class = '', $data_render = '', $width = 'auto' ) {

	$attr_width = 'width:' . $width;
	$langs = get_language_list();

	?>
    <select class="form-control-lang-add <?php echo esc_attr( $class ); ?>"
            data-placeholder="<?php echo esc_html__( 'Select language', 'consent-magic' ) ?>"
            name="<?php echo esc_attr( $attr_name ) . '_' . esc_attr( $id ); ?>" autocomplete="off"
            style="<?php esc_attr_e( $attr_width ); ?>"
            data-rule="<?php echo esc_attr( $id ) ?>" data-render="<?php echo esc_attr( $data_render ) ?>"
            data-option-type="1"
            data-field="<?php echo esc_attr( $attr_name ) ?>">
		<?php foreach ( $langs as $lang_key => $lang_value ) : ?>
            <option></option>
            <option data-pid="<?php echo esc_attr( $lang_key ); ?>"
                    value="<?php echo esc_attr( $lang_key ); ?>"><?php echo esc_attr( $lang_value[ 1 ] ); ?></option>
		<?php endforeach; ?>
    </select>
	<?php
}

function renderSelectLanguagesByTerm( $attr_name = null, $id = null, $lang = CMPRO_DEFAULT_LANGUAGE, $class = '', $width = 'auto' ) {
	$attr_width = 'width:' . $width;
	$langs = get_language_list();

	?>
    <select class="form-control-lang <?php echo esc_attr( $class ); ?>" id="id-<?php echo uniqid() ?>"
            name="<?php echo esc_attr( $attr_name ) . '_' . esc_attr( $id ); ?>" autocomplete="off"
            style="<?php esc_attr_e( $attr_width ); ?>"
            data-rule="<?php echo esc_attr( $id ) ?>"
            data-option-type="1"
            data-lang="<?php echo esc_attr( $lang ); ?>"
            data-field="<?php echo esc_attr( $attr_name ) ?>">
		<?php foreach ( $langs as $lang_key => $lang_value ) : ?>
            <option data-pid="<?php echo esc_attr( $lang_key ); ?>"
                    value="<?php echo esc_attr( $lang_key ); ?>" <?php selected( $lang, $lang_key ); ?>><?php echo esc_attr( $lang_value[ 1 ] ); ?></option>
		<?php endforeach; ?>
    </select>
	<?php
}

function renderLanguageOptions( $key, $lang, $meta = false, $id = null ) {

	if ( $lang === false ) {
		if ( get_option( $key ) ) {
			$attr_value = get_option( $key );
		} else {
			$attr_value = $meta ? get_post_meta( $id, $key, true ) : ConsentMagic()->getOption( $key );
		}

		$attr_id = 'cs_' . $key;
		$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key]";

	} else {
		if ( $meta ) {
			if ( $id != false ) {
				$attr_value_old = get_post_meta( $id, $key, true );

				if ( !empty( $attr_value_old ) ) {
					update_post_meta( $id, $key . '_' . CMPRO_DEFAULT_LANGUAGE, $attr_value_old );

					$old_langs = get_post_meta( $id, $key . '_lang', true );
					if ( !is_array( $old_langs ) ) {
						update_post_meta( $id, $key . '_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					}

					delete_post_meta( $id, $key );
					$attr_value = $attr_value_old;
				} else {
					$attr_value = get_post_meta( $id, $key . '_' . $lang, true );
				}
			} else {
				$attr_value = '';
			}

			$attr_name = $key . '_' . $lang;
		} else {
			$attr_value_old = ConsentMagic()->getOption( $key );

			if ( !empty( $attr_value_old ) ) {
				ConsentMagic()->updateLangOptions( array( $key . '_' . CMPRO_DEFAULT_LANGUAGE => $attr_value_old ), $lang );
				ConsentMagic()->updateLangOptions( array( $key . '_lang' => array( CMPRO_DEFAULT_LANGUAGE ) ), $lang );
				ConsentMagic()->updateOptions( array( $key => '' ) );

				$attr_value = $attr_value_old;
			} else {
				$attr_value = ConsentMagic()->getLangOption( $key, $lang );
			}

			$attr_name = "cs[" . ConsentMagic()->plugin_name . "][$key" . '_' . "$lang]";
		}

		$attr_id = $key . '_' . uniqid();
	}

	return array(
		'attr_value' => $attr_value,
		'attr_id'    => $attr_id,
		'attr_name'  => $attr_name
	);
}

function get_language_list() {
	return array(
		'af'             => array(
			0 => 'Afrikaans',
			1 => 'Afrikaans',
		),
		'am'             => array(
			0 => 'Amharic',
			1 => 'አማርኛ',
		),
		'ar'             => array(
			0 => 'Arabic',
			1 => 'العربية',
		),
		'ary'            => array(
			0 => 'Moroccan Arabic',
			1 => 'العربية المغربية',
		),
		'as'             => array(
			0 => 'Assamese',
			1 => 'অসমীয়া',
		),
		'azb'            => array(
			0 => 'South Azerbaijani',
			1 => 'گؤنئی آذربایجان',
		),
		'az'             => array(
			0 => 'Azerbaijani',
			1 => 'Azərbaycan dili',
		),
		'bel'            => array(
			0 => 'Belarusian',
			1 => 'Беларуская мова',
		),
		'bg_BG'          => array(
			0 => 'Bulgarian',
			1 => 'Български',
		),
		'bn_BD'          => array(
			0 => 'Bengali (Bangladesh)',
			1 => 'বাংলা',
		),
		'bo'             => array(
			0 => 'Tibetan',
			1 => 'བོད་ཡིག',
		),
		'bs_BA'          => array(
			0 => 'Bosnian',
			1 => 'Bosanski',
		),
		'ca'             => array(
			0 => 'Catalan',
			1 => 'Català',
		),
		'ceb'            => array(
			0 => 'Cebuano',
			1 => 'Cebuano',
		),
		'cs_CZ'          => array(
			0 => 'Czech',
			1 => 'Čeština',
		),
		'cy'             => array(
			0 => 'Welsh',
			1 => 'Cymraeg',
		),
		'da_DK'          => array(
			0 => 'Danish',
			1 => 'Dansk',
		),
		'de_CH_informal' => array(
			0 => 'German (Switzerland, Informal)',
			1 => 'Deutsch (Schweiz, Du)',
		),
		'de_AT'          => array(
			0 => 'German (Austria)',
			1 => 'Deutsch (Österreich)',
		),
		'de_DE_formal'   => array(
			0 => 'German (Formal)',
			1 => 'Deutsch (Sie)',
		),
		'de_DE'          => array(
			0 => 'German',
			1 => 'Deutsch',
		),
		'de_CH'          => array(
			0 => 'German (Switzerland)',
			1 => 'Deutsch (Schweiz)',
		),
		'dsb'            => array(
			0 => 'Lower Sorbian',
			1 => 'Dolnoserbšćina',
		),
		'dzo'            => array(
			0 => 'Dzongkha',
			1 => 'རྫོང་ཁ',
		),
		'el'             => array(
			0 => 'Greek',
			1 => 'Ελληνικά',
		),
		'en_ZA'          => array(
			0 => 'English (South Africa)',
			1 => 'English (South Africa)',
		),
		'en_CA'          => array(
			0 => 'English (Canada)',
			1 => 'English (Canada)',
		),
		'en_NZ'          => array(
			0 => 'English (New Zealand)',
			1 => 'English (New Zealand)',
		),
		'en_GB'          => array(
			0 => 'English (UK)',
			1 => 'English (UK)',
		),
		'en_AU'          => array(
			0 => 'English (Australia)',
			1 => 'English (Australia)',
		),
		'en_US'          => array(
			0 => 'English (United States)',
			1 => 'English (United States)',
		),
		'eo'             => array(
			0 => 'Esperanto',
			1 => 'Esperanto',
		),
		'es_EC'          => array(
			0 => 'Spanish (Ecuador)',
			1 => 'Español de Ecuador',
		),
		'es_AR'          => array(
			0 => 'Spanish (Argentina)',
			1 => 'Español de Argentina',
		),
		'es_CO'          => array(
			0 => 'Spanish (Colombia)',
			1 => 'Español de Colombia',
		),
		'es_MX'          => array(
			0 => 'Spanish (Mexico)',
			1 => 'Español de México',
		),
		'es_DO'          => array(
			0 => 'Spanish (Dominican Republic)',
			1 => 'Español de República Dominicana',
		),
		'es_PE'          => array(
			0 => 'Spanish (Peru)',
			1 => 'Español de Perú',
		),
		'es_UY'          => array(
			0 => 'Spanish (Uruguay)',
			1 => 'Español de Uruguay',
		),
		'es_CL'          => array(
			0 => 'Spanish (Chile)',
			1 => 'Español de Chile',
		),
		'es_PR'          => array(
			0 => 'Spanish (Puerto Rico)',
			1 => 'Español de Puerto Rico',
		),
		'es_VE'          => array(
			0 => 'Spanish (Venezuela)',
			1 => 'Español de Venezuela',
		),
		'es_GT'          => array(
			0 => 'Spanish (Guatemala)',
			1 => 'Español de Guatemala',
		),
		'es_ES'          => array(
			0 => 'Spanish (Spain)',
			1 => 'Español',
		),
		'es_CR'          => array(
			0 => 'Spanish (Costa Rica)',
			1 => 'Español de Costa Rica',
		),
		'et'             => array(
			0 => 'Estonian',
			1 => 'Eesti',
		),
		'eu'             => array(
			0 => 'Basque',
			1 => 'Euskara',
		),
		'fa_IR'          => array(
			0 => 'Persian',
			1 => 'فارسی',
		),
		'fa_AF'          => array(
			0 => 'Persian (Afghanistan)',
			1 => '(فارسی (افغانستان',
		),
		'fi'             => array(
			0 => 'Finnish',
			1 => 'Finnish',
		),
		'fr_CA'          => array(
			0 => 'French (Canada)',
			1 => 'Français du Canada',
		),
		'fr_FR'          => array(
			0 => 'French (France)',
			1 => 'Français',
		),
		'fr_BE'          => array(
			0 => 'French (Belgium)',
			1 => 'Français de Belgique',
		),
		'fr_CH'          => array(
			0 => 'French (Switzerland)',
			1 => 'Français de Switzerland',
		),
		'fur'            => array(
			0 => 'Friulian',
			1 => 'Friulian',
		),
		'ga_IE'          => array(
			0 => 'Irish',
			1 => 'Irish',
		),
		'gd'             => array(
			0 => 'Scottish Gaelic',
			1 => 'Gàidhlig',
		),
		'gl_ES'          => array(
			0 => 'Galician',
			1 => 'Galego',
		),
		'gu'             => array(
			0 => 'Gujarati',
			1 => 'ગુજરાતી',
		),
		'haz'            => array(
			0 => 'Hazaragi',
			1 => 'هزاره گی',
		),
		'he_IL'          => array(
			0 => 'Hebrew',
			1 => 'עִבְרִית',
		),
		'hi_IN'          => array(
			0 => 'Hindi',
			1 => 'हिन्दी',
		),
		'hr'             => array(
			0 => 'Croatian',
			1 => 'Hrvatski',
		),
		'hsb'            => array(
			0 => 'Upper Sorbian',
			1 => 'Hornjoserbšćina',
		),
		'hu_HU'          => array(
			0 => 'Hungarian',
			1 => 'Magyar',
		),
		'hy'             => array(
			0 => 'Armenian',
			1 => 'Հայերեն',
		),
		'id_ID'          => array(
			0 => 'Indonesian',
			1 => 'Bahasa Indonesia',
		),
		'is_IS'          => array(
			0 => 'Icelandic',
			1 => 'Íslenska',
		),
		'it_IT'          => array(
			0 => 'Italian',
			1 => 'Italiano',
		),
		'ja'             => array(
			0 => 'Japanese',
			1 => '日本語',
		),
		'jv_ID'          => array(
			0 => 'Javanese',
			1 => 'Basa Jawa',
		),
		'ka_GE'          => array(
			0 => 'Georgian',
			1 => 'ქართული',
		),
		'kab'            => array(
			0 => 'Kabyle',
			1 => 'Taqbaylit',
		),
		'kk'             => array(
			0 => 'Kazakh',
			1 => 'Қазақ тілі',
		),
		'km'             => array(
			0 => 'Khmer',
			1 => 'ភាសាខ្មែរ',
		),
		'kn'             => array(
			0 => 'Kannada',
			1 => 'ಕನ್ನಡ',
		),
		'ko_KR'          => array(
			0 => 'Korean',
			1 => '한국어',
		),
		'ckb'            => array(
			0 => 'Kurdish (Sorani)',
			1 => 'كوردی‎',
		),
		'lo'             => array(
			0 => 'Lao',
			1 => 'ພາສາລາວ',
		),
		'lt_LT'          => array(
			0 => 'Lithuanian',
			1 => 'Lietuvių kalba',
		),
		'lv'             => array(
			0 => 'Latvian',
			1 => 'Latviešu valoda',
		),
		'mk_MK'          => array(
			0 => 'Macedonian',
			1 => 'Македонски јазик',
		),
		'ml_IN'          => array(
			0 => 'Malayalam',
			1 => 'മലയാളം',
		),
		'mn'             => array(
			0 => 'Mongolian',
			1 => 'Монгол',
		),
		'mr'             => array(
			0 => 'Marathi',
			1 => 'मराठी',
		),
		'mt'             => array(
			0 => 'Maltese',
			1 => 'Maltese',
		),
		'ms_MY'          => array(
			0 => 'Malay',
			1 => 'Bahasa Melayu',
		),
		'my_MM'          => array(
			0 => 'Myanmar (Burmese)',
			1 => 'ဗမာစာ',
		),
		'nb_NO'          => array(
			0 => 'Norwegian (Bokmål)',
			1 => 'Norsk bokmål',
		),
		'ne_NP'          => array(
			0 => 'Nepali',
			1 => 'नेपाली',
		),
		'nl_NL_formal'   => array(
			0 => 'Dutch (Formal)',
			1 => 'Nederlands (Formeel)',
		),
		'nl_BE'          => array(
			0 => 'Dutch (Belgium)',
			1 => 'Nederlands (België)',
		),
		'nl_NL'          => array(
			0 => 'Dutch',
			1 => 'Nederlands',
		),
		'nn_NO'          => array(
			0 => 'Norwegian (Nynorsk)',
			1 => 'Norsk nynorsk',
		),
		'oci'            => array(
			0 => 'Occitan',
			1 => 'Occitan',
		),
		'pa_IN'          => array(
			0 => 'Punjabi',
			1 => 'ਪੰਜਾਬੀ',
		),
		'pl_PL'          => array(
			0 => 'Polish',
			1 => 'Polski',
		),
		'ps'             => array(
			0 => 'Pashto',
			1 => 'پښتو',
		),
		'pt_PT'          => array(
			0 => 'Portuguese (Portugal)',
			1 => 'Português',
		),
		'pt_AO'          => array(
			0 => 'Portuguese (Angola)',
			1 => 'Português de Angola',
		),
		'pt_PT_ao90'     => array(
			0 => 'Portuguese (Portugal, AO90)',
			1 => 'Português (AO90)',
		),
		'pt_BR'          => array(
			0 => 'Portuguese (Brazil)',
			1 => 'Português do Brasil',
		),
		'rhg'            => array(
			0 => 'Rohingya',
			1 => 'Ruáinga',
		),
		'ro_RO'          => array(
			0 => 'Romanian',
			1 => 'Română',
		),
		'ru_RU'          => array(
			0 => 'Russian',
			1 => 'Русский',
		),
		'sah'            => array(
			0 => 'Sakha',
			1 => 'Сахалыы',
		),
		'snd'            => array(
			0 => 'Sindhi',
			1 => 'سنڌي',
		),
		'si_LK'          => array(
			0 => 'Sinhala',
			1 => 'සිංහල',
		),
		'sk_SK'          => array(
			0 => 'Slovak',
			1 => 'Slovenčina',
		),
		'skr'            => array(
			0 => 'Saraiki',
			1 => 'سرائیکی',
		),
		'sl_SI'          => array(
			0 => 'Slovenian',
			1 => 'Slovenščina',
		),
		'sq'             => array(
			0 => 'Albanian',
			1 => 'Shqip',
		),
		'sr_RS'          => array(
			0 => 'Serbian',
			1 => 'Српски језик',
		),
		'sv_SE'          => array(
			0 => 'Swedish',
			1 => 'Svenska',
		),
		'sw'             => array(
			0 => 'Swahili',
			1 => 'Kiswahili',
		),
		'szl'            => array(
			0 => 'Silesian',
			1 => 'Ślōnskŏ gŏdka',
		),
		'ta_IN'          => array(
			0 => 'Tamil',
			1 => 'தமிழ்',
		),
		'ta_LK'          => array(
			0 => 'Tamil (Sri Lanka)',
			1 => 'தமிழ்',
		),
		'te'             => array(
			0 => 'Telugu',
			1 => 'తెలుగు',
		),
		'th'             => array(
			0 => 'Thai',
			1 => 'ไทย',
		),
		'tl'             => array(
			0 => 'Tagalog',
			1 => 'Tagalog',
		),
		'tr_TR'          => array(
			0 => 'Turkish',
			1 => 'Türkçe',
		),
		'tt_RU'          => array(
			0 => 'Tatar',
			1 => 'Татар теле',
		),
		'tah'            => array(
			0 => 'Tahitian',
			1 => 'Reo Tahiti',
		),
		'ug_CN'          => array(
			0 => 'Uighur',
			1 => 'ئۇيغۇرچە',
		),
		'uk'             => array(
			0 => 'Ukrainian',
			1 => 'Українська',
		),
		'ur'             => array(
			0 => 'Urdu',
			1 => 'اردو',
		),
		'uz_UZ'          => array(
			0 => 'Uzbek',
			1 => 'O‘zbekcha',
		),
		'vi'             => array(
			0 => 'Vietnamese',
			1 => 'Tiếng Việt',
		),
		'zh_HK'          => array(
			0 => 'Chinese (Hong Kong)',
			1 => '香港中文版	',
		),
		'zh_TW'          => array(
			0 => 'Chinese (Taiwan)',
			1 => '繁體中文',
		),
		'zh_CN'          => array(
			0 => 'Chinese (China)',
			1 => '简体中文',
		)
	);
}

function get_lang_meta_list() {
	return array(
		'_cs_text_in_small_bar_popup',
		'_cs_text_in_large_bar_popup',
		'_cs_btn_text_allow_all',
		'_cs_btn_text_disable_all',
		'_cs_btn_text_customize',
		'_cs_btn_text_privacy_cookie',
		'_cs_btn_text_sticky_cookie',
		'_cs_btn_text_custom_button',
		'_cs_text_in_options_popup',
		'_cs_title_in_options_popup',
		'_cs_subtitle_in_options_popup',
		'_cs_btn_text_allow_all_in_options_popup',
		'_cs_btn_text_disable_all_in_options_popup',
		'_cs_btn_text_confirm_in_options_popup',
		'_cs_always_on_in_options_popup',
	);
}

//update options in WP DB if options not isset
function update_cat_id_options( $option = 'all' ) {

	if ( $option != 'all' ) {
		$term = get_term_by( 'slug', str_replace( '_cat_id', '', $option ), 'cs-cookies-category' );

		if ( $term != false && !empty( $term ) ) {
			update_option( $option, $term->term_id );
			return $term->term_id;
		}
	} else {
		$cat_id_options = array(
			'embedded_video_cat_id' => '',
			'unassigned_cat_id'     => '',
			'googlefonts_cat_id'    => '',
			'marketing_cat_id'      => '',
			'analytics_cat_id'      => '',
			'necessary_cat_id'      => '',
		);

		foreach ( $cat_id_options as $key => $cat_id_option ) {
			$term = get_term_by( 'slug', str_replace( '_cat_id', '', $cat_id_option ), 'cs-cookies-category' );
			if ( $term != false && !empty( $term ) ) {
				update_option( $option, $term->term_id );
				$cat_id_options[ $key ] = $term->term_id;
			}
		}

		return $cat_id_options;
	}
}

// get all default pre-defined categories
function get_default_categories() {
	return array(
		'necessary',
		'analytics',
		'marketing',
		'googlefonts',
		'unassigned',
		'embedded_video'
	);
}

function get_predefined_script_pattern() {
	return array(
		'Hotjar'                    => array(
			'option_key' => 'hotjar',
			'cat_key'    => 'cs_block_hotjar_scripts_cat',
			'script'     => 'hotjar'
		),
		'Instagram'                 => array(
			'option_key' => 'instagram',
			'cat_key'    => 'cs_block_instagram_scripts_cat',
			'script'     => 'instagram'
		),
		'Facebook Pixel'            => array(
			'option_key' => 'fb_pixel',
			'cat_key'    => 'cs_block_fb_pixel_scripts_cat',
			'script'     => 'fb_pixel'
		),
		'Google Analytics'          => array(
			'option_key' => 'google_analytics',
			'cat_key'    => 'cs_block_google_analytics_scripts_cat',
			'script'     => 'google_analytics'
		),
		'Google Publisher Tag'      => array(
			'option_key' => 'google_ads_tag',
			'cat_key'    => 'cs_block_google_tag_manager_scripts_cat',
			'script'     => 'google_ads_tag'
		),
		'Google Adsense'            => array(
			'option_key' => 'google_adsense',
			'cat_key'    => 'cs_block_google_adsense_scripts_cat',
			'script'     => 'google_adsense'
		),
		'Google maps'               => array(
			'option_key' => 'google_maps',
			'cat_key'    => 'cs_block_google_maps_scripts_cat',
			'script'     => 'google_maps'
		),
		'Google fonts'              => array(
			'option_key' => 'googlefonts',
			'cat_key'    => 'cs_block_googlefonts_scripts_cat',
			'script'     => 'googlefonts'
		),
		'Twitter widget'            => array(
			'option_key' => 'tw_tag',
			'cat_key'    => 'cs_block_tw_tag_scripts_cat',
			'script'     => 'tw_tag'
		),
		'Twitter Pixel'             => array(
			'option_key' => 'twitter',
			'cat_key'    => 'cs_block_twitter_scripts_cat',
			'script'     => 'twitter'
		),
		'Bing Tag'                  => array(
			'option_key' => 'big_tag',
			'cat_key'    => 'cs_block_big_tag_scripts_cat',
			'script'     => 'big_tag'
		),
		'Linkedin widget/Analytics' => array(
			'option_key' => 'ln_tag',
			'cat_key'    => 'cs_block_ln_tag_scripts_cat',
			'script'     => 'ln_tag'
		),
		'Pinterest widget'          => array(
			'option_key' => 'pin_tag',
			'cat_key'    => 'cs_block_pin_tag_scripts_cat',
			'script'     => 'pin_tag'
		),
		'Youtube embed'             => array(
			'option_key' => 'yt_embedded',
			'cat_key'    => 'cs_block_yt_embedded_scripts_cat',
			'script'     => 'yt_embedded'
		),
		'Vimeo embed'               => array(
			'option_key' => 'vimeo_embedded',
			'cat_key'    => 'cs_block_vimeo_embedded_scripts_cat',
			'script'     => 'vimeo_embedded'
		),
		'Hubspot Analytics'         => array(
			'option_key' => 'hubspot',
			'cat_key'    => 'cs_block_hubspot_scripts_cat',
			'script'     => 'hubspot'
		),
		'Matomo Analytics'          => array(
			'option_key' => 'matomo',
			'cat_key'    => 'cs_block_matomo_scripts_cat',
			'script'     => 'matomo'
		),
		'Addthis widget'            => array(
			'option_key' => 'addthis',
			'cat_key'    => 'cs_block_addthis_scripts_cat',
			'script'     => 'addthis'
		),
		'Sharethis widget'          => array(
			'option_key' => 'sharethis',
			'cat_key'    => 'cs_block_sharethis_scripts_cat',
			'script'     => 'sharethis'
		),
		'Soundcloud embed'          => array(
			'option_key' => 'soundcloud',
			'cat_key'    => 'cs_block_soundcloud_scripts_cat',
			'script'     => 'soundcloud'
		),
		'Slideshare embed'          => array(
			'option_key' => 'slideshare',
			'cat_key'    => 'cs_block_slideshare_scripts_cat',
			'script'     => 'slideshare'
		),
		'Tik-tok pixel'             => array(
			'option_key' => 'tiktok',
			'cat_key'    => 'cs_block_tiktok_scripts_cat',
			'script'     => 'tiktok'
		)
	);
}

function get_general_language( $current_lang ) {

	$current_lang = preg_replace('/_.*$/', '', $current_lang);

    switch ($current_lang) {
        case 'en':
			$general_lang = 'en_US';
            break;
		case 'bg':
			$general_lang = 'bg_BG';
			break;
		case 'cs':
			$general_lang = 'cs_CZ';
			break;
		case 'da':
			$general_lang = 'da_DK';
			break;
		case 'de':
			$general_lang = 'de_DE';
			break;
		case 'el':
			$general_lang = 'el';
			break;
		case 'es':
			$general_lang = 'es_ES';
			break;
		case 'et':
			$general_lang = 'et';
			break;
		case 'fi':
			$general_lang = 'fi';
			break;
		case 'fr':
			$general_lang = 'fr_FR';
			break;
		case 'ga':
			$general_lang = 'ga_IE';
			break;
		case 'hr':
			$general_lang = 'hr';
			break;
		case 'hu':
			$general_lang = 'hu_HU';
			break;
		case 'it':
			$general_lang = 'it_IT';
			break;
		case 'lt':
			$general_lang = 'lt_LT';
			break;
		case 'lv':
			$general_lang = 'lv';
			break;
		case 'mt':
			$general_lang = 'mt';
			break;
		case 'nl':
			$general_lang = 'nl_NL';
			break;
		case 'pl':
			$general_lang = 'pl_PL';
			break;
		case 'pt':
			$general_lang = 'pt_PT';
			break;
		case 'ro':
			$general_lang = 'ro';
			break;
		case 'sk':
			$general_lang = 'sk';
			break;
		case 'sl':
			$general_lang = 'sl_SI';
			break;
		case 'sv':
			$general_lang = 'sv_SE';
			break;
		case 'uk':
			$general_lang = 'uk';
			break;
        default:
			$general_lang = $current_lang;
    }

	return $general_lang;
}