( function ( $ ) {
    'use strict';

    /**
     * All of the code for your admin-facing JavaScript source
     * should reside in this file.
     *
     * Note: It has been assumed you will write jQuery code here, so the
     * $ function reference has been prepared for usage within the scope
     * of this function.
     *
     * This enables you to define handlers, for when the DOM is ready:
     *
     * $(function() {
     *
     * });
     *
     * When the window is loaded:
     *
     * $( window ).load(function() {
     *
     * });
     *
     * ...and/or other possibilities.
     *
     * Ideally, it is not considered best practise to attach more than a
     * single DOM-ready or window-load handler for a particular page.
     * Although scripts in the WordPress core, Plugins and Themes may be
     * practising this, we should strive to set a better example in our own work.
     */
    $( function () {

        var cs_settings_form = $( '#cs_settings_form' ),
            cs_step_form = $( '#cs_step_form' ),
            step_url = cs_step_form.attr( 'action' ),
            cs_design_form = $( '#cs_design_form' ),
            cs_script_form = $( '#cs_script_form' ),
            cs_cookie_form = $( '#cs_cookie_form' ),
            cs_new_rule_form = $( '#cs_new_rule_form' ),
            cs_settings_tab_form = $( '#cs_settings_tab_form' ),
            url = cs_settings_form.attr( 'action' ),
            cs_nav_tab = $( '.nav-tab' ),
            link_to_nav = $( '.link-to-nav-tab' ),
            switcher = $( '.custom-switch-input' ),
            select_target = $( '#_cs_target' ),
            select_term_lang = $( '.form-control-term-lang' ),
            wpnonce = $( '#_wpnonce' ).val();

        $( ".portlet_column" ).sortable( {
            connectWith: ".portlet_column",
            handle: ".portlet-header",
            cancel: ".portlet-toggle",
            placeholder: "ui-state-highlight",
        } );

        $( ".portlet" )
            .addClass( "ui-widget ui-widget-content ui-helper-clearfix ui-corner-all" )
            .find( ".portlet-header" )
            .addClass( "ui-widget-header ui-corner-all" )
            .prepend( "<span class='icon-down btn btn-link portlet-toggle'></span>" );

        $( ".portlet-toggle" ).on( "click", function () {
            var icon = $( this );
            icon.toggleClass( "icon-down icon-up-arrow" );
            icon.closest( ".portlet" ).find( ".portlet-content" ).toggle();
        } );

        var itemList = $( ".portlet_column" );
        itemList.sortable( {
            update: function ( event, ui ) {
                $.ajax( {
                    url: ajax_object.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'item_sort',
                        order: itemList.sortable( 'toArray' ).toString(), // Passes ID's of list items in  1,3,2 format
                        _wpnonce: wpnonce
                    },
                    success: function ( response ) {
                        if ( !response.success ) {
                            console.log( 'There was an error saving the updates' );
                        }
                    }
                } );
            },
            change: function ( event, ui ) {
                $.ajax( {
                    url: ajax_object.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'item_sort', // Tell WordPress how to handle this ajax request
                        order: itemList.sortable( 'toArray' ).toString(), // Passes ID's of list items in  1,3,2 format
                        _wpnonce: wpnonce
                    },
                    success: function ( response ) {
                        if ( !response.success ) {
                            console.log( 'There was an error saving the updates' );
                        }
                    }
                } );
            }
        } );

        $( 'select' ).cs_select2();

        //Target matcher function for search countries
        function target_matcher( params, data ) {
            let search = $.trim( params.term ).toLowerCase();

            if ( search === '' ) {
                $( '.cs_select2-results__options' ).removeClass( 'cs_select2-results__searched' );
                return data;
            } else {
                $( '.cs_select2-results__options' ).addClass( 'cs_select2-results__searched' );
                let name = data.text.toLowerCase();
                if ( data.id === 'GDPR' || data.id === 'NONGDPR' || data.id === 'CCPA' ) {
                    return null;
                }

                if ( name.indexOf( search ) > -1 ) {
                    return data;
                }
            }
            return null;
        }

        select_target.cs_select2( {
            closeOnSelect: false,
            dropdownCssClass: "cs_location",
            allowClear: false,
            matcher: target_matcher,

        } ).on( 'cs_select2:open', () => {
            $( '.cs_select2-search__field' ).attr( 'placeholder', 'Click to hide locations list' );
            $( ".cs_select2-results:not(:has(a))" ).prepend( '<div class="cs_options_button_group">' +
                '<a href="#" class="selectAll">Select All</a>' +
                '<a href="#" class="clearAll">Clear All</a>' +
                '</div>' );
        } ).on( 'cs_select2:close', ( e ) => {
            $( '.cs_select2-search__field' ).attr( 'placeholder', 'Click to show locations list' );
        } ).on( 'cs_select2:select', function ( e ) {
            var $select = $( this );
            var data = e.params.data;
            var pid = data.element.attributes[ 0 ].value;
            if ( data.id == 'CCPA' || data.id == 'GDPR' || data.id == 'NONGDPR' ) {
                $select.find( 'option' ).prop( 'disabled', false ).prop( 'selected', false ).trigger( "change" );
                $select.cs_select2( 'destroy' ).find( 'option' ).prop( 'disabled', false ).prop( 'selected', false ).end().cs_select2( {
                    closeOnSelect: false,
                    dropdownCssClass: "cs_location",
                    allowClear: false,
                    matcher: target_matcher,
                } );
                if ( data.id == 'CCPA' ) {
                    $select.val( [ "CCPA" ] ).find( 'option:selected' ).prop( 'disabled', true ).trigger( "change" );
                }
                if ( data.id == 'GDPR' || data.id == 'NONGDPR' ) {
                    var childIds = $.grep( e.target.options, function ( option ) {
                        return $( option ).data( 'pid' ) == pid;
                    } );
                    childIds = $.map( childIds, function ( option ) {
                        return option.value;
                    } );

                    $select.val( data.id );

                    $select.val( $select.cs_select2( 'val' ).concat( childIds ) ).find( 'option:selected' ).prop( 'disabled', true ).trigger( "change" );
                    $select.trigger( "change" );
                }
                $select.cs_select2( "open" );
            }
        } );

        $( '.cs_select2-search__field' ).attr( 'placeholder', 'Click to show locations list' );

        $( document ).on( 'click', '.clearAll', function ( e ) {
            $( this ).addClass( 'active' );
            select_target.cs_select2( 'destroy' ).find( 'option' ).prop( 'disabled', false ).prop( 'selected', false ).end().cs_select2( {
                closeOnSelect: false,
                dropdownCssClass: "cs_location",
                allowClear: false,
                matcher: target_matcher,
            } );
            select_target.cs_select2( "open" );
        } );

        select_target.on( 'cs_select2:clear', function ( e ) {
            $( '.selectGDPR, .selectnonGDPR' ).removeClass( 'active' );
            $( "#_cs_target option" ).each( function () {
                $( this ).prop( 'disabled', false );
                $( this ).prop( 'selected', false );
            } );
        } );

        $( document ).on( 'click', '.selectAll', function ( e ) {
            select_target.cs_select2( 'destroy' ).find( 'option' ).prop( 'selected', 'selected' ).end().cs_select2( {
                closeOnSelect: false,
                dropdownCssClass: "cs_location",
                allowClear: false,
                matcher: target_matcher,
            } );
            $( '.selectAll' ).addClass( 'active' );
            select_target.cs_select2( "open" );
        } );

        switcher.on( 'click', function () {
            if ( $( this ).is( ':checked' ) ) {
                $( this ).closest( '.custom-switch__parent_wrap' ).removeClass( 'not-active' );
                $( this ).closest( '.scripts-list-item' ).removeClass( 'not-active' );
            } else {
                $( this ).closest( '.custom-switch__parent_wrap' ).addClass( 'not-active' );
                $( this ).closest( '.scripts-list-item' ).addClass( 'not-active' );
            }
        } );

        $( '.js-control .custom-switch-input' ).on( 'change', function () {
            var active = 0;
            var status = 'draft';
            if ( $( this ).is( ':checked' ) ) {
                active = 1;
                status = 'publish';
            }
            var parent = $( this ).closest( '.js-control' ),
                id = parent.data( 'id' );
            if ( status == 'publish' ) {
                $( this ).closest( '.rules-wrap' ).removeClass( 'draft' );
            } else {
                $( this ).closest( '.rules-wrap' ).addClass( 'draft' );
            }

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'predefined_rule_enable_update',
                    id: id,
                    active: active,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    console.log( 'rule updated', response.data );
                    $.ajax( {
                        url: ajax_object.ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'item_sort', // Tell WordPress how to handle this ajax request
                            order: itemList.sortable( 'toArray' ).toString(), // Passes ID's of list items in  1,3,2 format
                            _wpnonce: wpnonce
                        },
                        success: function ( response ) {
                            if ( !response.success ) {
                                console.log( 'There was an error saving the updates' );
                            }
                        }
                    } );
                },
                error: function () {  // This can be expanded to provide more information
                    console.log( 'There was an error saving the updates' );
                }
            } );
        } );

        $( '.js-ip-rule-control .custom-switch-input' ).on( 'change', function () {
            var active = 0;
            if ( $( this ).is( ':checked' ) ) {
                active = 1;
            }
            var parent = $( this ).closest( '.js-ip-rule-control' ),
                id = parent.data( 'id' );

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'no_ip_rule_update',
                    id: id,
                    active: active,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    console.log( 'rule updated', response.data );
                },
                error: function () {  // This can be expanded to provide more information
                    console.log( 'There was an error saving the updates' );
                }
            } );
        } );

        // Export
        $( '.export_proof_consent' ).on( 'click', function ( e ) {
            e.preventDefault();
            cs_export_proof_consent();
        } );

        // Export
        $( '.export_proof_consent_popup' ).on( 'click', function ( e ) {
            e.preventDefault();
            cs_export_proof_consent( true );
        } );

        function cs_export_proof_consent( submit = false, limit, offset ) {
            if ( typeof ( offset ) === 'undefined' ) offset = 0;
            if ( typeof ( limit ) === 'undefined' ) limit = 'undefined';
            var post_data = {
                'limit': limit,
                'offset': offset,
                'submit': submit,
                nonce_code: ajax_object.nonce,
                action: 'cs_export_proof_consent'
            };
            if ( offset == 0 )
                $( '.popup' ).html( '<div class="msg">Export processing...</div>' ).show();
            $.ajax( {
                type: "POST",
                data: post_data,
                url: ajax_object.ajaxurl,
                success: function ( response ) {
                    console.log( 'Processing, do not cancel' );
                    if ( response.loop == 1 ) {
                        cs_export_proof_consent( submit, response.limit, response.offset );
                        $( '.popup' ).addClass( 'success' ).html( '<div class="msg">Exported ' + response.offset + ' items</div>' );
                    }
                    if ( response.loop == 0 ) {
                        $( '.popup' ).addClass( 'success' ).html( '<div class="msg">Exported completed</div>' );
                        var valFileDownloadPath = response.file_url;
                        window.open( valFileDownloadPath, '_blank' );
                        if ( $( '.cs_delete_proof_consent_wrap' ).length > 0 ) {
                            $( '.cs_delete_proof_consent_wrap' ).hide();
                        }

                        $.ajax( {
                            url: ajax_object.ajaxurl,
                            type: 'POST',
                            data: {
                                action: 'cs_export_proof_consent_done',
                                nonce_code: ajax_object.nonce
                            },
                            error: function ( response ) {
                                console.log( 'ERROR' );
                                console.log( response );
                            }
                        } )
                    }
                },
                error: function ( response ) {
                    console.log( 'ERROR' );
                    console.log( response );
                    $( '.popup' ).addClass( 'error' ).html( '<div class="msg">Oops, something wrong</div>' ).show();
                    setTimeout( function () {
                        $( '.popup' ).removeClass( 'error' ).hide();
                    }, 1500 );
                }
            } );
        }

        $( '.color-field' ).wpColorPicker();

        $( '.card-collapse' ).on( 'click', function () {
            var e = $( this ).closest( ".card" ).find( ".card-body" );
            var i = $( this ).find( "i" );
            e.hasClass( "show" ) ? e.hide().removeClass( "show" ) : e.show().addClass( "show" );
            i.hasClass( "icon-up-arrow" ) ? i.removeClass( "icon-up-arrow" ).addClass( "icon-down" ) : i.removeClass( "icon-down" ).addClass( "icon-up-arrow" );
        } );

        $( '.sub-card-collapse' ).on( 'click', function () {
            var e = $( this ).closest( ".sub-card" ).find( ".sub-card-body" );
            var i = $( this ).find( "i" );
            e.hasClass( "show" ) ? e.hide().removeClass( "show" ) : e.show().addClass( "show" );
            i.hasClass( "icon-up-arrow" ) ? i.removeClass( "icon-up-arrow" ).addClass( "icon-down" ) : i.removeClass( "icon-down" ).addClass( "icon-up-arrow" );
        } );

        $( document ).on( 'click', '.cs-modal-close, .preview_wrap .cs_popup_overlay, .preview_wrap .cs_action_btn', function () {
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' );
            jQuery( 'body' ).removeClass( "cs-barmodal-open" );
            popup.find( '.cs_settings_popup' ).removeClass( 'cs-show cs-blowup' );
            popup.find( '.cs_settings_popup' ).addClass( 'cs-out' );
            jQuery( 'body' ).removeClass( "cs-modal-open" );
            popup.find( ".cs-settings-overlay" ).removeClass( "cs-show" );
            popup.find( ".cs-popupbar-overlay" ).removeClass( "cs-show" );

            let info_bar = popup.find( ".cs-info-bar" );
            info_bar.css( 'opacity', 0 );
            info_bar.css( 'display', 'none' );
            popup.hide();

            let overlay = $( '.preview_wrap .cs_popup_overlay' );
            overlay.css( 'visibility', 'hidden' );
            overlay.css( 'opacity', 0 );
        } );

        jQuery( document ).on( 'click', '.options_btn', function ( e ) {
            e.preventDefault();
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' );
            if ( !popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                jQuery( 'body' ).addClass( "cs-barmodal-open" );
            }
            popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
            popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
            jQuery( 'body' ).addClass( "cs-modal-open" );
            popup.find( ".cs-settings-overlay" ).addClass( "cs-show" );
            popup.find( ".cs-info-bar" ).hide();
        } );

        $( '.btn_next_step' ).on( 'click', function () {
            var that = $( this );
            var next = that.closest( '.steps-wrap' ).next();
            that.closest( '.steps-wrap' ).hide();
            next.fadeIn();
        } );

        $( '.btn_second_step' ).on( 'click', function () {
            var that = $( this );
            var next = $( '#cs_step_form' );
            that.closest( '.steps-wrap' ).hide();
            next.fadeIn();
        } );

        $( '.btn_prev_second_step' ).on( 'click', function () {
            var prev = $( '.cs_settings_form' );
            $( '#cs_step_form' ).hide();
            prev.fadeIn();
        } );

        $( '.btn_prev_step' ).on( 'click', function () {
            var that = $( this );
            var prev = that.closest( '.steps-wrap' ).prev();
            that.closest( '.steps-wrap' ).hide();
            prev.fadeIn();
        } );

        $( '.delete_custom_post' ).on( 'click', function ( e ) {
            e.preventDefault();
            var post_id = $( this ).data( 'id' ),
                data_cat = $( this ).data( 'cat' );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'post_id=' + post_id + '&data_cat=' + data_cat + '&cs_settings_ajax_update=delete_custom_post&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    location.reload();
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '.delete_cookie_cat_button' ).on( 'click', function () {
            var cat_id = $( this ).data( 'id' );
            var wrap = $( this ).closest( '.card-body' );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'cs_cookie_cat_id=' + cat_id + '&cs_settings_ajax_update=delete_cookie_cat&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    location.reload();
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '.btn_save_descr' ).on( 'click', function () {
            var submit = $( '#cs_settings_form' ).find( ":submit" );
            submit.trigger( 'click' );
        } );

        $( '.details-control' ).on( 'click', function () {
            $( this ).toggleText( 'Details', 'Close' );
            var tr = $( this ).closest( '.row' ).find( '.details-col' );
            tr.slideToggle();
        } );

        var prop = $( '.row-property .cs_consent_for_pys[type=checkbox]' );

        if ( !prop.prop( 'checked' ) ) {
            toggleProperty( prop );
        }

        prop.on( 'click', function () {
            toggleProperty( $( this ) )
        } );

        function toggleProperty( prop ) {
            var tr = prop.closest( '.row-property' ).siblings( '.row-sub-property' ).find( '.row-sub-property-toggle' );
            tr.slideToggle();
        }

        $( '.cs_save_edit_cat' ).on( 'click', function () {
            window.tinyMCE.triggerSave();
            var wrap = $( this ).closest( '.card-body' ).find( '.cs_data_render_wrap_editor' );
            var lang_control = wrap.closest( '.cs_data_render_wrap' ).find( '.cs_input_language_control' ).val();
            var font = '';
            var fields = [];

            wrap.each( function () {
                var lang_item = $( this ).find( '.form-control-lang-new' ).attr( 'data-lang' );
                if ( lang_item !== undefined ) {
                    var arr = {
                        'name': $( this ).find( '.cs_cookie_cat_title' ).val(),
                        'descr': $( this ).find( '.cs_cookie_cat_description' ).val(),
                        'lang': lang_item,
                    };
                    fields.push( arr );
                }

                if ( wrap.find( '#cs_default_font' ).val() !== undefined ) {
                    font = '&default_font=' + wrap.find( '#cs_default_font' ).val();
                }
            } );

            var unassigned = 0;
            var cat_id = $( this ).data( 'id' );
            var cs_ignore_this_category = 0;

            if ( wrap.find( '.custom-switch-input' ).prop( 'checked' ) == true ) {
                cs_ignore_this_category = 1;
            }
            if ( wrap.find( '#cs_not_block_unassigned_cookies' ).prop( 'checked' ) == true ) {
                unassigned = 1;
            }
            var btn = $( this );
            btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'cs_cookie_cat_fields=' + JSON.stringify( fields ) + '&cs_cookie_cat_id=' + cat_id + '&cs_language_control_' + cat_id + '=' + lang_control + '&cs_settings_ajax_update=update_cookie_cat' + '&cs_ignore_this_category=' + cs_ignore_this_category + '&cs_not_block_unassigned_cookies=' + unassigned + font + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '.cs_new_cat_description' ).on( 'click', function () {
            $( '.cs_renew_consent_wrap_new_cat' ).show();
        } );

        function isValidIP( str ) {
            const octet4 = '(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]?|0)';
            const regex = new RegExp( `^${octet4}\\.${octet4}\\.${octet4}\\.${octet4}$` );
            if ( regex.test( str ) ) {
                return true
            } else {
                const regex_exp_v6 = '^\\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([ 0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4] \\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]? \\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1, 4}){1,2})|:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[ 0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f] {1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1 ,4})?:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]| 2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4 }:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}) {0,2}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]| 2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4 }:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}) {0,3}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]| 2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4 }:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}) {0,4}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4] \\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}) {1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\\d|1 \\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)) {3}))|:)))(%.+)?\\s*$';
                const regex6 = new RegExp( `${ regex_exp_v6 }` );
                if ( regex6.test( str ) ) {
                    return true
                }
            }
            return false;
        }

        $( '#add_new_ignore_ip' ).on( 'click', function () {
            var new_ignore_ip = $( '#new_ignore_ip' ).val();

            if ( isValidIP( new_ignore_ip ) ) {
                $( '.cs-error-message' ).fadeOut();
                $.ajax( {
                    url: ajax_object.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'cs_new_ignore_ip',
                        nonce_code: ajax_object.nonce,
                        ignore_ip: new_ignore_ip
                    },
                    success: function ( response ) {
                        console.log( response );
                        if ( response.success ) {
                            $( '.cs-error-message' ).fadeOut();
                            location.reload();
                        } else {
                            $( '.cs-error-message' ).text( 'Duplicate IP address' ).fadeIn();
                        }
                    }
                } );
            } else {
                $( '.cs-error-message' ).text( 'Invalid IP address' ).fadeIn();
            }
        } );

        $( '.cs_renew_consent_cancel_new_cat' ).on( 'click', function () {
            $( '.cs_renew_consent_wrap_new_cat' ).hide();
        } );

        $( '.cs_renew_consent_category_new_cat' ).on( 'click', function () {
            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_renew_consent',
                    nonce_code: ajax_object.nonce
                },
                success: function ( response ) {
                    window.tinyMCE.triggerSave();
                    var name = $( '#cs_new_cat_title' ).val();
                    var descr = $( '#cs_new_cat_description' ).val();

                    $.ajax( {
                        url: url,
                        type: 'POST',
                        data: 'cs_cookie_cat_name=' + name + '&cs_cookie_cat_descr=' + descr + '&cs_settings_ajax_update=add_new_cookie_cat&_wpnonce=' + wpnonce,
                        success: function ( response ) {
                            location.reload();
                        },
                        error: function () {
                            location.reload();
                        }
                    } );
                }
            } );
        } );

        $( 'body' ).on( 'click', '.btn_single_save', function () {
            var submit_btn = $( this );
            submit_btn.removeClass( 'saved-effect' );
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            cs_settings_form.submit();
        } );

        $( '.js-control-element' ).on( 'input', function () {
            $( this ).closest( '.card' ).find( '.btn_single_save' ).addClass( 'saved-effect' );
        } );

        $( '.btn_restore_adjust' ).on( 'click', function ( e ) {
            var submit_action = 'btn_restore_adjust';
            var submit_btn = $( this );
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            e.preventDefault();
            $.ajax( {
                url: url,
                type: 'POST',
                data: {
                    cs_settings_ajax_update: submit_action,
                    _wpnonce: wpnonce,
                },
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    location.reload();
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        $( '.template_delete_btn, .custom_rule_delete_btn' ).on( 'click', function () {
            var template_id = $( this ).data( 'id' );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'template_id=' + template_id + '&cs_settings_ajax_update=delete_template&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    location.reload();
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '._cs_bars_type' ).on( 'change', function () {
            var check_type = $( '._cs_bars_type' ).children( "option:selected" ).val();
            if ( check_type == 'popup_small' || check_type == 'popup_large' ) {
                $( ".cs_bars_position_wrap" ).hide();
            } else {
                $( ".cs_bars_position_wrap" ).show();
            }
        } );

        $( '._cs_custom_text' ).on( 'change', function () {
            if ( $( this ).is( ':checked' ) ) {
                $( '.custom_text_wrap' ).show();
            } else {
                $( '.custom_text_wrap' ).hide();
            }
        } );

        $( '._cs_bars_position' ).each( function () {
            if ( $( this ).val() == 'top' ) {
                $( '.cs_top_push_wrap' ).show();
            } else {
                $( '.cs_top_push_wrap' ).hide();
            }
        } );

        $( '._cs_bars_position' ).on( 'change', function () {
            if ( $( this ).val() == 'top' ) {
                $( '.cs_top_push_wrap' ).show();
                $( '._cs_top_push' ).prop( "checked", true );
            } else {
                $( '.cs_top_push_wrap' ).hide();
                $( '._cs_top_push' ).prop( "checked", false );
            }
        } );

        $( '._cs_bars_type' ).each( function () {
            if ( $( this ).val() == 'bar_small' || $( this ).val() == 'bar_large' ) {
                $( '._cs_bars_position_wrap' ).show();
            } else {
                $( '._cs_bars_position_wrap' ).hide();
            }
        } );

        $( '._cs_bars_type' ).on( 'change', function () {
            if ( $( this ).val() == 'bar_small' || $( this ).val() == 'bar_large' ) {
                $( '._cs_bars_position_wrap' ).show();
            } else {
                $( '._cs_bars_position_wrap' ).hide();
            }
        } );

        var check_type = $( '._cs_type' ).children( "option:selected" ).val();

        function change_options_by_type( check_type ) {
            $( "._cs_bars_position" ).val( "bottom" ).change();
            let sticky = $( '._cs_sticky' ),
                custom_button = $( '.cs_custom_button_block' ),
                close_on_scroll = $( '._cs_close_on_scroll' ),
                refresh_after_consent = $( '._cs_refresh_after_consent' ),
                deny_consent_for_close = $( '._cs_deny_consent_for_close' );
            if ( check_type == 'just_inform' ) {
                $( "._cs_bars_type" ).val( "bar_small" ).change();
                $( '._cs_privacy_link' ).prop( "checked", true );
                close_on_scroll.prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).show();
                refresh_after_consent.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_deny_all_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_hide_close_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_block_content' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();

                sticky.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', false );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', false );
                } );
            }
            if ( check_type == 'inform_and_opiout' ) {
                $( "._cs_bars_type" ).val( "bar_small" ).change();
                $( '._cs_privacy_link' ).prop( "checked", true );
                $( '._cs_block_content' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).hide();
                $( '._cs_deny_all_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_hide_close_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                refresh_after_consent.closest( '.list-item' ).show();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                refresh_after_consent.closest( '.list-item' ).find( '.cs_showing_line' ).hide();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();

                sticky.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );
            }
            if ( check_type == 'ask_before_tracking' ) {
                $( "._cs_bars_type" ).val( "bar_large" ).change();
                $( '._cs_privacy_link' ).prop( "checked", true );
                $( '._cs_block_content' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).hide();
                $( '._cs_deny_all_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_hide_close_btn' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                refresh_after_consent.prop( "checked", true ).closest( '.list-item' ).show();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                refresh_after_consent.closest( '.list-item' ).find( '.cs_showing_line' ).show();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().show();

                sticky.prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );
            }
        }

        $( '._cs_type' ).on( 'change', function () {
            var check_type = $( '._cs_type' ).children( "option:selected" ).val();
            change_options_by_type( check_type );
        } );

        /*
        * preview functions
         */

        $( '.preview_size_btn' ).on( 'click', function () {
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                prefix = 'cs_d_consent-magic_cs_d_sb_',
                preview_container = $( this ).closest( '.cs_preview_container' );
            popup.html( '' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            switch ( bar_type ) {
                case 'bar_small':
                    prefix = 'cs_d_consent-magic_cs_d_sb_';
                    break;
                case 'bar_large':
                    prefix = 'cs_d_consent-magic_cs_d_lb_';
                    break;
                case 'popup_small':
                    prefix = 'cs_d_consent-magic_cs_d_sp_';
                    break;
                case 'popup_large':
                    prefix = 'cs_d_consent-magic_cs_d_lp_';
                    break;
            }

            var wrap_type = $( 'body' ).find( '.cs_wrap_type.' + bar_type ),
                option_wrap = $( 'body' ).find( '.cs_wrap_type.options_popup' ),
                min_height = $( 'input[id^="' + prefix + 'min_height"]' ).val(),
                pd_top = $( 'input[id^="' + prefix + 'padding_top"]' ).val(),
                pd_bottom = $( 'input[id^="' + prefix + 'padding_bottom"]' ).val(),
                pd_left = $( 'input[id^="' + prefix + 'padding_left"]' ).val(),
                pd_right = $( 'input[id^="' + prefix + 'padding_right"]' ).val(),
                font_s = $( 'input[id^="' + prefix + 'font_size"]' ).val(),
                font_w = $( '#' + prefix + 'font_weight' ).children( "option:selected" ).val(),
                btn_pd_t = $( 'input[id^="' + prefix + 'btn_pd_t"]' ).val(),
                btn_pd_b = $( 'input[id^="' + prefix + 'btn_pd_bt"]' ).val(),
                btn_pd_l = $( 'input[id^="' + prefix + 'btn_pd_l"]' ).val(),
                btn_pd_r = $( 'input[id^="' + prefix + 'btn_pd_r"]' ).val(),
                btn_mg_t = $( 'input[id^="' + prefix + 'btn_mg_t"]' ).val(),
                btn_mg_b = $( 'input[id^="' + prefix + 'btn_mg_bt"]' ).val(),
                btn_mg_l = $( 'input[id^="' + prefix + 'btn_mg_l"]' ).val(),
                btn_mg_r = $( 'input[id^="' + prefix + 'btn_mg_r"]' ).val(),
                btn_font_s = $( 'input[id^="' + prefix + 'btn_font_size"]' ).val(),
                btn_font_w = $( '#' + prefix + 'btn_font_weight' ).children( "option:selected" ).val(),
                op_min_height = $( 'input[id^="cs_d_consent-magic_cs_d_op_min_height"]' ).val(),
                op_pd_top = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_top"]' ).val(),
                op_pd_bottom = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_bottom"]' ).val(),
                op_pd_left = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_left"]' ).val(),
                op_pd_right = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_right"]' ).val(),
                op_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_font_size"]' ).val(),
                op_font_w = $( '#cs_d_consent-magic_cs_d_op_font_weight' ).children( "option:selected" ).val(),
                op_btn_pd_t = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_t"]' ).val(),
                op_btn_pd_b = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_bt"]' ).val(),
                op_btn_pd_l = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_l"]' ).val(),
                op_btn_pd_r = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_r"]' ).val(),
                op_btn_mg_t = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_t"]' ).val(),
                op_btn_mg_b = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_bt"]' ).val(),
                op_btn_mg_l = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_l"]' ).val(),
                op_btn_mg_r = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_r"]' ).val(),
                op_btn_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_font_size"]' ).val(),
                op_title_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_titles_font_size"]' ).val(),
                op_subtitle_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_subtitles_font_size"]' ).val(),
                op_btn_font_w = $( '#cs_d_consent-magic_cs_d_op_btn_font_weight' ).children( "option:selected" ).val(),
                op_title_f_w = $( '#cs_d_consent-magic_cs_d_op_titles_font_weight' ).children( "option:selected" ).val(),
                op_subtitle_f_w = $( '#cs_d_consent-magic_cs_d_op_subtitles_font_weight' ).children( "option:selected" ).val();

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_size_show',
                    bar_type: bar_type,
                    min_height: min_height,
                    pd_top: pd_top,
                    pd_bottom: pd_bottom,
                    pd_left: pd_left,
                    pd_right: pd_right,
                    font_s: font_s,
                    font_w: font_w,
                    btn_pd_t: btn_pd_t,
                    btn_pd_b: btn_pd_b,
                    btn_pd_l: btn_pd_l,
                    btn_pd_r: btn_pd_r,
                    btn_mg_t: btn_mg_t,
                    btn_mg_b: btn_mg_b,
                    btn_mg_r: btn_mg_r,
                    btn_mg_l: btn_mg_l,
                    btn_font_s: btn_font_s,
                    btn_font_w: btn_font_w,
                    op_min_height: op_min_height,
                    op_pd_top: op_pd_top,
                    op_pd_bottom: op_pd_bottom,
                    op_pd_left: op_pd_left,
                    op_pd_right: op_pd_right,
                    op_font_s: op_font_s,
                    op_font_w: op_font_w,
                    op_btn_pd_t: op_btn_pd_t,
                    op_btn_pd_b: op_btn_pd_b,
                    op_btn_pd_l: op_btn_pd_l,
                    op_btn_pd_r: op_btn_pd_r,
                    op_btn_mg_t: op_btn_mg_t,
                    op_btn_mg_b: op_btn_mg_b,
                    op_btn_mg_l: op_btn_mg_l,
                    op_btn_mg_r: op_btn_mg_r,
                    op_btn_font_s: op_btn_font_s,
                    op_title_f_s: op_title_f_s,
                    op_subtitle_f_s: op_subtitle_f_s,
                    op_btn_font_w: op_btn_font_w,
                    op_title_f_w: op_title_f_w,
                    op_subtitle_f_w: op_subtitle_f_w,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response.data.html );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.preview_color_btn' ).on( 'click', function () {
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                cs_border_style = $( '#cs_cs_border_style' ).children( "option:selected" ).val(),
                cs_backend_color = $( '#cs_cs_backend_color' ).val(),
                cs_border_weight = $( 'input[id^="cs_consent-magic_cs_border_weight"]' ).val(),
                cs_border_color = $( '#cs_cs_border_color' ).val(),
                cs_text_color = $( '#cs_cs_text_color' ).val(),
                cs_links_color = $( '#cs_cs_links_color' ).val(),
                cs_titles_text_color = $( '#cs_cs_titles_text_color' ).val(),
                cs_subtitles_text_color = $( '#cs_cs_subtitles_text_color' ).val(),
                cs_accept_all_buttons_bg = $( '#cs_cs_accept_all_buttons_bg' ).val(),
                cs_accept_all_buttons_text_color = $( '#cs_cs_accept_all_buttons_text_color' ).val(),
                cs_custom_button_buttons_bg = $( '#cs_cs_custom_button_buttons_bg' ).val(),
                cs_custom_button_buttons_text_color = $( '#cs_cs_custom_button_buttons_text_color' ).val(),
                cs_deny_all_buttons_bg = $( '#cs_cs_deny_all_buttons_bg' ).val(),
                cs_deny_all_buttons_text_color = $( '#cs_cs_deny_all_buttons_text_color' ).val(),
                cs_options_buttons_text_color = $( '#cs_cs_options_buttons_text_color' ).val(),
                cs_options_buttons_bg = $( '#cs_cs_options_buttons_bg' ).val(),
                cs_confirm_buttons_bg = $( '#cs_cs_confirm_buttons_bg' ).val(),
                cs_confirm_buttons_text_color = $( '#cs_cs_confirm_buttons_text_color' ).val(),
                cs_sticky_bg = $( '#cs_cs_sticky_bg' ).val(),
                cs_sticky_link_color = $( '#cs_cs_sticky_link_color' ).val(),
                cs_logo_size = $( '#cs_cs_logo_size' ).children( "option:selected" ).val(),
                cs_logo = $( '#cs_cs_logo' ).val(),
                cs_position_vertical_list = $( '#cs_cs_position_vertical_list' ).children( "option:selected" ).val(),
                cs_position_horizontal_list = $( '#cs_cs_position_horizontal_list' ).children( "option:selected" ).val(),
                cs_cat_color = $( '#cs_cs_cat_color' ).val(),
                cs_active_toggle_color = $( '#cs_cs_active_toggle_color' ).val(),
                preview_container = $( this ).closest( '.cs_preview_container' );
            popup.html( '' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            if ( cs_border_style == null ) {
                cs_border_style = $( '#cs_d_consent-magic_cs_border_style' ).children( "option:selected" ).val();
            }

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_color_show',
                    cs_backend_color: cs_backend_color,
                    cs_border_style: cs_border_style,
                    cs_border_weight: cs_border_weight,
                    cs_border_color: cs_border_color,
                    cs_text_color: cs_text_color,
                    cs_links_color: cs_links_color,
                    cs_titles_text_color: cs_titles_text_color,
                    cs_subtitles_text_color: cs_subtitles_text_color,
                    cs_accept_all_buttons_bg: cs_accept_all_buttons_bg,
                    cs_accept_all_buttons_text_color: cs_accept_all_buttons_text_color,
                    cs_custom_button_buttons_bg: cs_custom_button_buttons_bg,
                    cs_custom_button_buttons_text_color: cs_custom_button_buttons_text_color,
                    cs_deny_all_buttons_bg: cs_deny_all_buttons_bg,
                    cs_deny_all_buttons_text_color: cs_deny_all_buttons_text_color,
                    cs_options_buttons_text_color: cs_options_buttons_text_color,
                    cs_options_buttons_bg: cs_options_buttons_bg,
                    cs_confirm_buttons_bg: cs_confirm_buttons_bg,
                    cs_confirm_buttons_text_color: cs_confirm_buttons_text_color,
                    cs_sticky_bg: cs_sticky_bg,
                    cs_sticky_link_color: cs_sticky_link_color,
                    cs_logo: cs_logo,
                    cs_position_vertical_list: cs_position_vertical_list,
                    cs_position_horizontal_list: cs_position_horizontal_list,
                    cs_logo_size: cs_logo_size,
                    cs_cat_color: cs_cat_color,
                    cs_active_toggle_color: cs_active_toggle_color,
                    bar_type: bar_type,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.btn_preview_rule_edit' ).on( 'click', function () {
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                consent_type = $( '._cs_type' ).children( "option:selected" ).val(),
                privacy = 0,
                bar_theme = $( '._cs_theme' ).children( "option:selected" ).val(),
                bar_type = $( '._cs_bars_type' ).children( "option:selected" ).val(),
                bar_position = $( '._cs_bars_position' ).children( "option:selected" ).val(),
                deny_all_btn = 0,
                hide_close_btn = 0,
                custom_button = 0,
                sticky = 0,
                cs_rule_id = $( '#cs_rule_id' ).val(),
                preview_container = $( this ).closest( '.cs_preview_container' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );
            if ( $( '._cs_privacy_link' ).is( ':checked' ) ) {
                privacy = 1;
            }
            if ( $( '._cs_deny_all_btn' ).is( ':checked' ) ) {
                deny_all_btn = 1;
            }
            if ( $( '._cs_sticky' ).is( ':checked' ) ) {
                sticky = 1;
            }
            if ( $( '._cs_custom_button' ).is( ':checked' ) ) {
                custom_button = 1;
            }
            if ( $( '._cs_hide_close_btn' ).is( ':checked' ) ) {
                hide_close_btn = 1;
            }
            popup.html( '' );
            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_show',
                    cs_type: consent_type,
                    cs_privacy: privacy,
                    cs_sticky: sticky,
                    cs_theme: bar_theme,
                    cs_bar_type: bar_type,
                    cs_bar_position: bar_position,
                    cs_deny_all_btn: deny_all_btn,
                    cs_custom_button: custom_button,
                    cs_hide_close_btn: hide_close_btn,
                    cs_rule_id: cs_rule_id,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.btn_preview_rule' ).on( 'click', function () {
            $( '.preview_wrap' ).show();
            if ( $( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                jQuery( 'body' ).addClass( "cs-barmodal-open" );
                jQuery( ".cs-popupbar-overlay" ).addClass( "cs-show" );
            }
            jQuery( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
        } );

        $( '.preview_action_btn' ).on( 'click', function () {
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                preview_container = $( this ).closest( '.cs_preview_container' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                jQuery( 'body' ).addClass( "cs-barmodal-open" );
                popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
            }
            popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
            popup.show();
            cs_show_popup_overlay();
        } );

        $( '.preview_list_action_btn' ).on( 'click', function () {
            var popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                preview_container = $( this ).closest( '.cs_preview_container' ),
                id = $( this ).data( 'id' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            popup.html( '' );
            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'preview_list_show',
                    id: id,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.cs_sub_tab__script_block li' ).on( "click", function () {
            var trgt = $( this ).attr( 'data-target' ),
                prnt = $( this ).parent( '.cs_sub_tab' ),
                ctnr = prnt.siblings( '.cs_sub_tab_container' );
            localStorage.setItem( 'activeSubTabScriptBlock', trgt );
            prnt.find( 'li' ).removeClass( 'active' );
            $( this ).addClass( 'active' );
            ctnr.find( '.cs_sub_tab_content' ).hide();
            ctnr.find( '.cs_sub_tab_content[data-id="' + trgt + '"]' ).fadeIn();
        } );

        $( '.open_target_tab' ).on( "click", function ( e ) {
            var trgt = $( this ).attr( 'data-target' );
            e.preventDefault();
            $( '.cs_sub_tab ' ).find( "[data-target='" + trgt + "']" ).trigger( 'click' );
            $( 'html, body' ).animate( { scrollTop: 0 }, 1500 );
        } );

        $( '.cs_sub_tab__script_block' ).each( function () {
            var activeSubTabScriptBlock = localStorage.getItem( 'activeSubTabScriptBlock' );
            var elm_tp = $( this ).find( "[data-target='" + activeSubTabScriptBlock + "']" );
            if ( activeSubTabScriptBlock == null ) {
                activeSubTabScriptBlock = $( this ).find( "li:eq(0)" ).attr( 'data-target' );
                elm_tp = $( this ).find( "[data-target='" + activeSubTabScriptBlock + "']" );
            }
            elm_tp.trigger( "click" );
        } );

        $( '.templates_sub_tab li' ).on( "click", function () {
            var trgt = $( this ).attr( 'data-target' ),
                prnt = $( this ).parent( '.cs_sub_tab' ),
                ctnr = prnt.siblings( '.cs_sub_tab_container' );
            localStorage.setItem( 'activeSubTabTemplate', trgt );
            prnt.find( 'li' ).removeClass( 'active' );
            $( this ).addClass( 'active' );
            ctnr.find( '.cs_sub_tab_content' ).hide();
            ctnr.find( '.cs_sub_tab_content[data-id="' + trgt + '"]' ).fadeIn();
        } );

        $( '.templates_sub_tab' ).each( function () {
            var activeSubTabTemplate = localStorage.getItem( 'activeSubTabTemplate' );
            var elm_tp = $( this ).find( "[data-target='" + activeSubTabTemplate + "']" );
            if ( activeSubTabTemplate == null ) {
                activeSubTabTemplate = $( this ).find( "li:eq(0)" ).attr( 'data-target' );
                elm_tp = $( this ).find( "[data-target='" + activeSubTabTemplate + "']" );
            }
            elm_tp.trigger( "click" );
        } );

        $( '.cs_force_update' ).on( 'click', function ( e ) {
            var submit_btn = $( this );
            submit_btn.hide();
            $( '.fancy-spinner' ).css( { 'opacity': '1', 'height': '3rem' } );
            var message_wrap = $( this ).siblings( '.cs_message_db_update' );
            message_wrap.hide();

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_force_update',
                    nonce_code: ajax_object.nonce
                },
                success: function ( data ) {

                    submit_btn.show();
                    $( '.fancy-spinner' ).css( { 'opacity': '0', 'height': '0' } );
                    message_wrap.html( data.data.message );
                    message_wrap.show();

                },
                error: function ( data ) {
                    console.log( data )
                }
            } );
        } );

        /**
         * Forms submitted functions
         */

        cs_settings_form.on( 'submit', function ( e ) {
            if ( window.tinyMCE ) {
                window.tinyMCE.triggerSave();
            }

            var submit_action = $( '#cs_update_action' ).val(),
                btn_single_save = $( '.btn_single_save' ),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                cs_target = $( '#_cs_target' ).cs_select2( "data" ),
                submit_btn = $( this ).find( 'input[type="submit"]' ),
                cs_target_result = [];

            if ( cs_target ) {
                for ( var i = 0; i <= cs_target.length - 1; i++ ) {
                    cs_target_result.push( cs_target[ i ].id );
                }
            }
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_cs_target=' + cs_target_result + '&_wpnonce=' + wpnonce,
                success: function ( response ) {
                    if ( response ) {
                        if ( check_type != $( '._cs_type' ).children( "option:selected" ).val() ) {
                            $.ajax( {
                                url: ajax_object.ajaxurl,
                                type: 'POST',
                                data: {
                                    action: 'cs_renew_consent',
                                    nonce_code: ajax_object.nonce
                                },
                                success: function ( response ) {
                                    if ( response.success ) {
                                        location.reload();
                                    } else {
                                        console.log( response );
                                    }
                                }
                            } );
                        }
                        submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                        btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                        if ( submit_btn.closest( '.container' ).hasClass( 'edit_rule_container' ) ) {
                            window.location.href = url;
                        } else {
                            location.reload();
                        }
                    } else {
                        submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                        btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    }
                }
            } );
        } );

        cs_step_form.on( 'submit', function ( e ) {
            var submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                step_url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            $( '.fancy-spinner' ).css( { 'opacity': '1', 'height': '3rem' } );
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: step_url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    window.location = step_url;
                }
            } );
        } );

        cs_design_form.on( 'submit', function ( e ) {
            var submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url + '&tab=cs-design';
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_script_form.on( 'submit', function ( e ) {
            window.tinyMCE.triggerSave();
            var submit_action = $( '#cs_update_action' ).val(),
                heedle = $( '#cs_cs_default_script_js_heedle' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&heedle=' + heedle + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url + '&tab=cs-script-blocking';
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_cookie_form.on( 'submit', function ( e ) {
            window.tinyMCE.triggerSave();
            var submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url + '&tab=cs-script-blocking';
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_new_rule_form.on( 'submit', function ( e ) {
            window.tinyMCE.triggerSave();
            var submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' ),
                cs_target = $( '#_cs_target' ).cs_select2( "data" ),
                cs_target_result = [];

            for ( var i = 0; i <= cs_target.length - 1; i++ ) {
                cs_target_result.push( cs_target[ i ].id );
            }
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_cs_target=' + cs_target_result + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url;
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_settings_tab_form.on( 'submit', function ( e ) {
            var permissions = $( '#cs_cs_admin_permissions' ).val(),
                ignore_users = $( '#cs_cs_admin_ignore_users' ).val(),
                ignore_users_ip = $( '#cs_cs_admin_ignore_users_ip' ).val(),
                important_emails = $( '#cs_cs_send_important_emails' ).val(),
                submit_action = $( '#cs_update_action' ).val(),
                btn_single_save = $( '.btn_single_save' ),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&permissions=' + permissions + '&important_emails=' + important_emails + '&ignore_users=' + ignore_users + '&ignore_users_ip=' + ignore_users_ip + '&_wpnonce=' + wpnonce,
                success: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    location.reload();
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        $( '.cart_line_item .custom-switch-input' ).on( 'change', function () {
            var id = $( this ).attr( 'id' );
            $( '.cs_renew_consent_wrap' ).attr( 'data-id', id );
            $( '.cs_renew_consent_wrap' ).show();
        } );

        $( '.cs_renew_consent_cancel' ).on( 'click', function () {
            var element = $( '.cs_renew_consent_wrap' ).attr( 'data-id' );
            if ( $( '#' + element ).prop( 'checked' ) == false ) {
                $( '#' + element ).prop( 'checked', true );
            } else {
                $( '#' + element ).prop( 'checked', false );
            }
            $( '.cs_renew_consent_wrap' ).hide();
        } );

        $( '.cs_renew_consent_category' ).on( 'click', function () {
            var element = $( '.cs_renew_consent_wrap' ).attr( 'data-id' );
            $( '#' + element ).closest( '.card-body' ).find( '.cs_save_edit_cat' ).trigger( 'click' );
        } );

        /**
         * Settings actions
         */

        $( '.cs_renew_consent_confirm' ).on( 'click', function () {
            $( '.cs_renew_consent_wrap' ).show();
        } );

        $( '.cs_restart_setup' ).on( 'click', function () {
            $( '.cs_restart_setup_wrap' ).show();
        } );

        $( '.cs_deactivation_db_clear' ).on( 'change', function () {
            if ( $( '.cs_deactivation_db_clear' ).is( ':checked' ) ) {
                $( '.cs_deactivation_db_clear_popup' ).show();
            }
        } );

        $( '.cs_deactivation_db_clear_close' ).on( 'click', function () {
            $( '.cs_deactivation_db_clear_popup' ).hide();
            $( '.cs_deactivation_db_clear' ).prop( 'checked', false );
        } );

        $( '.delete_proof_consent' ).on( 'click', function () {
            $( '.cs_delete_proof_consent_wrap' ).show();
        } );

        $( '.delete_proof_consent_close' ).on( 'click', function () {
            $( '.cs_delete_proof_consent_wrap' ).hide();
        } );

        $( '.restore_translations' ).on( 'click', function () {
            $( '.cs_restore_translations_wrap' ).show();
        } );

        $( '.restore_translations_close' ).on( 'click', function () {
            $( '.cs_restore_translations_wrap' ).hide();
        } );

        $( '.cs_restart_setup_close' ).on( 'click', function () {
            $( '.cs_restart_setup_wrap' ).hide();
        } );

        $( '.cs_renew_consent' ).on( 'click', function () {
            var button = $( this );
            button.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $( '.cs_renew_consent_wrap' ).hide();
            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_renew_consent',
                    nonce_code: ajax_object.nonce
                },
                success: function ( response ) {
                    button.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.cs_delete_license' ).on( 'click', function () {
            var button = $( this );
            button.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_instance_update',
                    nonce_code: ajax_object.nonce_code,
                },
                success: function ( response ) {
                    button.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location = '/wp-admin/admin.php?page=cs-license';
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        /**
         * multi select functions
         */

        $( '.cs_multi_select' ).cs_select2();

        $( ".cs_multi_select_tags" ).cs_select2( { tags: true } );

        /*
         * images uploaded functions
         */

        $( document ).on( 'click', '.cs_img_upload', function ( e ) {
            e.preventDefault();
            var custom_uploader = wp.media( {
                title: 'Insert image',
                library: {
                    type: 'image'
                },
                button: {
                    text: 'Use this image'
                },
                multiple: false
            } ).on( 'select', function () {
                var attachment = custom_uploader.state().get( 'selection' ).first().toJSON();
                $( '.cs_logo_img_wrap' ).append( '<img src="' + attachment.sizes.full.url + '" alt="">' );
                $( '.img_recommender' ).css( 'display', 'block' );
                $( '.cs_img_upload_rmv' ).css( 'display', 'block' );
                $( '#cs_cs_logo' ).val( attachment.id );
            } ).open();
        } );

        $( document ).on( 'click', '.cs_img_upload_rmv', function ( e ) {
            e.preventDefault();
            $( '.cs_logo_img_wrap' ).find( 'img' ).remove();
            $( '#cs_cs_logo' ).val( '' );
            $( this ).css( 'display', 'none' );
            $( '.img_recommender' ).css( 'display', 'none' );
        } );

        //change language text
        $( '.form-control-lang' ).cs_select2( {
            closeOnSelect: true,
            allowClear: false,
        } ).on( 'cs_select2:select', function ( e ) {

            var id = $( this ).closest( '.cs_data_render_wrap' ).find( '.js-control-element' ).attr( 'id' );
            cs_select2_processing( e, $( this ), id );

        } );

        //add form for new language
        $( '.add_new_lang_action' ).on( 'click', function () {
            var add_html = $( this ).siblings( '.add_new_lang' );

            var key = $( this ).attr( 'data-key' );
            var render = $( this ).attr( 'data-render' );
            var id = key + '_' + ( new Date() ).getTime();
            var language_list = $( this ).closest( '.sub-card-body' ).find( '.language_list' );

            language_list.find( '.cs_empty_langs' ).remove();
            language_list.append( add_html.html() );
            language_list.find( '.cs_data_render_wrap:not([class*="cs_data_render_wrap_editor"])' ).addClass( "cs_data_render_wrap_editor" );

            var add_new_lang = language_list.parent().find( '.language_list > .cart_line_item:last-child' );
            add_new_lang.find( '.cs_select2-container' ).remove();
            add_new_lang.find( '.form-control-lang-add' ).addClass( 'form-control-lang-new' );
            var meta = add_new_lang.find( '.form-control-lang-new' ).cs_select2( {
                closeOnSelect: true,
                allowClear: false,
            } ).on( 'cs_select2:select', function ( e ) {
                cs_select2_processing( e, $( this ), id );
            } ).attr( 'data-option-type' );

            var name = '';
            if ( meta == 1 ) {
                name = key + '_0';
            } else {
                name = 'cs[' + $( this ).attr( 'data-plugin-name' ) + '][' + key + '_0]';
            }

            if ( render == 'renderWpEditor' || render == 'renderWpEditorByTerm' ) {
                if ( render == 'renderWpEditorByTerm' ) {
                    var textarea = '<textarea id="' + id + '" name="' + name + '" class="cs_cookie_cat_description"></textarea>';
                } else {
                    var textarea = '<textarea id="' + id + '" name="' + name + '"></textarea>';
                }

                add_new_lang.find( '.cs_data_render' ).append( textarea );
                init_wp_editor( id );

                var class_list = $( this ).closest( '.card-body' ).find( '.input_row_default .cs_data_render_wrap textarea' ).attr( "class" );
                if ( class_list !== undefined ) {
                    class_list.split( /\s+/ );
                    $( '#' + id ).addClass( class_list );
                }

            } else if ( render == 'renderTextInput' ) {
                var input = '<input type="text" id="' + id + '" name="' + name + '">';
                var class_list = $( this ).closest( '.cart_line_item' ).find( '.input_row_default .cs_data_render_wrap input' ).attr( "class" ).split( /\s+/ );

                $( '#' + id ).addClass( class_list );
                add_new_lang.find( '.cs_data_render' ).append( input );
            }
        } );

        function cs_select2_processing( e, $this, id ) {
            var data = e.params.data;
            var plugin_name = $this.attr( 'data-plugin-name' );
            var key = $this.attr( 'data-field' );

            $this.attr( 'data-lang', data.id );
            var meta = $this.attr( 'data-option-type' );
            if ( meta == 1 ) {
                $( '#' + id ).attr( 'name', key + '_' + data.id );
            } else {
                $( '#' + id ).attr( 'name', 'cs[' + plugin_name + '][' + key + '_' + data.id + ']' );
            }
        }

        $( document ).on( 'click', '.cs-delete-lang', function () {

            var wrap = $( this ).closest( '.cart_line_item' );
            var lang_select = wrap.find( 'select[class^="form-control-lang"]' );
            var lang = lang_select.attr( 'data-lang' );
            var meta = lang_select.attr( 'data-option-type' );
            var key = lang_select.attr( 'data-field' );
            var id = lang_select.attr( 'data-rule' );
            var term = $( this ).hasClass( 'cs-delete-lang-term' ) ? 1 : 0;
            $( this ).closest( '.cart_line_item' ).remove();

            if ( lang != undefined ) {
                $.ajax( {
                    url: ajax_object.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'cs_delete_lang',
                        lang: lang,
                        meta: meta,
                        key: key,
                        id: ( id != '' ) ? id : false,
                        term: term,
                        _wpnonce: wpnonce,
                    },
                    error: function ( response ) {
                        console.log( response );
                    }
                } );
            }
        } )

        //toggle geolocation settings
        $( '.cs_geolocation' ).on( 'click', function () {
            $( this ).closest( '#geolocation-settings-wrap' ).toggleClass( 'geo_disable' );
        } );

        // activate/deactivate geo license
        $( '.cs_activate_geo_license' ).on( 'click', function () {

            var key = $( '#cs_cs_geo_licence_key' ).val();
            var message = $( '.cs_geo_license_message' );
            var btn = $( this );
            var text_activate = btn.attr( 'data-activate' );
            var text_deactivate = btn.attr( 'data-deactivate' );
            var license_action = btn.attr( 'data-action' );

            btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    'key': key,
                    'license_action': license_action,
                    'action': 'cs_check_geo_license',
                    _wpnonce: wpnonce,
                },
                success: function ( data ) {
                    if ( data.data.status == true && data.data.license_action == 1 ) {

                        message.addClass( 'cs_geo_license_message_activated' );
                        btn.html( text_deactivate );
                        btn.attr( 'data-action', 0 );

                    } else {
                        message.removeClass( 'cs_geo_license_message_activated' );
                        btn.html( text_activate );
                        btn.attr( 'data-action', 1 );
                    }
                    message.html( data.data.message );
                    btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                },
                error: function ( data ) {
                    console.log( 'error' );
                }
            } );
        } );

        //load additional languages for text fields
        $( '.cs_load_langs' ).on( 'click', function ( click_event ) {
            $( this ).removeClass( 'cs_load_langs' );
            var render = $( this ).attr( 'data-render' );
            var language_block = $( this ).closest( '.sub-card' );
            var add_html = language_block.find( '.sub-card-body .add_new_lang' );
            var data_add = language_block.find( '.add_new_lang_action' );
            var key = $( this ).attr( 'data-key' );
            var language_list = language_block.find( '.sub-card-body .language_list' );
            var term = $( this ).attr( 'data-option-type' )

            $.ajax( {
                url: ajax_object.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_load_langs',
                    current_lang: $( this ).attr( 'data-current-lang' ),
                    key: key,
                    term: term,
                    nonce_code: ajax_object.nonce,
                },
                success: async function ( data ) {
                    var lang_list = data.data.lang_list;

                    if ( typeof lang_list === "object" && Object.keys( lang_list ).length > 0 ) {
                        for ( var k in lang_list ) {

                            add_html.find( '.cs_data_render_wrap:not([class*="cs_data_render_wrap_editor"])' ).addClass( "cs_data_render_wrap_editor" );
                            language_list.append( add_html.html() );
                            var add_new_lang = language_list.parent().find( '.language_list > .cart_line_item:last-child' );
                            add_new_lang.find( '.cs_select2-container' ).remove();
                            add_new_lang.find( '.form-control-lang-add' ).addClass( 'form-control-lang-new' );
                            var form_control_lang_new = add_new_lang.find( '.form-control-lang-new' );
                            form_control_lang_new.val( k );
                            form_control_lang_new.attr( 'data-lang', k );

                            var meta = form_control_lang_new.cs_select2( {
                                closeOnSelect: true,
                                allowClear: false,
                            } ).on( 'cs_select2:select', function ( event ) {

                                var js_control_id = $( this ).closest( '.cs_data_render_wrap' ).find( '.js-control-element' ).attr( 'id' );
                                cs_select2_processing( event, $( this ), js_control_id );
                            } ).attr( 'data-option-type' );

                            var name = '';
                            if ( meta == 1 ) {
                                name = key + '_' + k;
                            } else {
                                name = 'cs[' + data_add.attr( 'data-plugin-name' ) + '][' + key + '_' + k + ']';
                            }

                            if ( render == 'renderWpEditor' || render == 'renderWpEditorByTerm' ) {

                                if ( render == 'renderWpEditorByTerm' ) {
                                    add_new_lang.find( '.cs_cookie_cat_title' ).val( lang_list[ k ][ 'name' ] );
                                    var id = 'cs_edit_cat_description_' + ( new Date() ).getTime();
                                    var textarea = '<textarea id="' + id + '" name="cs_edit_cat_description_' + k + '" class="cs_cookie_cat_description">' + lang_list[ k ][ 'descr' ] + '</textarea>';
                                } else {
                                    var id = key + '_' + ( new Date() ).getTime();
                                    var textarea = '<textarea id="' + id + '" name="' + name + '">' + lang_list[ k ] + '</textarea>';
                                }

                                add_new_lang.find( '.cs_data_render' ).append( textarea );
                                init_wp_editor( id );

                                var class_list = data_add.closest( '.card-body' ).find( '.input_row_default .cs_data_render_wrap textarea' ).attr( "class" );
                                if ( class_list !== undefined ) {
                                    class_list.split( /\s+/ );
                                    $( '#' + id ).addClass( class_list );
                                }

                            } else if ( render == 'renderTextInput' ) {
                                var id = key + '_' + ( new Date() ).getTime();
                                var input = '<input type="text" class="js-control-element" id="' + id + '" name="' + name + '" + value="' + lang_list[ k ] + '">';
                                var class_list = data_add.closest( '.cart_line_item' ).find( '.input_row_default .cs_data_render_wrap input' ).attr( "class" ).split( /\s+/ );

                                $( '#' + id ).addClass( class_list );
                                add_new_lang.find( '.cs_data_render' ).append( input );
                            }
                        }
                    } else {
                        if ( typeof data.data.message !== 'undefined' ) {
                            language_block.find( '.language_list' ).html( '<p class="cs_empty_langs">' + data.data.message + '</p>' );
                        }
                    }

                    if ( data.success ) {
                        language_block.find( '.cs_input_language_control' ).val( '1' );
                    }

                    setTimeout( function () {
                        language_block.find( '.cs_lang_loading' ).css( 'display', 'none' );
                    }, 500 );
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
            $( this ).unbind( click_event );
        } );

        //show popup overlay
        function cs_show_popup_overlay() {
            $( '.preview_wrap .cs_popup_overlay' ).css( {
                visibility: 'visible',
                opacity: 1,
            } );
        }
    } )

} )( jQuery );

function cs_store_settings_btn_click( vl ) {
    document.getElementById( 'cs_update_action' ).value = vl;
}

function init_wp_editor( id ) {
    wp.editor.initialize( id, {
        tinymce: {
            wpautop: true,
            skin: 'lightgray',
            relative_urls: false,
            remove_script_host: false,
            convert_urls: false,
            browser_spellcheck: true,
            fix_list_elements: true,
            resize: 'vertical',
            body_class: '',
            preview_styles: 'font-family font-size font-weight font-style text-decoration text-transform',
            wpeditimage_disable_captions: false,
            wpeditimage_html5_captions: true,
            toolbar1: 'bold,italic,underline,blockquote,strikethrough,bullist,numlist,alignleft,aligncenter,alignright,undo,redo,link,spellchecker,fullscreen',
        },
        quicktags: true,
        mediaButtons: false,
    } );
}

function copyShortcode( val, that ) {
    /* Copy the text inside the text field */
    navigator.clipboard.writeText( val );
    var popup = jQuery( that ).closest( '.wrap_title' ).append( '<div class="cs_preview_container cs_renew_consent_wrap">' +
        '<div class="cs-modal cs-blowup">' +
        '<div class="cs-info-bar cs-public-cookie-popup popup_small">Copied the shortcode: ' + val + '</div>' +
        '</div>' +
        '</div>' );
    setTimeout( function () {
        jQuery( that ).closest( '.wrap_title' ).find( '.cs_preview_container' ).remove();
    }, 1000 );
}

var CS_Cookie = {
    set: function ( name, value, days ) {
        if ( days ) {
            var date = new Date();
            date.setTime( date.getTime() + ( days * 24 * 60 * 60 * 1000 ) );
            var expires = "; expires=" + date.toGMTString();
        } else
            var expires = "";
        document.cookie = name + "=" + value + expires + "; path=/";
    },
    read: function ( name ) {
        var nameEQ = name + "=";
        var ca = document.cookie.split( ';' );
        for ( var i = 0; i < ca.length; i++ ) {
            var c = ca[ i ];
            while ( c.charAt( 0 ) == ' ' ) {
                c = c.substring( 1, c.length );
            }
            if ( c.indexOf( nameEQ ) === 0 ) {
                return c.substring( nameEQ.length, c.length );
            }
        }
        return null;
    },
    erase: function ( name ) {
        this.set( name, "", -10 );
    },
    exists: function ( name ) {
        return ( this.read( name ) !== null );
    }
}