<?php

namespace ConsentMagicPro;

// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
	die;
}

if ( !class_exists( 'ConsentMagicPro\CS_Scanner' ) ) {
	echo sprintf( esc_html__( 'Scanner module is disabled. To continue using the scanner, turn on option ', 'consent-magic' ) . '<a href="%s">' . esc_html__( '"Scanner module" in Settings', 'consent-magic' ) . '</a>', esc_url( get_admin_url( null, 'admin.php?page=cs-settings' ) ) );
	return;
}

$per_request = array(
	'1'  => '1',
	'2'  => '2',
	'3'  => '3',
	'4'  => '4',
	'5'  => '5',
	'6'  => '6',
	'7'  => '7',
	'8'  => '8',
	'9'  => '9',
	'10' => '10',
);

$scan_interval = array(
	'once_a_week'  => 'Once a week',
	'once_a_month' => 'Once a month',
	'never'        => 'Never'
);

$auto_scan_type = array(
	'scan_all_pages' => 'Scan all pages',
	'scan_key_pages' => 'Scan key pages'
);

$cs_scanner = new CS_Scanner;

$last_scan = $cs_scanner->get_last_scan();

$table_data = get_scan_cookies_list();
$unassigned_counter = 0;

if ( $table_data ) {

	foreach ( $table_data as $item ) {
		if ( $item[ 'term_slug' ] === 'unassigned' ) {
			$unassigned_counter++;
		}
	}
}

?>

<div class="rules-wrap-border">
    <div class="container rules-wrap">
        <div class="row">
            <div class="col-12">
                <h4 class="indicator-label"><?php esc_html_e( 'The scan will detect pre-defined scripts, custom scripts and cookies. You can use shortcodes to display the results to your website visitors.', 'consent-magic' ); ?></h4>
                <p><?php esc_html_e( 'Learn how the scanner work:', 'consent-magic' ); ?> <a
                            href="https://www.youtube.com/watch?v=Dpj-qSNb3eE"
                            target="_blank"><?php esc_html_e( 'watch video', 'consent-magic' ); ?></a></p>
            </div>
        </div>
    </div>

    <div class="container rules-wrap">
        <div class="row">
            <div class="col">
				<?php
				if ( $last_scan ) {
					esc_html_e( 'Last scan ' . $last_scan[ 'created_at' ] . ', ' . $last_scan[ 'total_url' ] . ' scanned URLs, ' . $last_scan[ 'total_scripts' ] . ' scripts, ' . $last_scan[ 'total_cookies' ] . ' cookies detected', 'consent-magic' );
				}
				?>
            </div>
        </div>
    </div>

    <div class="container rules-wrap headline">
        <div>
            <h2><?php esc_html_e( 'Scan Settings', 'consent-magic' ); ?></h2>
            <div class="row" style="margin: 25px 0 0;">
                <div class="col">
                    <p>
						<?php esc_html_e( 'Newly detected cookies will go under the Unassigned category, and you can manually assign them to the correct category. You can manage categories from ', 'consent-magic' ); ?>
                        <a href="#" data-target="settings-bar"
                           class="open_target_tab"><?php esc_html_e( 'here', 'consent-magic' ); ?></a>.
                    </p>
                    <p>
						<?php esc_html_e( 'You can change pre-defined scripts category from the ', 'consent-magic' ); ?>
                        <a
                                href="#" data-target="pre-defined-scripts-bar"
                                class="open_target_tab"><?php esc_html_e( 'Pre-defined scripts page', 'consent-magic' ); ?></a>.
                    </p>
                    <p>
						<?php esc_html_e( 'You can change custom scripts category from the ', 'consent-magic' ); ?><a
                                href="#"
                                data-target="manual-cookies-bar"
                                class="open_target_tab"><?php esc_html_e( 'Custom scripts page', 'consent-magic' ); ?></a>.
                    </p>
                </div>
            </div>
        </div>

        <div class="row align-items-center" style="margin: 15px 0;">
            <div class="col-6">
                <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Auto scan type', 'consent-magic' ); ?></h4>
            </div>

            <div class="col-6 right-aligned">
				<?php renderSelectInput( 'cs_auto_scan_type', $auto_scan_type, true ); ?>
            </div>
        </div>

        <div class="row align-items-center" style="margin: 15px 0;">
            <div class="col-6">
                <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Cookie scanner URL per request', 'consent-magic' ); ?></h4>
            </div>

            <div class="col-6 right-aligned">
				<?php renderSelectInput( 'cs_scan_url_per_request', $per_request, true ); ?>
            </div>
        </div>

        <div class="row align-items-center" style="margin: 15px 0;">
            <div class="col-6">
                <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Auto scan', 'consent-magic' ); ?></h4>
            </div>

            <div class="col-6 right-aligned">
				<?php renderSelectInput( 'cs_auto_scan_interval', $scan_interval, true ); ?>
            </div>
        </div>

        <div class="row align-items-center" style="margin: 15px 0;">
            <div class="col-1">
				<?php echo render_switcher_input( 'cs_auto_scan_email_enabled' ); ?>
            </div>

            <div class="col-5" style="padding-right: 15px;">
                <h4 class="indicator-label switcher-label"><?php esc_html_e( 'When a new auto-scan is completed, email to this address:', 'consent-magic' ); ?></h4>
            </div>

            <div class="col-6 right-aligned">
				<?php renderProofDeletingEmail( 'cs_auto_scan_email', true ); ?>
            </div>
        </div>
    </div>

    <div class="container rules-wrap">
        <div class="row align-items-center">
            <div class="col-3">
                <button type="button" class="btn btn-blue cs_cookies_scan" style="margin-left: 0;"><i
                            class="icon-renew"></i> <?php esc_html_e( 'Run scan now', 'consent-magic' ); ?></button>
            </div>

            <div class="col">
				<?php esc_html_e( 'You can run a scan now if you made any significant changes to your website.', 'consent-magic' ); ?>
            </div>

            <div class="col-2">
                <div class="fancy-spinner fancy-spinner-scan">
                    <div class="ring"></div>
                    <div class="ring"></div>
                    <div class="dot"></div>
                </div>
            </div>
        </div>
        <div class="cs-scan-bar"></div>
    </div>

    <div class="container no-padding headline rules-wrap">
        <div>
            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Scripts', 'consent-magic' ); ?></h3>
        </div>

        <p>
			<?php esc_html_e( "The plugin will control pre-defined and custom scripts according to the rules' settings and customers' preferences.", 'consent-magic' ); ?>
        </p>

        <p>
			<?php esc_html_e( 'These are the ', 'consent-magic' ); ?><a href="#" data-target="pre-defined-scripts-bar"
                                                                        class="open_target_tab"><?php esc_html_e( 'pre-defined', 'consent-magic' ); ?></a>
			<?php esc_html_e( ' and ', 'consent-magic' ); ?><a href="#" data-target="manual-cookies-bar"
                                                               class="open_target_tab"><?php esc_html_e( 'custom', 'consent-magic' ); ?></a>
			<?php esc_html_e( ' scripts we detected on your site:', 'consent-magic' ); ?>
        </p>

        <table id="custom_scripts" class="display" style="width:100%;">
            <thead>
            <tr>
                <th></th>
                <th><?php esc_html_e( 'Script name', 'consent-magic' ); ?></th>
                <th><?php esc_html_e( 'Script category', 'consent-magic' ); ?></th>
            </tr>
            </thead>
            <tfoot>
            <tr>
                <th></th>
                <th><?php esc_html_e( 'Script name', 'consent-magic' ); ?></th>
                <th><?php esc_html_e( 'Script category', 'consent-magic' ); ?></th>
            </tr>
            </tfoot>
        </table>
    </div>

    <div class="container no-padding headline rules-wrap">
        <div>
            <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Cookies', 'consent-magic' ); ?></h3>
        </div>

        <p>
			<?php esc_html_e( "You can show the list with your cookies using the dedicated shortcodes.", 'consent-magic' ); ?>
        </p>

		<?php
		if ( $unassigned_counter > 0 ) { ?>
            <div class="wrap_title"
                 style="font-size: 18px; font-weight: bold; margin-bottom: 25px;background-color: #f9f9f9;padding: 25px;border: 1px solid #e2e2e2;">
				<?php esc_html_e( "You have $unassigned_counter Unassigned cookies. Assign them to the correct category and update settings.", 'consent-magic' ); ?>
            </div>
		<?php } ?>

        <table id="custom_cookies" class="display" style="width:100%;">
            <thead>
            <tr>
                <th></th>
                <th><?php esc_html_e( 'Cookie name', 'consent-magic' ); ?></th>
                <th><?php esc_html_e( 'Cookie category', 'consent-magic' ); ?></th>
            </tr>
            </thead>
            <tfoot>
            <tr>
                <th></th>
                <th><?php esc_html_e( 'Cookie name', 'consent-magic' ); ?></th>
                <th><?php esc_html_e( 'Cookie category', 'consent-magic' ); ?></th>
            </tr>
            </tfoot>
        </table>
    </div>

    <div class="container rules-wrap headline">
        <div>
            <h2><?php esc_html_e( 'Shortcodes', 'consent-magic' ); ?></h2>
        </div>

        <div class="rules-wrap-border">
            <div class="rules-wrap headline">
                <div class="wrap_title" style="font-size: 18px;">
                    <strong><?php esc_html_e( '[cm_scan]', 'consent-magic' ); ?></strong>
                    <span class="icon-files-empty copy_shorctode" onclick="copyShortcode('[cm_scan]', this)"></span>
                </div>
                <p><?php esc_html_e( 'It will show all cookies and scripts detected by the last scan.', 'consent-magic' ); ?></p>
            </div>

            <div class="rules-wrap headline">
                <div class="wrap_title" style="font-size: 18px;">
                    <strong><?php esc_html_e( '[cm_scan_cookies]', 'consent-magic' ); ?></strong>
                    <span class="icon-files-empty copy_shorctode"
                          onclick="copyShortcode('[cm_scan_cookies]', this)"></span>
                </div>
                <p><?php esc_html_e( 'It will show all cookies detected by the last scan.', 'consent-magic' ); ?></p>
            </div>

            <div class="rules-wrap headline">
                <div class="wrap_title" style="font-size: 18px;">
                    <strong><?php esc_html_e( '[cm_scan_scripts]', 'consent-magic' ); ?></strong>
                    <span class="icon-files-empty copy_shorctode"
                          onclick="copyShortcode('[cm_scan_scripts]', this)"></span>
                </div>
                <p><?php esc_html_e( 'It will show all scripts detected by the last scan.', 'consent-magic' ); ?></p>
            </div>

            <div class="rules-wrap headline">
                <div class="wrap_title" style="font-size: 18px;">
                    <strong><?php esc_html_e( '[cm_scan_description]', 'consent-magic' ); ?></strong>
                    <span class="icon-files-empty copy_shorctode"
                          onclick="copyShortcode('[cm_scan_description]', this)"></span>
                </div>
                <p><?php esc_html_e( 'It will show all cookies and scripts detected by the last scan and their descriptions.', 'consent-magic' ); ?></p>
            </div>

            <div class="rules-wrap headline">
                <div class="wrap_title" style="font-size: 18px;">
                    <strong><?php esc_html_e( '[cm_scan_cookies_description]', 'consent-magic' ); ?></strong>
                    <span class="icon-files-empty copy_shorctode"
                          onclick="copyShortcode('[cm_scan_cookies_description]', this)"></span>
                </div>
                <p><?php esc_html_e( 'It will show all cookies detected by the last scan and their descriptions.', 'consent-magic' ); ?></p>
            </div>

            <div class="rules-wrap headline">
                <div class="wrap_title" style="font-size: 18px;">
                    <strong><?php esc_html_e( '[cm_scan_scrips_description]', 'consent-magic' ); ?></strong>
                    <span class="icon-files-empty copy_shorctode"
                          onclick="copyShortcode('[cm_scan_scrips_description]', this)"></span>
                </div>
                <p><?php esc_html_e( 'It will show all scripts detected by the last scan and their descriptions.', 'consent-magic' ); ?></p>
            </div>
        </div>
    </div>

</div>