<?php

namespace ConsentMagicPro;

// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
	die;
}
$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
$terms_primary = get_cookies_terms_objects( 'cs_primary_term', true, $unassigned->term_id );
$terms = get_cookies_terms_objects( 'cs_primary_term', false, $unassigned->term_id );
$fonts = array(
	array(
		'option_value' => 'arial',
		'option_name'  => esc_html__( 'Arial', 'consent-magic' )
	),
	array(
		'option_value' => 'verdana',
		'option_name'  => esc_html__( 'Verdana', 'consent-magic' )
	),
	array(
		'option_value' => 'times',
		'option_name'  => esc_html__( 'Times New Roman', 'consent-magic' )
	)
);

?>
<div class="container container-clear">
    <div class="row" style="margin-bottom: 25px;">
        <div class="col">
            <h2><?php esc_html_e( 'Cookie/Script Types:', 'consent-magic' ); ?></h2>
        </div>
    </div>
	<?php

	if ( $terms_primary ) {
		foreach ( $terms_primary as $term ) {
			?>
            <div class="card bottom-border-row">
                <div class="card-header">
                    <div class="row">
                        <div class="col">
                            <h3><?php echo esc_html( $term->name_l ); ?></h3>
                        </div>

                        <div class="col-2 right-aligned">
                            <button type="button" class="btn btn-link card-collapse">
								<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i class="icon-down"></i>
                            </button>
                        </div>
                    </div>
                </div>

                <div class="card-body cs_data_render_wrap " style="display: none;">
                    <div class="cs_data_render_wrap_editor">
						<?php if ( $term->slug === 'unassigned' ) { ?>
                            <div class="cart_line_item">
                                <ul class="cs_ignore_category">
                                    <li>
										<?php
										echo render_switcher_term_input( 'cs_ignore_this_category', $term->term_id ); ?>
                                        <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Hide the Unassigned category in the Options popup', 'consent-magic' ); ?></h3>
                                        <ul style="margin: 25px 0 0 60px">
                                            <li>
												<?php echo render_checkbox_input( 'cs_not_block_unassigned_cookies' ); ?>
                                                <label for="cs_not_block_unassigned_cookies"
                                                       class="indicator-label switcher-label"><?php esc_html_e( "Don't block Unassigned before consent is expressed for 'Ask before tracking' consent type.", 'consent-magic' ); ?></label>
                                            </li>
                                        </ul>
                                    </li>
                                </ul>
                            </div>
						<?php } ?>

                        <div class="cart_line_item">
                            <div class="label_row">
                                <h4><?php esc_html_e( 'Title', 'consent-magic' ); ?>:</h4>
                            </div>

                            <div class="row input_row cs_data_render">
                                <div class="cs_data_render">
                                    <input type="text" class="cs_cookie_cat_title form-control js-control-element"
                                           value="<?php echo esc_html( $term->name_l ); ?>"/>
                                </div>
                            </div>
                        </div>

                        <div class="cart_line_item">
                            <div class="label_row">
                                <h4><?php esc_html_e( 'Description', 'consent-magic' ); ?>:</h4>
                            </div>

                            <div class="label_row">
                                <div class="row input_row cs_data_render">
                                    <div class="cs_data_render">
										<?php renderWpEditorByTerm( $term->description_l, $term->display_lang, 'cs_cookie_cat_description form-control js-control-element', $term->term_id ); ?>
                                    </div>
                                    <div class="form-control-lang-new"
                                         data-lang="<?php echo esc_attr( $term->display_lang ) ?>"></div>
                                </div>

								<?php if ( $term->slug === 'googlefonts' ) { ?>
                                    <div class="row align-items-center" style="margin-top: 15px;">
                                        <div class="col-6">
                                            <h4 class="indicator-label"><?php esc_html_e( 'Select the fallback font: ', 'consent-magic' ); ?></h4>
                                        </div>

                                        <div class="col-6">
											<?php renderSelectInput( 'default_font', $fonts, true ); ?>
                                        </div>
                                    </div>
								<?php } ?>

								<?php if ( $term->slug !== 'unassigned' ) { ?>
                                    <div class="cart_line_item">
                                        <div class="cs_ignore_category">
											<?php echo render_switcher_term_input( 'cs_ignore_this_category', $term->term_id ); ?>
                                            <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Ignore this category', 'consent-magic' ); ?></h4>
                                        </div>
                                    </div>
								<?php } ?>
                            </div>
                        </div>
                    </div>

                    <div class="sub-card">
                        <div class="sub-card-header">
                            <div class="row">
                                <div class="col">
                                    <h4><?php esc_html_e( 'Additional languages', 'consent-magic' ); ?></h4>
                                </div>

                                <div class="col-2 right-aligned">
                                    <button type="button" class="btn btn-link sub-card-collapse cs_load_langs"
                                            data-option-type="1"
                                            data-current-lang="<?php echo esc_attr( $term->display_lang ); ?>"
                                            data-key="<?php echo esc_attr( $term->term_id ); ?>"
                                            data-render="renderWpEditorByTerm">
										<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i class="icon-down"></i>
                                    </button>
                                </div>
                            </div>
                        </div>

                        <div class="sub-card-body" style="display: none;">
                            <div class="cs_lang_loading"><?php echo esc_html__( 'Loading languages', 'consent-magic' ); ?>
                                <p>...</p>
                            </div>
							<?php echo render_hidden_checkbox( sprintf( '%s_language_control', $term->term_id ), 0, 'cs_input_language_control' ); ?>
                            <div class="language_list language_list_cat"></div>
                            <div class="add_new_lang_wrap">
                                <a class="btn btn-blue add_new_lang_action"
                                   data-render="renderWpEditorByTerm"
                                   data-key="cs_edit_cat_description"
                                   data-plugin-name="<?php echo esc_attr( ConsentMagic()->get_plugin_name() ); ?>"><i
                                            class="icon-plus"></i> <?php esc_html_e( 'Add New Language', 'consent-magic' ); ?>
                                </a>
                                <div style="display: none" class="add_new_lang">
                                    <div class="row cart_line_item">
                                        <div class="col-1 cs-delete-lang-wrap">
                                            <span class="icon-minus cs-delete-lang cs-delete-lang-term"></span>
                                        </div>

                                        <div class="col-11 row cs_data_render_wrap">
                                            <div class="col-12">
                                                <div class="cart_line_item">
                                                    <div class="label_row">
                                                        <h4><?php esc_html_e( 'Title', 'consent-magic' ); ?>:</h4>
                                                    </div>

                                                    <div class="row input_row">
                                                        <input type="text"
                                                               class="cs_cookie_cat_title form-control js-control-element"/>
                                                    </div>
                                                </div>

                                                <div class="cart_line_item">
                                                    <div class="label_row">
                                                        <h4><?php esc_html_e( 'Description', 'consent-magic' ); ?>:</h4>
                                                    </div>

                                                    <div class="label_row">
                                                        <div class="row input_row cs_data_render">
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="row cs_data_render_buttons">
													<?php renderSelectLanguagesByTermNew( 'cs_edit_cat_description', $term->term_id, '', 'renderWpEditorByTerm', '250px' ); ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row cs_data_render_buttons">
                        <button type="button" data-id="<?php echo esc_attr( $term->term_id ); ?>"
                                class="btn btn-blue btn-right cs_save_edit_cat"><i
                                    class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?></button>
                    </div>
                </div>
            </div>
			<?php
		}
	}

	if ( $terms ) {
		foreach ( $terms as $term ) {
			?>
            <div class="card card-body bottom-border-row">
                <div class="card-header">
                    <div class="row">
                        <div class="col">
                            <h3><?php echo esc_html( $term->name_l ); ?></h3>
                        </div>

                        <div class="col-2 right-aligned">
                            <button type="button" class="btn btn-link card-collapse">
								<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i class="icon-down"></i>
                            </button>
                        </div>
                    </div>
                </div>

                <div class="card-body cs_data_render_wrap " style="display: none;">
                    <div class="cart_line_item cs_data_render_wrap_editor">
                        <div class="label_row">
                            <h4><?php esc_html_e( 'Title', 'consent-magic' ); ?>:</h4>
                        </div>

                        <div class="row input_row cs_data_render">
                            <div class="cs_data_render">
                                <input type="text" class="cs_cookie_cat_title form-control js-control-element"
                                       value="<?php echo esc_html( $term->name_l ); ?>"/>
                            </div>
                        </div>

                        <div class="cart_line_item">
                            <div class="label_row">
                                <h4><?php esc_html_e( 'Description', 'consent-magic' ); ?>:</h4>
                            </div>

                            <div class="label_row">
                                <div class="row input_row cs_data_render">
                                    <div class="cs_data_render">
										<?php renderWpEditorByTerm( $term->description_l, $term->display_lang, 'cs_cookie_cat_description form-control js-control-element', $term->term_id ); ?>
                                    </div>
                                    <div class="form-control-lang-new"
                                         data-lang="<?php echo esc_attr( $term->display_lang ) ?>"></div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="sub-card">
                        <div class="sub-card-header">
                            <div class="row">
                                <div class="col">
                                    <h4><?php esc_html_e( 'Additional languages', 'consent-magic' ); ?></h4>
                                </div>

                                <div class="col-2 right-aligned">
                                    <button type="button" class="btn btn-link sub-card-collapse cs_load_langs"
                                            data-option-type="1"
                                            data-current-lang="<?php echo esc_attr( $term->display_lang ); ?>"
                                            data-key="<?php echo esc_attr( $term->term_id ); ?>"
                                            data-render="renderWpEditorByTerm">
										<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i class="icon-down"></i>
                                    </button>
                                </div>
                            </div>
                        </div>

                        <div class="sub-card-body" style="display: none;">
                            <div class="cs_lang_loading"><?php echo esc_html__( 'Loading languages', 'consent-magic' ); ?>
                                <p>...</p>
                            </div>
							<?php echo render_hidden_checkbox( sprintf( '%s_language_control', $term->term_id ), 0, 'cs_input_language_control' ); ?>
                            <div class="language_list language_list_cat"></div>
                            <div class="add_new_lang_wrap">
                                <a class="btn btn-blue add_new_lang_action" data-render="renderWpEditorByTerm"
                                   data-key="cs_edit_cat_description"
                                   data-plugin-name="<?php echo esc_attr( ConsentMagic()->get_plugin_name() ); ?>"><i
                                            class="icon-plus"></i> <?php esc_html_e( 'Add New Language', 'consent-magic' ); ?>
                                </a>
                                <div style="display: none" class="add_new_lang">
                                    <div class="row cart_line_item">
                                        <div class="col-1 cs-delete-lang-wrap">
                                            <span class="icon-minus cs-delete-lang cs-delete-lang-term"></span>
                                        </div>

                                        <div class="col-11 row cs_data_render_wrap">
                                            <div class="col-12">
                                                <div class="cart_line_item">
                                                    <div class="label_row">
                                                        <h4><?php esc_html_e( 'Title', 'consent-magic' ); ?>:</h4>
                                                    </div>

                                                    <div class="row input_row">
                                                        <input type="text"
                                                               class="cs_cookie_cat_title form-control js-control-element"/>
                                                    </div>
                                                </div>

                                                <div class="cart_line_item">
                                                    <div class="label_row">
                                                        <h4><?php esc_html_e( 'Description', 'consent-magic' ); ?>:</h4>
                                                    </div>

                                                    <div class="label_row">
                                                        <div class="row input_row cs_data_render">
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="row cs_data_render_buttons">
													<?php renderSelectLanguagesByTermNew( 'cs_edit_cat_description', $term->term_id, '', 'renderWpEditorByTerm', '250px' ); ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row align-items-center cs_data_render_buttons">
                        <div class="col right-aligned">
                            <button type="button" data-id="<?php echo esc_attr( $term->term_id ); ?>"
                                    class="btn btn-blue btn-right cs_save_edit_cat" style="margin-right: 15px;"><i
                                        class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?></button>
                            <button type="button" data-id="<?php echo esc_attr( $term->term_id ); ?>"
                                    class="btn btn-blue delete_cookie_cat_button"><i
                                        class="icon-delete"></i> <?php esc_html_e( 'Delete', 'consent-magic' ); ?>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
			<?php
		}
	}
	?>

    <div class="card cs_">
        <div class="card-header right-aligned">
            <button type="button" class="btn btn-blue card-collapse"><i
                        class="icon-plus"></i> <?php esc_html_e( 'Add new type', 'consent-magic' ); ?></button>
            <p></p>
        </div>

        <div class="card-body" style="display: none;">
            <div class="cart_line_item">
                <div class="label_row">
                    <h4><?php esc_html_e( 'Title', 'consent-magic' ); ?>:</h4>
                </div>

                <div class="input_row">
                    <input type="text" name="cs_new_cat_title" id="cs_new_cat_title"
                           class="form-control js-control-element" value=""/>
                </div>
            </div>

            <div class="cart_line_item">
                <div class="label_row">
                    <h4><?php esc_html_e( 'Description', 'consent-magic' ); ?>:</h4>
                </div>

                <div class="input_row">
					<?php renderWpEditorByTerm( '', CMPRO_DEFAULT_LANGUAGE, 'cs_cookie_cat_description form-control js-control-element' ); ?>
                </div>
            </div>

            <div class="right-aligned mt-20">
                <button type="button" name="cs_add_new_cat" class="btn btn-blue btn-right cs_new_cat_description"><i
                            class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?></button>
            </div>
        </div>
    </div>

    <div class="cs_preview_container cs_renew_consent_wrap" style="display: none;" data-id="">
        <div class="cs-info-bar cs-public-cookie-popup popup_small"
             style="box-shadow: rgba(0,0,0,0.5) 0 2px 10px;text-align: center;">
            <div class="cs-modal cs-blowup">
                <div class="cs-modal-dialog" role="document">
                    <div class="cs-modal-content cs-bar-popup">
                        <div class="cs-modal-body">
                            <div class="cs-container-fluid cs-tab-container">
                                <p><?php esc_html_e( 'Existing consent will be invalidated, and your visitors will be asked for consent again. ', 'consent-magic' ); ?></p>
                                <button type="button" class="btn btn-blue cs_renew_consent_cancel"><i
                                            class="icon-restore"></i> <?php esc_html_e( 'Cancel', 'consent-magic' ); ?>
                                </button>
                                <button type="button" class="btn btn-blue cs_renew_consent cs_renew_consent_category"><i
                                            class="icon-renew"></i> <?php esc_html_e( 'Ok', 'consent-magic' ); ?>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="cs_preview_container cs_renew_consent_wrap_new_cat" style="display: none;">
        <div class="cs-info-bar cs-public-cookie-popup popup_small"
             style="box-shadow: rgba(0,0,0,0.5) 0 2px 10px;text-align: center;">
            <div class="cs-modal cs-blowup">
                <div class="cs-modal-dialog" role="document">
                    <div class="cs-modal-content cs-bar-popup">
                        <div class="cs-modal-body">
                            <div class="cs-container-fluid cs-tab-container">
                                <p><?php esc_html_e( 'Existing consent will be invalidated, and your visitors will be asked for consent again. ', 'consent-magic' ); ?></p>
                                <button type="button" class="btn btn-blue cs_renew_consent_cancel_new_cat"><i
                                            class="icon-restore"></i> <?php esc_html_e( 'Cancel', 'consent-magic' ); ?>
                                </button>
                                <button type="button"
                                        class="btn btn-blue cs_renew_consent cs_renew_consent_category_new_cat"><i
                                            class="icon-renew"></i> <?php esc_html_e( 'Ok', 'consent-magic' ); ?>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>