<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    ConsentMagic PRO
 * @subpackage ConsentMagic PRO/includes
 */

namespace ConsentMagicPro;

class CS_Admin {

	/**
	 * The ID of this plugin.
	 */
	public $plugin_name;

	/**
	 * The version of this plugin.
	 */
	public $version;

	public $plugin_obj;

	public $cs_options = array();

	public $data_key;

	public $wc_am_api_key_key;

	public $wc_am_instance_key;

	public $data;

	public $wc_am_instance_id;

	public $wc_am_domain;

	public $wc_am_activated_key;

	public $wc_am_deactivate_checkbox_key;

	public $edd_deactivate_checkbox_key;

	public $product_name;

	public $url_activate;

	public $edd_license_key;

	public $edd_activated_key;

	private $product_id = '';

	protected static $instance;

	public $limit;

	public $offset;

	private $current_lang;

	public static $default_rules = array(
		'cs_gdpr_rule',
		'cs_ccpa_rule',
		'cs_rest_of_world_rule',
	);

	private $adminPagesSlugs = array(
		'consent-magic',
		'cs-proof-consent',
		'cs-geolocation',
		'cs-proof-statistics',
		'cs-settings',
		'cs-additionals',
		'cs-license'
	);

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name = null, $version = null, $plugin_obj = null ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->plugin_obj = $plugin_obj;
		$this->current_lang = get_locale();

		if ( CMPRO_LICENSE_TYPE == 'edd' ) {

			$this->data_key = CMPRO_LICENSE_TYPE . '_' . CMPRO_LICENSE_PLUGIN_NAME;
			$this->product_name = CMPRO_LICENSE_NAME;
			$this->url_activate = 'https://www.pixelyoursite.com';
			$this->edd_deactivate_checkbox_key = $this->data_key . '_deactivate_checkbox';
			$this->edd_license_key = CMPRO_LICENSE_TYPE . '_license_key';
			$this->edd_activated_key = $this->data_key . '_activated';
		} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
			$this->data_key = 'wc_am_client_consent_magic_pro';
			$this->wc_am_api_key_key = $this->data_key . '_api_key';
			$this->wc_am_instance_key = $this->data_key . '_instance';
			$this->wc_am_instance_id = get_option( $this->wc_am_instance_key );
			$this->wc_am_domain = str_ireplace( array(
				'http://',
				'https://'
			), '', home_url() ); // blog domain name
			$this->wc_am_activated_key = $this->data_key . '_activated';
			$this->wc_am_deactivate_checkbox_key = $this->data_key . '_deactivate_checkbox';
			$this->product_id = get_option( 'wc_am_product_id_consent_magic_pro' );
			$this->data = get_option( $this->data_key );
		}

		register_activation_hook( CMPRO_PLUGIN_FILENAME, array(
			$this,
			'activator'
		) );

		$this->cs_cron_check_status_edd();

		if ( wp_doing_ajax() ) {
			add_action( 'wp_ajax_cs_preview_show', array(
				$this,
				'cs_preview_show'
			) );
			add_action( 'wp_ajax_nopriv_cs_preview_show', array(
				$this,
				'cs_preview_show'
			) );

			add_action( 'wp_ajax_preview_list_show', array(
				$this,
				'cs_preview_list_show'
			) );
			add_action( 'wp_ajax_nopriv_preview_list_show', array(
				$this,
				'cs_preview_list_show'
			) );

			add_action( 'wp_ajax_cs_preview_size_show', array(
				$this,
				'cs_preview_size_show'
			) );
			add_action( 'wp_ajax_nopriv_cs_preview_size_show', array(
				$this,
				'cs_preview_size_show'
			) );

			add_action( 'wp_ajax_cs_preview_color_show', array(
				$this,
				'cs_preview_color_show'
			) );
			add_action( 'wp_ajax_nopriv_cs_preview_color_show', array(
				$this,
				'cs_preview_color_show'
			) );

			add_action( 'wp_ajax_cs_renew_consent', array(
				$this,
				'cs_renew_consent'
			) );
			add_action( 'wp_ajax_nopriv_cs_renew_consent', array(
				$this,
				'cs_renew_consent'
			) );


			add_action( 'wp_ajax_item_sort', array(
				$this,
				'cs_save_item_order'
			), 200 );
			add_action( 'wp_ajax_nopriv_item_sort', array(
				$this,
				'cs_save_item_order'
			), 200 );

			add_action( 'wp_ajax_predefined_rule_enable_update', array(
				$this,
				'cs_predefined_rule_enable_update'
			), 200 );
			add_action( 'wp_ajax_nopriv_predefined_rule_enable_update', array(
				$this,
				'cs_predefined_rule_enable_update'
			), 200 );

			add_action( 'wp_ajax_no_ip_rule_update', array(
				$this,
				'cs_no_ip_rule_update'
			), 200 );
			add_action( 'wp_ajax_nopriv_no_ip_rule_update', array(
				$this,
				'cs_no_ip_rule_update'
			), 200 );

			add_action( 'wp_ajax_cs_update_primary_rule', array(
				$this,
				'cs_update_primary_rule'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_update_primary_rule', array(
				$this,
				'cs_update_primary_rule'
			), 200 );

			add_action( 'wp_ajax_cs_force_update', array(
				$this,
				'cs_force_update'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_force_update', array(
				$this,
				'cs_force_update'
			), 200 );

			add_action( 'wp_ajax_cs_instance_update', array(
				$this,
				'cs_instance_update'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_instance_update', array(
				$this,
				'cs_instance_update'
			), 200 );

			add_action( 'wp_ajax_get_proof_consent_data', array(
				$this,
				'get_proof_consent_data'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_proof_consent_data', array(
				$this,
				'get_proof_consent_data'
			), 200 );

			add_action( 'wp_ajax_get_ignore_ip_table', array(
				$this,
				'get_ignore_ip_table'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_ignore_ip_table', array(
				$this,
				'get_ignore_ip_table'
			), 200 );

			add_action( 'wp_ajax_remove_ignore_ip_table', array(
				$this,
				'remove_ignore_ip_table'
			), 200 );
			add_action( 'wp_ajax_nopriv_remove_ignore_ip_table', array(
				$this,
				'remove_ignore_ip_table'
			), 200 );

			add_action( 'wp_ajax_cs_new_ignore_ip', array(
				$this,
				'cs_new_ignore_ip'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_new_ignore_ip', array(
				$this,
				'cs_new_ignore_ip'
			), 200 );

			add_action( 'wp_ajax_get_manual_added_cookies', array(
				$this,
				'get_manual_added_cookies'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_manual_added_cookies', array(
				$this,
				'get_manual_added_cookies'
			), 200 );

			add_action( 'wp_ajax_get_manual_added_scripts', array(
				$this,
				'get_manual_added_scripts'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_manual_added_scripts', array(
				$this,
				'get_manual_added_scripts'
			), 200 );

			add_action( 'wp_ajax_get_scan_cookies', array(
				$this,
				'get_scan_cookies'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_scan_cookies', array(
				$this,
				'get_scan_cookies'
			), 200 );

			add_action( 'wp_ajax_get_scan_scripts', array(
				$this,
				'get_scan_scripts'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_scan_scripts', array(
				$this,
				'get_scan_scripts'
			), 200 );

			add_action( 'wp_ajax_cs_save_scan_data', array(
				$this,
				'save_scan_data'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_save_scan_data', array(
				$this,
				'save_scan_data'
			), 200 );

			add_action( 'wp_ajax_get_proof_rules_stats_data', array(
				$this,
				'get_proof_rules_stats_data'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_proof_rules_stats_data', array(
				$this,
				'get_proof_rules_stats_data'
			), 200 );

			add_action( 'wp_ajax_get_proof_cs_type_stats_data', array(
				$this,
				'get_proof_cs_type_stats_data'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_proof_cs_type_stats_data', array(
				$this,
				'get_proof_cs_type_stats_data'
			), 200 );

			add_action( 'wp_ajax_get_proof_global_stats_data', array(
				$this,
				'get_proof_global_stats_data'
			), 200 );
			add_action( 'wp_ajax_nopriv_get_proof_global_stats_data', array(
				$this,
				'get_proof_global_stats_data'
			), 200 );

			add_action( 'wp_ajax_cs_export_proof_consent', array(
				$this,
				'cs_export_proof_consent'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_export_proof_consent', array(
				$this,
				'cs_export_proof_consent'
			), 200 );
			add_action( 'wp_ajax_cs_export_proof_consent_done', array(
				$this,
				'cs_export_proof_consent_done'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_export_proof_consent_done', array(
				$this,
				'cs_export_proof_consent_done'
			), 200 );

			add_action( 'wp_ajax_cs_update_scan_page', array(
				$this,
				'cs_update_scan_page'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_update_scan_page', array(
				$this,
				'cs_update_scan_page'
			), 200 );

			add_action( 'wp_ajax_cs_delete_lang', array(
				$this,
				'cs_delete_lang'
			), 200 );
			add_action( 'wp_ajax_nopriv_cs_delete_lang', array(
				$this,
				'cs_delete_lang'
			), 200 );
			add_action( 'wp_ajax_cs_check_geo_license', array(
				$this,
				'cs_check_geo_license'
			), 200 );
			add_action( 'wp_ajax_cs_load_langs', array(
				$this,
				'cs_load_langs'
			), 200 );
		}

		if ( is_plugin_activated() ) {
			add_action( 'admin_bar_menu', array(
				$this,
				'cs_admin_bar_delete_test_button'
			), 200 );
			add_action( 'admin_bar_menu', array(
				$this,
				'cs_admin_bar_clear_test_consent'
			), 200 );
		}

		// hook that function onto our scheduled event:
		add_action( 'cs_db_cron_update_hook', array(
			$this,
			'cs_force_update'
		), 200 );
		add_action( 'cs_db_cron_update_hook_one_time', array(
			$this,
			'cs_force_update'
		), 200, 1 );

		add_filter( 'cron_schedules', array(
			$this,
			'custom_cron_job_recurrence'
		), 200 );
		add_action( 'admin_enqueue_scripts', array(
			$this,
			'load_media_files'
		), 200 );

		if ( CMPRO_LICENSE_TYPE == 'edd' ) {
			add_action( 'cs_cron_check_status_edd_hook', array(
				$this,
				'cs_cron_check_edd_status'
			), 200 );
		} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
			add_action( 'cs_cron_check_status_hook', array(
				$this,
				'cs_cron_check_status'
			), 200 );
		}

	}

	public function load_media_files() {
		wp_enqueue_media();
	}

	/**
	 * Register the stylesheets for the admin area.
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in CS_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The ConsentMagic will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( in_array( getCurrentAdminPage(), $this->adminPagesSlugs ) ) {

			wp_enqueue_style( 'datatables', CMPRO_PLUGIN_URL . "css/datatables.min.css", array(), CMPRO_LATEST_VERSION_NUMBER );
			wp_enqueue_style( 'daterangepicker', CMPRO_PLUGIN_URL . "css/datarangepicker.min.css", array(), CMPRO_LATEST_VERSION_NUMBER );
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_style( 'code-editor' );
			wp_enqueue_style( 'CS-Style', CMPRO_PLUGIN_URL . "assets/css/style-admin.min.css", array(), CMPRO_LATEST_VERSION_NUMBER );
			wp_enqueue_style( $this->plugin_name . '-select2', CMPRO_PLUGIN_URL . "css/select2.min.css", array(), CMPRO_LATEST_VERSION_NUMBER );
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in CS_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The ConsentMagic will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( 'CS-Magic-notice', CMPRO_PLUGIN_URL . 'js/cs-notice.js', array(
			'jquery'
		), null, false );

		wp_localize_script( 'CS-Magic-notice', 'ajax_object', array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'nonce'   => wp_create_nonce( 'cs-ajax-nonce' )
		) );

		if ( in_array( getCurrentAdminPage(), $this->adminPagesSlugs ) ) {

			wp_enqueue_script( 'moment' );
			wp_enqueue_script( 'datarangepicker', CMPRO_PLUGIN_URL . 'js/datarangepicker.min.js', array( 'jquery' ), CMPRO_LATEST_VERSION_NUMBER, true );
			wp_enqueue_script( 'data-tables', CMPRO_PLUGIN_URL . 'js/data-tables.min.js', array( 'jquery' ), CMPRO_LATEST_VERSION_NUMBER, true );
			wp_enqueue_script( 'code-editor' );
			wp_enqueue_script( 'CS-Select2', CMPRO_PLUGIN_URL . 'js/select2.min.js', array( 'jquery' ), CMPRO_LATEST_VERSION_NUMBER, true );
			wp_enqueue_script( 'CS-jquery-ui', CMPRO_PLUGIN_URL . 'js/jquery-ui.min.js', array( 'jquery' ), CMPRO_LATEST_VERSION_NUMBER, true );
			wp_enqueue_script( 'CS-Magic', CMPRO_PLUGIN_URL . 'js/cs-admin.js', array(
				'jquery',
				'wp-color-picker'
			), time(), time() );
			wp_enqueue_script( 'CS-Magic-Tables', CMPRO_PLUGIN_URL . 'js/tables-functions.js', array(
				'jquery'
			), null, false );
			$cs_settings[ 'codeEditor' ] = wp_enqueue_code_editor( [ 'type' => 'text/html' ] );
			wp_localize_script( 'code-editor', 'cs_settings', $cs_settings );
			wp_localize_script( 'CS-Magic', 'ajax_object', array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce'   => wp_create_nonce( 'cs-ajax-nonce' )
			) );
			wp_localize_script( 'CS-Magic-Tables', 'ajax_object', array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce'   => wp_create_nonce( 'cs-ajax-nonce' )
			) );
		}
	}

	function cs_export_proof_consent() {

		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );

		global $wpdb;
		$table = $wpdb->prefix . 'cs_proof_consent';
		$submit = ( isset( $_POST[ 'submit' ] ) && !empty( $_POST[ 'submit' ] ) ) ? sanitize_text_field( $_POST[ 'submit' ] ) : false;
		$this->offset = intval( sanitize_text_field( $_POST[ 'offset' ] ) );
		$this->limit = intval( sanitize_text_field( $_POST[ 'limit' ] ) );

		$step_data = array();

		$export_keys = array(
			'UUID'         => 'uuid',
			'Time'         => 'created_at',
			'URL'          => 'url',
			'IP'           => 'ip',
			'User'         => 'email',
			'User profile' => 'profile',
			'Rule'         => 'rule',
			'Consent type' => 'consent_type',
			'Consents'     => 'category',
			'Action'       => 'current_action',
		);

		if ( $this->limit == 'undefined' || $this->limit == 0 ) {
			$this->limit = 100;
			$this->clear_export_proof_consent( $export_keys, 'export_proof_consent.csv' );
		}

		$query_from = $wpdb->prepare( 'FROM %1$s WHERE 1=1 ', $table );
		$consent_array = $wpdb->get_results( $wpdb->prepare( 'SELECT * %1$s LIMIT %2$d OFFSET %3$d', $query_from, $this->limit, $this->offset ) );

		$total_consent_number = $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s', $table ) );

		$array = [];
		foreach ( $consent_array as $item ) {
			$array[ 'UUID' ] = $item->uuid;
			$array[ 'Time' ] = $item->created_at;
			$array[ 'URL' ] = $item->url;
			$array[ 'IP' ] = $item->ip;
			$array[ 'User' ] = $item->email;
			$array[ 'User profile' ] = wp_strip_all_tags( $item->profile );
			$array[ 'Rule' ] = $item->rule;
			$array[ 'Consent type' ] = $item->consent_type;
			$array[ 'Consents' ] = strip_tags( $item->category );
			$array[ 'Action' ] = $item->current_action;
			array_push( $step_data, $array );
		}

		$new_offset = $this->offset + $this->limit;

		if ( ( $total_consent_number - $new_offset ) < $this->limit ) {
			$this->limit = $total_consent_number - $new_offset;
		}

		$data_result = array(
			"limit"                 => "$this->limit",
			"offset"                => "$new_offset",
			"total_products_number" => $total_consent_number,
			"loop"                  => ( $new_offset < $total_consent_number ) ? "1" : "0",
			"step_data"             => $step_data,
			"file_url"              => $this->export_proof_consent( $step_data, $export_keys, 'export_proof_consent.csv' ),
		);

		if ( ( $new_offset >= $total_consent_number ) && ( $submit == 'true' ) ) {
			$table = $wpdb->prefix . 'cs_proof_consent';
			$delete = $wpdb->query( $wpdb->prepare( 'DELETE FROM %1$s', $table ) );
			$this->renew_consent_run();
		}

		wp_send_json( $data_result );
	}

	function cs_export_proof_consent_done() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );
		unlink( CMPRO_PLUGIN_PATH . 'export_proof_consent.csv' );
	}

	function clear_export_proof_consent( $export_keys, $file_name ) {

		$file = CMPRO_PLUGIN_PATH . $file_name;
		$file_url = CMPRO_PLUGIN_URL . $file_name;
		# Generate CSV data from array
		$fh = fopen( $file, 'w' );
		# to use memory instead
		# write out the headers
		fputcsv( $fh, $export_keys, ";" );
		fclose( $fh );

		return $file_url;
	}

	function export_proof_consent( $items, $export_keys, $file_name ) {

		$file = CMPRO_PLUGIN_PATH . $file_name;
		$file_url = CMPRO_PLUGIN_URL . $file_name;
		# Generate CSV data from array
		$fh = fopen( $file, 'a+' );
		# to use memory instead

		# write out the headers
		foreach ( $items as $item ) {
			unset( $csv_line );
			foreach ( $export_keys as $key => $value ) {
				if ( isset( $item[ $key ] ) ) {
					$csv_line[] = $item[ $key ];
				}
			}
			if ( isset( $csv_line ) ) {
				fputcsv( $fh, $csv_line, ";" );
			}
		}
		fclose( $fh );

		return $file_url;
	}

	function get_proof_consent_data() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_proof_consent';

		$cs_proof_consent = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s', $table_name ) );

		$json_data = array(
			"draw" => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"data" => $cs_proof_consent
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function get_ignore_ip_table() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_unblock_ip';

		## Date search value
		$searchByFromdate = sanitize_text_field( $_POST[ 'searchByFromdate' ] );
		$searchByTodate = sanitize_text_field( $_POST[ 'searchByTodate' ] );

		$searchByFromdate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByFromdate ) ) );
		$searchByTodate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByTodate ) . ' +1 day' ) );

		$table_data = array();
		## Total number of records without filtering
		if ( $searchByFromdate != '' && $searchByTodate != '' ) {
			$ips = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s WHERE 1 AND `created_at` <= \'%2$s\' AND `created_at` >= \'%3$s\'', $table_name, $searchByTodate_sql, $searchByFromdate_sql ) );
			$totalRecords = count( $ips );
			$totalRecordwithFilter = count( $ips );
		} else {
			$ips = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s', $table_name ) );
			$totalRecords = count( $ips );
			$totalRecordwithFilter = count( $ips );
		}
		if ( $ips ) {
			foreach ( $ips as $ip ) {
				$id = $ip->id;
				if ( $searchByFromdate != '' && $searchByTodate != '' ) {
					$data = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s WHERE `id` = %2$d AND `created_at` <= \'%3$s\' AND `created_at` >= \'%4$s\'', $table_name, $id, $searchByTodate_sql, $searchByFromdate_sql ) );
					$table_data[] = array(
						'id'         => $data[ 0 ]->id,
						'ip'         => $data[ 0 ]->ip,
						'created_at' => $data[ 0 ]->created_at,
					);
				} else {
					$data = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s WHERE `id` = %2$d', $table_name, $id ) );
					$table_data[] = array(
						'id'         => $data[ 0 ]->id,
						'ip'         => $data[ 0 ]->ip,
						'created_at' => $data[ 0 ]->created_at,
					);
				}
			}
		}

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function remove_ignore_ip_table() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );
		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_unblock_ip';
		$id = sanitize_text_field( $_POST[ 'id' ] );

		$ips = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s WHERE `id` = %2$d', $table_name, $id ) );

		if ( $ips ) {
			$wpdb->get_results( $wpdb->prepare( 'DELETE FROM %1$s WHERE `id` = %2$d', $table_name, $id ) );
		}

		wp_die(); //to remove that 0 response
	}

	function cs_new_ignore_ip() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );
		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_unblock_ip';
		$ignore_ip = isset( $_POST[ 'ignore_ip' ] ) ? sanitize_text_field( $_POST[ 'ignore_ip' ] ) : false;
		$check_duplicate = false;

		if ( $ignore_ip ) {
			$like = '%' . $wpdb->esc_like( $ignore_ip ) . '%';
			$check_duplicate = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM %1$s WHERE `ip` LIKE \'%2$s\'', $table_name, $like ) );
		}

		if ( $check_duplicate ) {
			wp_send_json_error();
		} else {
			$data = array(
				'ip'         => $wpdb->prepare( '%s', $ignore_ip ),
				'created_at' => current_time( 'mysql' ),
			);
			$wpdb->insert( $table_name, $data );
			wp_send_json_success();
		}
	}

	function get_manual_added_cookies() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		$table_data = get_custom_cookies_list();

		$totalRecords = count( $table_data );
		$totalRecordwithFilter = count( $table_data );

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function get_scan_cookies() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		$table_data = get_scan_cookies_list();
		$result_data = array();
		$temp_data_unassigned = array();
		$temp_data_other = array();

		if ( $table_data ) {

			foreach ( $table_data as $item ) {
				if ( $item[ 'term_slug' ] === 'unassigned' ) {
					$temp_data_unassigned[] = $item;
				} else {
					$temp_data_other[] = $item;
				}
			}
		}

		if ( $temp_data_unassigned ) {
			foreach ( $temp_data_unassigned as $item ) {
				array_push( $result_data, $item );
			}
		}

		if ( $temp_data_other ) {
			foreach ( $temp_data_other as $item ) {
				array_push( $result_data, $item );
			}
		}

		$totalRecords = count( $table_data );
		$totalRecordwithFilter = count( $table_data );

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $result_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function get_scan_scripts() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		$table_data = get_scan_scripts_list();

		$totalRecords = count( $table_data );
		$totalRecordwithFilter = count( $table_data );

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function cs_update_scan_page() {
		check_ajax_referer( 'cs_scanner', 'security' );

		$cs_scan_existing_page = sanitize_text_field( $_POST[ 'cs_scan_existing_page' ] );

		update_option( 'cs_auto_scan_type', $cs_scan_existing_page );

		$return = array(
			'message' => 'cs_auto_scan_type updated',
			'ID'      => $cs_scan_existing_page
		);

		wp_send_json_success( $return );
	}

	function save_scan_data() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );
		$cookie_id = isset( $_POST[ 'cookie_id' ] ) ? sanitize_text_field( $_POST[ 'cookie_id' ] ) : null;
		$script_id = isset( $_POST[ 'script_id' ] ) ? sanitize_text_field( $_POST[ 'script_id' ] ) : null;
		$descr_text = isset( $_POST[ 'descr_text' ] ) ? wp_kses_post( wp_unslash( $_POST[ 'descr_text' ] ) ) : null;

		if ( $cookie_id ) {
			$data_arr = array(
				"description" => $descr_text
			);
			$update = update_scan_cookie_data( $cookie_id, $data_arr );
		}

		if ( $script_id ) {
			$data_arr = array(
				"description" => $descr_text
			);
			$update = update_scan_script_data( $script_id, $data_arr );

			if ( !$update ) {
				$template_data = array(
					'ID'         => $script_id,
					'meta_input' => array(
						'cs_default_script_desc' => $descr_text
					)
				);

				wp_update_post( $template_data );
			}
		}

		$response = array( 'success' => true );

		wp_send_json_success( $response );
	}

	function get_manual_added_scripts() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		$table_data = get_custom_scripts_list();

		$totalRecords = count( $table_data );
		$totalRecordwithFilter = count( $table_data );

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function get_proof_rules_stats_data() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_stats_consent';

		## Date search value
		$searchByFromdate = sanitize_text_field( $_POST[ 'searchByFromdate' ] );
		$searchByTodate = sanitize_text_field( $_POST[ 'searchByTodate' ] );

		$searchByFromdate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByFromdate ) ) );
		$searchByTodate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByTodate ) . ' +1 day' ) );

		$table_data = array();
		## Total number of records without filtering
		if ( $searchByFromdate != '' && $searchByTodate != '' ) {
			$proof_rules = $wpdb->get_results( $wpdb->prepare( 'SELECT DISTINCT `rule_id` FROM %1$s WHERE 1 AND `created_at` <= \'%2$s\' AND `created_at` >= \'%3$s\'', $table_name, $searchByTodate_sql, $searchByFromdate_sql ) );
			$totalRecords = count( $proof_rules );
			$totalRecordwithFilter = count( $proof_rules );
		} else {
			$proof_rules = $wpdb->get_results( $wpdb->prepare( 'SELECT DISTINCT `rule_id` FROM %1$s', $table_name ) );
			$totalRecords = count( $proof_rules );
			$totalRecordwithFilter = count( $proof_rules );
		}
		if ( $proof_rules ) {
			foreach ( $proof_rules as $rule ) {
				$rule_id = $rule->rule_id;
				$rule_name = $wpdb->get_var( $wpdb->prepare( 'SELECT `rule` FROM %1$s WHERE `rule_id` = %2$d', $table_name, $rule_id ) );

				if ( $searchByFromdate != '' && $searchByTodate != '' ) {
					$table_data[] = array(
						'rule_name'       => $rule_name,
						'allow_all'       => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\' 
                					AND `created_at` >= \'%5$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Allow all' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'disallow_all'    => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\' 
                					AND `created_at` >= \'%5$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Disable all' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'close_on_scroll' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\' 
                					AND `created_at` >= \'%5$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Close on Scroll' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'confirm_choices' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\' 
                					AND `created_at` >= \'%5$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Confirm my choices' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'close_consent'   => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\' 
                					AND `created_at` >= \'%5$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Close consent' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'close_opt_popup' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\' 
                					AND `created_at` >= \'%5$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Close Options Popup' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
					);
				} else {
					$table_data[] = array(
						'rule_name'       => $rule_name,
						'allow_all'       => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Allow all' ) . '%' ) ),
						'disallow_all'    => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Disable all' ) . '%' ) ),
						'close_on_scroll' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Close on Scroll' ) . '%' ) ),
						'confirm_choices' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Confirm my choices' ) . '%' ) ),
						'close_consent'   => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Close consent' ) . '%' ) ),
						'close_opt_popup' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `rule_id` = \'%2$d\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule_id, '%' . $wpdb->esc_like( 'Close Options Popup' ) . '%' ) ),
					);
				}
			}
		}

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function get_proof_cs_type_stats_data() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_stats_consent';
		$totalRecords = 3;
		$totalRecordwithFilter = 3;
		## Date search value
		$searchByFromdate = sanitize_text_field( $_POST[ 'searchByFromdate' ] );
		$searchByTodate = sanitize_text_field( $_POST[ 'searchByTodate' ] );

		$searchByFromdate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByFromdate ) ) );
		$searchByTodate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByTodate ) . ' +1 day' ) );
		$proof_type = array(
			'Just inform',
			'Inform and Opt-out',
			'Ask before tracking'
		);
		$table_data = array();

		if ( $proof_type ) {
			foreach ( $proof_type as $rule ) {

				if ( $searchByFromdate != '' && $searchByTodate != '' ) {
					$table_data[] = array(
						'consent_type'    => $rule,
						'allow_all'       => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `consent_type` = \'%2$s\'
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\'
                					AND `created_at` >= \'%5$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Allow all' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'disallow_all'    => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `consent_type` = \'%2$s\'
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\'
                					AND `created_at` >= \'%5$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Disable all' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'close_on_scroll' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `consent_type` = \'%2$s\'
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\'
                					AND `created_at` >= \'%5$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Close on Scroll' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'confirm_choices' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `consent_type` = \'%2$s\'
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\'
                					AND `created_at` >= \'%5$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Confirm my choices' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'close_consent'   => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `consent_type` = \'%2$s\'
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\'
                					AND `created_at` >= \'%5$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Close consent' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
						'close_opt_popup' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `consent_type` = \'%2$s\'
                					AND `current_action` LIKE \'%3$s\'
                					AND `created_at` <= \'%4$s\'
                					AND `created_at` >= \'%5$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Close Options Popup' ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
					);
				} else {
					$table_data[] = array(
						'consent_type'    => $rule,
						'allow_all'       => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `consent_type` = \'%2$s\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Allow all' ) . '%' ) ),
						'disallow_all'    => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `consent_type` = \'%2$s\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Disable all' ) . '%' ) ),
						'close_on_scroll' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `consent_type` = \'%2$s\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Close on Scroll' ) . '%' ) ),
						'confirm_choices' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `consent_type` = \'%2$s\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Confirm my choices' ) . '%' ) ),
						'close_consent'   => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `consent_type` = \'%2$s\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Close consent' ) . '%' ) ),
						'close_opt_popup' => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s 
                					WHERE `consent_type` = \'%2$s\' 
                					AND `current_action` LIKE \'%3$s\'', $table_name, $rule, '%' . $wpdb->esc_like( 'Close Options Popup' ) . '%' ) ),
					);
				}
			}
		}

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function get_proof_global_stats_data() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code', false );

		array_walk( $_REQUEST, array(
			ConsentMagic(),
			'cs_sanitize_array'
		) );
		$request_escaped = $_REQUEST;

		global $wpdb;
		$table_name = $wpdb->prefix . 'cs_stats_consent';
		$totalRecords = 4;
		$totalRecordwithFilter = 4;
		## Date search value
		$searchByFromdate = sanitize_text_field( $_POST[ 'searchByFromdate' ] );
		$searchByTodate = sanitize_text_field( $_POST[ 'searchByTodate' ] );

		$searchByFromdate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByFromdate ) ) );
		$searchByTodate_sql = gmdate( 'Y-m-d H:i:s', strtotime( str_replace( '-', '/', $searchByTodate ) . ' +1 day' ) );
		$actions = array(
			'Allow All',
			'Disable all',
			'Close on scroll',
			'Confirm my choices',
			'Close consent',
			'Close Options Popup'
		);
		$table_data = array();

		if ( $actions ) {
			foreach ( $actions as $action ) {

				if ( $searchByFromdate != '' && $searchByTodate != '' ) {
					$table_data[] = array(
						'action' => $action,
						'count'  => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `current_action` LIKE \'%2$s\'
                					AND `created_at` <= \'%3$s\'
                					AND `created_at` >= \'%4$s\'', $table_name, '%' . $wpdb->esc_like( $action ) . '%', $searchByTodate_sql, $searchByFromdate_sql ) ),
					);
				} else {
					$table_data[] = array(
						'action' => $action,
						'count'  => $wpdb->get_var( $wpdb->prepare( 'SELECT COUNT(*) FROM %1$s
                					WHERE `current_action` LIKE \'%2$s\'', $table_name, '%' . $wpdb->esc_like( $action ) . '%' ) ),
					);
				}
			}
		}

		$json_data = array(
			"draw"                 => intval( ( isset( $request_escaped[ "draw" ] ) ? $request_escaped[ "draw" ] : 0 ) ),
			"iTotalRecords"        => $totalRecords,
			"iTotalDisplayRecords" => $totalRecordwithFilter,
			"aaData"               => $table_data
		);

		echo json_encode( $json_data );
		wp_die(); //to remove that 0 response
	}

	function cs_cron_check_status() {

		if ( CMPRO_LICENSE_TYPE == 'edd' ) {
			$license_status = $this->edd_license_key_status();
			db_cron_update();

			if ( isset( $license_status[ 'success' ] ) && isset( $license_status[ 'license' ] ) ) {
				if ( $license_status[ 'success' ] === false && $license_status[ 'license' ] === 'invalid' ) {
					update_option( $this->edd_activated_key, 'Deactivated' );
					update_option( $this->edd_deactivate_checkbox_key, 'on' );
					update_option( $this->edd_license_key, '' );
				}
			}
		} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
			$license_status = $this->license_key_status();
			db_cron_update();

			if ( isset( $license_status[ 'status_check' ] ) && $license_status[ 'status_check' ] == 'inactive' ) {
				update_option( 'wc_am_client_consent_magic_pro_activated', 'Canceled' );
			}
			if ( isset( $license_status[ 'code' ] ) && $license_status[ 'code' ] == '100' ) {
				update_option( 'wc_am_client_consent_magic_pro_activated', 'Expired' );
			}
		}
	}

	/**
	 * Deletes all data if plugin deactivated
	 */
	public function cs_instance_update() {

		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );

		update_option( 'wc_am_client_consent_magic_pro_instance', wp_generate_password( 12, false ) );
		delete_option( 'wc_am_client_consent_magic_pro_activated' );
		delete_option( 'wc_am_client_consent_magic_pro' );
		delete_option( 'wc_am_client_consent_magic_pro_deactivate_checkbox' );
		delete_option( 'edd_license_key' );
		delete_option( 'edd_consent_magic_pro' );
		delete_option( 'edd_consent_magic_pro_activated' );
		delete_option( 'edd_consent_magic_pro_deactivate_checkbox' );
		wp_die();
	}

	// Custom Cron Recurrences
	function custom_cron_job_recurrence( $schedules ) {

		$schedules[ 'daily' ] = array(
			'display'  => esc_html__( 'Once a week', 'consent-magic' ),
			'interval' => 86400,
		);

		$schedules[ 'weekly' ] = array(
			'display'  => esc_html__( 'Once a week', 'consent-magic' ),
			'interval' => 604800,
		);

		$schedules[ 'monthly' ] = array(
			'display'  => esc_html__( 'Once a month', 'consent-magic' ),
			'interval' => 2635200,
		);

		$schedules[ 'one_half_year' ] = array(
			'display'  => esc_html__( 'Once time in half a year', 'consent-magic' ),
			'interval' => 15768000,
		);

		$schedules[ 'yearly' ] = array(
			'display'  => esc_html__( 'Once a year', 'consent-magic' ),
			'interval' => 31536000,
		);

		return $schedules;
	}

	public function get_plugin_options() {

		return ConsentMagic()->cs_options;
	}

	function cs_save_item_order() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		$order_post = ( isset( $_POST[ 'order' ] ) && !empty( (int) $_POST[ 'order' ] ) ) ? sanitize_text_field( $_POST[ 'order' ] ) : array();

		$order = explode( ',', $order_post );

		$counter = 0;
		foreach ( $order as $item_id ) {
			update_post_meta( $item_id, '_cs_order', $counter );
			$counter++;
		}

		$this->change_active_rule();

		$data = array(
			'order' => $order
		);
		wp_send_json_success( $data );
	}

	function cs_predefined_rule_enable_update() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		$id = ( isset( $_POST[ 'id' ] ) && !empty( (int) $_POST[ 'id' ] ) ) ? (int) sanitize_text_field( $_POST[ 'id' ] ) : null;

		$active = ( isset( $_POST[ 'active' ] ) && !empty( $_POST[ 'active' ] ) ) ? sanitize_text_field( $_POST[ 'active' ] ) : 0;

		update_post_meta( $id, '_cs_enable_rule', "$active" );
		$data = array(
			'id'     => $id,
			'active' => $active
		);
		wp_send_json_success( $data );
	}

	function cs_no_ip_rule_update() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		$id = ( isset( $_POST[ 'id' ] ) && !empty( (int) $_POST[ 'id' ] ) ) ? (int) sanitize_text_field( $_POST[ 'id' ] ) : null;

		$active = ( isset( $_POST[ 'active' ] ) && !empty( $_POST[ 'active' ] ) ) ? sanitize_text_field( $_POST[ 'active' ] ) : 0;

		update_post_meta( $id, '_cs_no_ip_rule', "$active" );
		$data = array(
			'id'     => $id,
			'active' => $active
		);
		wp_send_json_success( $data );
	}

	function cs_update_primary_rule() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		foreach ( $_POST as $item_name => $val ) {
			if ( isset( $_POST[ 'cs_rule_id' ] ) && get_post_meta( sanitize_text_field( $_POST[ 'cs_rule_id' ] ), sanitize_text_field( $item_name ) ) ) {
				update_post_meta( sanitize_text_field( $_POST[ 'cs_rule_id' ] ), sanitize_text_field( $item_name ), sanitize_text_field( $val ) );
			}
		}

		wp_send_json_success();
	}

	public function change_active_rule() {
		$args_posts = array(
			'post_type'      => CMPRO_POST_TYPE,
			'post_status'    => 'publish',
			'meta_query'     => [
				[
					'key'   => '_cs_enable_rule',
					'value' => 1,
				]
			],
			'posts_per_page' => 1,
			'order'          => 'ASC',
			'meta_key'       => '_cs_order',
			'orderby'        => 'meta_value_num',
			'meta_type'      => 'NUMERIC',
		);
		$rules = get_posts( $args_posts );

		if ( $rules != false && !empty( $rules ) ) {
			update_option( 'cs_active_rule_id', $rules[ 0 ]->ID );
		} else {
			update_option( 'cs_active_rule_id', '' );
		}
	}

	public function change_rule_order_admin( $rule_id ) {
		$args_posts = array(
			'post_type'      => CMPRO_POST_TYPE,
			'post_status'    => 'publish',
			'include'        => array( $rule_id ),
			'posts_per_page' => 1,
		);
		$rule_first = get_posts( $args_posts );

		$args_posts = array(
			'post_type'      => CMPRO_POST_TYPE,
			'post_status'    => 'publish',
			'posts_per_page' => -1,
			'order'          => 'ASC',
			'exclude'        => $rule_id

		);
		$rule_other = get_posts( $args_posts );

		if ( $rule_first != false && !empty( $rule_first ) ) {
			$counter = 0;
			update_post_meta( $rule_first[ 0 ]->ID, '_cs_order', $counter );

			$counter++;
			if ( $rule_other != false && !empty( $rule_other ) ) {
				foreach ( $rule_other as $rule ) {
					update_post_meta( $rule->ID, '_cs_order', $counter );
					$counter++;
				}
			}
		}
	}

	function cs_admin_bar_delete_test_button( $wp_admin_bar ) {
		$cs_options = $this->get_plugin_options();
		if ( $cs_options[ 'cs_test_mode' ] ) {
			$wp_admin_bar->add_menu( array(
				'id'    => 'delete_test_consent',
				'title' => __( 'Disable ConsentMagic test mode', 'consent-magic' ),
				'href'  => wp_nonce_url( admin_url( 'admin.php?page=cs-settings' ) . '&cs_update_action=cs_test_mode_disable', 'cs-update-' . CMPRO_SETTINGS_FIELD ),
			) );
		}
	}

	function cs_admin_bar_clear_test_consent( $wp_admin_bar ) {
		$cs_options = $this->get_plugin_options();
		if ( $cs_options[ 'cs_test_mode' ] ) {
			$wp_admin_bar->add_menu( array(
				'id'    => 'cs_test_consent_clear',
				'title' => __( 'Delete test consent', 'consent-magic' ),
				'href'  => wp_nonce_url( admin_url( 'admin.php?page=cs-settings' ) . '&cs_update_action=cs_test_consent_clear', 'cs-update-' . CMPRO_SETTINGS_FIELD ),
			) );
		}
	}

	function cs_force_update( $first_time = false ) {

		if ( !wp_doing_cron() ) {
			check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );
		}

		if ( ( (int) ConsentMagic()->getOption( 'cs_geolocation' ) === 1 && ConsentMagic()->getOption( 'cs_geo_activated' ) == true ) || $first_time ) {
			$message = $this->cs_force_update_runner();
		} else {

			if ( (int) ConsentMagic()->getOption( 'cs_geolocation' ) === 0 ) {
				$message = '<span style="color:#f30000;margin-left: 15px;"><strong>' . esc_html__( 'Geolocation is deactivated. Please, enable it.', 'consent-magic' ) . '</strong></span>';
			} elseif ( ConsentMagic()->getOption( 'cs_geo_activated' ) == false ) {
				$message = '<span style="color:#f30000;margin-left: 15px;"><strong>' . esc_html__( 'The MaxMind license key is invalid.', 'consent-magic' ) . '</strong></span>';
			}
		}

		if ( wp_doing_ajax() ) {
			$data = array(
				'message' => $message,
			);
			wp_send_json_success( $data );
			wp_die();
		}
	}

	/**
	 * Force update geolocation DB runner
	 * @return string
	 */
	public function cs_force_update_runner() {
		$cs_geo = new CS_Geoip;
		$message = '';
		foreach ( $cs_geo->databases as $database ) {
			$result = $cs_geo->update_database( $database );
			if ( is_wp_error( $result ) ) {
				$message = '<span style="color:#f30000;margin-left: 15px;"><strong>' . $result->get_error_message( 'geo_error' ) . '</strong></span>';
				break;
			} else {
				$message = '<span style="color:#00a125;margin-left: 15px;"><strong>' . esc_html__( 'Geo Database updated successfully', 'consent-magic' ) . '</strong></span>';
			}
		}

		return $message;
	}

	public function activator() {
		$privacy_settings = get_option( 'cs_privacy_overview_content_settings' );
		$privacy_defaults = array(
			'privacy_overview_content' => esc_html__( 'This website uses cookies to improve your experience while you navigate through the website. Out of these cookies, the cookies that are categorized as necessary are stored on your browser as they are essential for the working of basic functionalities of the website. We also use third-party cookies that help us analyze and understand how you use this website. These cookies will be stored in your browser only with your consent. You also have the option to opt-out of these cookies. But opting out of some of these cookies may have an effect on your browsing experience.', 'consent-magic' ),
			'privacy_overview_title'   => esc_html__( 'Privacy Overview', 'consent-magic' )
		);
		( $privacy_settings === false ) ? update_option( 'cs_privacy_overview_content_settings', $privacy_defaults ) : false;
	}

	/**
	 * Registers menu options
	 * Hooked into admin_menu
	 */
	public function admin_menu() {
		global $submenu;

		if ( is_plugin_activated() ) {
			add_menu_page( 'ConsentMagic', 'ConsentMagic', 'manage_cs', 'consent-magic', array(
				$this,
				'adminPageMain'
			), CMPRO_PLUGIN_URL . '/assets/images/cm_icon.png' );

			add_submenu_page( 'consent-magic', 'Settings', 'Settings', 'manage_cs', 'cs-settings', array(
				$this,
				'adminPageSettings'
			) );

			add_submenu_page( 'consent-magic', 'Geolocation', 'Geolocation', 'manage_cs', 'cs-geolocation', array(
				$this,
				'adminPageGeolocation'
			) );

			add_submenu_page( 'consent-magic', 'Proof of consent storage', 'Consent Proof', 'manage_cs', 'cs-proof-consent', array(
				$this,
				'adminPageProofConsent'
			) );

			add_submenu_page( 'consent-magic', 'Proof of consent Statistics', 'Statistics', 'manage_cs', 'cs-proof-statistics', array(
				$this,
				'adminPageProofStatistics'
			) );

			add_submenu_page( 'consent-magic', 'Shortcodes & Filters', 'Shortcodes & Filters', 'manage_cs', 'cs-additionals', array(
				$this,
				'adminPageAdditionals'
			) );

			add_submenu_page( 'consent-magic', 'License', 'License', 'manage_cs', 'cs-license', array(
				$this,
				'config_page'
			) );

			// rename first submenu item
			if ( isset( $submenu[ 'consent-magic' ] ) ) {
				$submenu[ 'consent-magic' ][ 0 ][ 0 ] = 'Dashboard';
			}
		} else {
			add_menu_page( 'ConsentMagic', 'ConsentMagic', 'manage_cs', 'cs-license', array(
				$this,
				'config_page'
			), CMPRO_PLUGIN_URL . '/assets/images/cm_icon.png' );

			// core admin pages
			$this->adminPagesSlugs = array(
				'cs-license'
			);
		}
	}

	// Draw option page
	public function config_page() {
		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html( __( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) ) );
		}
		settings_errors();

		if ( CMPRO_LICENSE_TYPE == 'edd' ) {
			if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} else {
				include CMPRO_PLUGIN_VIEWS_PATH . 'admin/license/html-edd-license.php';
			}
		} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
			if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			} else {
				include CMPRO_PLUGIN_VIEWS_PATH . 'admin/license/html-wc-license.php';
			}
		}
	}

	/**
	 * Returns the API Key status by querying the Status API function from the WooCommerce API Manager on the server.
	 *
	 * @return array|mixed|object
	 */
	public function license_key_status() {

		$status = $this->status();

		return !empty( $status ) ? json_decode( $this->status(), true ) : $status;
	}

	public function edd_license_key_status() {

		$status = $this->edd_status();

		return !empty( $status ) ? json_decode( $this->edd_status(), true ) : $status;
	}

	/**
	 * Sends the status check request to the API Manager.
	 *
	 * @return bool|string
	 */
	public function status() {

		if ( empty( $this->data[ $this->wc_am_api_key_key ] ) ) {
			return '';
		}

		$defaults = array(
			'wc_am_action' => 'status',
			'api_key'      => $this->data[ $this->wc_am_api_key_key ],
			'product_id'   => $this->product_id,
			'instance'     => $this->wc_am_instance_id,
			'object'       => $this->wc_am_domain
		);

		$target_url = esc_url_raw( $this->create_software_api_url( $defaults ) );
		$request = wp_safe_remote_post( $target_url );

		if ( is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) != 200 ) {
			// Request failed
			return '';
		}
		return wp_remote_retrieve_body( $request );
	}

	public function edd_status() {

		$api_params = array(
			'edd_action' => 'check_license',
			'license'    => get_option( $this->edd_license_key ),
			'item_name'  => $this->product_name,
			'url'        => home_url()
		);

		$request = wp_remote_post( $this->url_activate, array(
			'timeout'   => 15,
			'sslverify' => false,
			'body'      => $api_params
		) );

		if ( is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) != 200 ) {
			// Request failed
			return '';
		}
		return wp_remote_retrieve_body( $request );
	}

	/**
	 * Builds the URL containing the API query string for activation, deactivation, and status requests.
	 *
	 * @param array $args
	 *
	 * @return string
	 */
	public function create_software_api_url( $args ) {
		return add_query_arg( 'wc-api', 'wc-am-api', esc_url( 'https://www.pixelyoursite.com/' ) ) . '&' . http_build_query( $args );
	}

	function cs_preview_show() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		$id = isset( $_POST[ 'cs_theme' ] ) ? sanitize_text_field( $_POST[ 'cs_theme' ] ) : '';
		$active_rule_id = ConsentMagic()->get_preview_rule_id();
		$post_id = isset( $_POST[ 'cs_rule_id' ] ) ? sanitize_text_field( $_POST[ 'cs_rule_id' ] ) : '';
		$cs_bars_type = isset( $_POST[ 'cs_bar_type' ] ) ? sanitize_text_field( $_POST[ 'cs_bar_type' ] ) : '';
		$cs_bars_position = isset( $_POST[ 'cs_bar_position' ] ) ? sanitize_text_field( $_POST[ 'cs_bar_position' ] ) : '';
		$cs_type = isset( $_POST[ 'cs_type' ] ) ? sanitize_text_field( $_POST[ 'cs_type' ] ) : '';
		$cs_sticky = isset( $_POST[ 'cs_sticky' ] ) ? sanitize_text_field( $_POST[ 'cs_sticky' ] ) : '';
		$cs_hide_close_btn = isset( $_POST[ 'cs_hide_close_btn' ] ) ? sanitize_text_field( $_POST[ 'cs_hide_close_btn' ] ) : '';
		$cs_hide_close_btn_admin = true;
		$cs_deny_all_btn = isset( $_POST[ 'cs_deny_all_btn' ] ) ? sanitize_text_field( $_POST[ 'cs_deny_all_btn' ] ) : '';
		$cs_custom_button_btn = isset( $_POST[ 'cs_custom_button' ] ) ? sanitize_text_field( $_POST[ 'cs_custom_button' ] ) : '';
		$cs_privacy_link = isset( $_POST[ 'cs_privacy' ] ) ? sanitize_text_field( $_POST[ 'cs_privacy' ] ) : '';

		ob_start();
		if ( $cs_bars_type == 'bar_small' || $cs_bars_type == 'bar_large' ) {
			include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs-bar.php';
		} else if ( $cs_bars_type == 'popup_small' || $cs_bars_type == 'popup_large' ) {
			include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs_popup.php';
		}

		$html = ob_get_contents();
		ob_end_clean();
		add_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );
		echo wp_kses_post( $html );
		remove_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );

		wp_die(); // ajax call must die to avoid trailing 0 in your response

	}

	function cs_preview_list_show() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		ob_start();
		$post_id = isset( $_POST[ 'id' ] ) ? sanitize_text_field( $_POST[ 'id' ] ) : '';
		$rule_obj = get_post_meta( $post_id );
		$id = $rule_obj[ '_cs_theme' ][ 0 ];
		$active_rule_id = ConsentMagic()->get_preview_rule_id();
		$cs_bars_type = $rule_obj[ '_cs_bars_type' ][ 0 ];
		$cs_bars_position = $rule_obj[ '_cs_bars_position' ][ 0 ];
		$cs_type = $rule_obj[ '_cs_type' ][ 0 ];
		$cs_privacy_link = $rule_obj[ '_cs_privacy_link' ][ 0 ];
		$cs_deny_all_btn = $rule_obj[ '_cs_deny_all_btn' ][ 0 ];
		$cs_custom_button_btn = $rule_obj[ '_cs_custom_button' ][ 0 ];
		$cs_hide_close_btn = $rule_obj[ '_cs_hide_close_btn' ][ 0 ];
		$cs_hide_close_btn_admin = true;
		if ( $cs_bars_type == 'bar_small' || $cs_bars_type == 'bar_large' ) {
			include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs-bar.php';
		} else if ( $cs_bars_type == 'popup_small' || $cs_bars_type == 'popup_large' ) {
			include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs_popup.php';
		}
		$html = ob_get_contents();
		ob_end_clean();
		add_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );
		echo wp_kses_post( $html );
		remove_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );

		wp_die(); // ajax call must die to avoid trailing 0 in your response

	}

	function cs_preview_size_show() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );
		ob_start();
		$active_rule_id = ConsentMagic()->get_preview_rule_id();
		$metas = get_post_meta( $active_rule_id );
		$id = $metas[ '_cs_theme' ][ 0 ];
		$cs_type = $metas[ '_cs_type' ][ 0 ];
		$cs_privacy_link = $metas[ '_cs_privacy_link' ][ 0 ];
		$cs_bars_position = $metas[ '_cs_bars_position' ][ 0 ];
		$cs_deny_all_btn = $metas[ '_cs_deny_all_btn' ][ 0 ];
		$cs_hide_close_btn = $metas[ '_cs_hide_close_btn' ][ 0 ];
		$cs_hide_close_btn_admin = true;
		$cs_custom_button_btn = $metas[ '_cs_custom_button' ][ 0 ];
		$cs_bars_type = isset( $_POST[ 'bar_type' ] ) ? sanitize_text_field( $_POST[ 'bar_type' ] ) : '';

		$min_height = isset( $_POST[ 'min_height' ] ) ? sanitize_text_field( $_POST[ 'min_height' ] ) : '';
		$pd_top = isset( $_POST[ 'pd_top' ] ) ? sanitize_text_field( $_POST[ 'pd_top' ] ) : '';
		$pd_bottom = isset( $_POST[ 'pd_bottom' ] ) ? sanitize_text_field( $_POST[ 'pd_bottom' ] ) : '';
		$pd_left = isset( $_POST[ 'pd_left' ] ) ? sanitize_text_field( $_POST[ 'pd_left' ] ) : '';
		$pd_right = isset( $_POST[ 'pd_right' ] ) ? sanitize_text_field( $_POST[ 'pd_right' ] ) : '';

		$font_s = isset( $_POST[ 'font_s' ] ) ? sanitize_text_field( $_POST[ 'font_s' ] ) : '';
		$font_w = isset( $_POST[ 'font_w' ] ) ? sanitize_text_field( $_POST[ 'font_w' ] ) : '';

		$btn_pd_t = isset( $_POST[ 'btn_pd_t' ] ) ? sanitize_text_field( $_POST[ 'btn_pd_t' ] ) : '';
		$btn_pd_b = isset( $_POST[ 'btn_pd_b' ] ) ? sanitize_text_field( $_POST[ 'btn_pd_b' ] ) : '';
		$btn_pd_l = isset( $_POST[ 'btn_pd_l' ] ) ? sanitize_text_field( $_POST[ 'btn_pd_l' ] ) : '';
		$btn_pd_r = isset( $_POST[ 'btn_pd_r' ] ) ? sanitize_text_field( $_POST[ 'btn_pd_r' ] ) : '';
		$btn_mg_t = isset( $_POST[ 'btn_mg_t' ] ) ? sanitize_text_field( $_POST[ 'btn_mg_t' ] ) : '';
		$btn_mg_b = isset( $_POST[ 'btn_mg_b' ] ) ? sanitize_text_field( $_POST[ 'btn_mg_b' ] ) : '';
		$btn_mg_l = isset( $_POST[ 'btn_mg_l' ] ) ? sanitize_text_field( $_POST[ 'btn_mg_l' ] ) : '';
		$btn_mg_r = isset( $_POST[ 'btn_mg_r' ] ) ? sanitize_text_field( $_POST[ 'btn_mg_r' ] ) : '';
		$btn_font_s = isset( $_POST[ 'btn_font_s' ] ) ? sanitize_text_field( $_POST[ 'btn_font_s' ] ) : '';
		$btn_font_w = isset( $_POST[ 'btn_font_w' ] ) ? sanitize_text_field( $_POST[ 'btn_font_w' ] ) : '';

		$op_min_height = isset( $_POST[ 'op_min_height' ] ) ? sanitize_text_field( $_POST[ 'op_min_height' ] ) : '';
		$op_pd_top = isset( $_POST[ 'op_pd_top' ] ) ? sanitize_text_field( $_POST[ 'op_pd_top' ] ) : '';
		$op_pd_bottom = isset( $_POST[ 'op_pd_bottom' ] ) ? sanitize_text_field( $_POST[ 'op_pd_bottom' ] ) : '';
		$op_pd_left = isset( $_POST[ 'op_pd_left' ] ) ? sanitize_text_field( $_POST[ 'op_pd_left' ] ) : '';
		$op_pd_right = isset( $_POST[ 'op_pd_right' ] ) ? sanitize_text_field( $_POST[ 'op_pd_right' ] ) : '';

		$op_font_s = isset( $_POST[ 'op_font_s' ] ) ? sanitize_text_field( $_POST[ 'op_font_s' ] ) : '';
		$op_font_w = isset( $_POST[ 'op_font_w' ] ) ? sanitize_text_field( $_POST[ 'op_font_w' ] ) : '';

		$op_btn_pd_t = isset( $_POST[ 'op_btn_pd_t' ] ) ? sanitize_text_field( $_POST[ 'op_btn_pd_t' ] ) : '';
		$op_btn_pd_b = isset( $_POST[ 'op_btn_pd_b' ] ) ? sanitize_text_field( $_POST[ 'op_btn_pd_b' ] ) : '';
		$op_btn_pd_l = isset( $_POST[ 'op_btn_pd_l' ] ) ? sanitize_text_field( $_POST[ 'op_btn_pd_l' ] ) : '';
		$op_btn_pd_r = isset( $_POST[ 'op_btn_pd_r' ] ) ? sanitize_text_field( $_POST[ 'op_btn_pd_r' ] ) : '';
		$op_btn_mg_t = isset( $_POST[ 'op_btn_mg_t' ] ) ? sanitize_text_field( $_POST[ 'op_btn_mg_t' ] ) : '';
		$op_btn_mg_b = isset( $_POST[ 'op_btn_mg_b' ] ) ? sanitize_text_field( $_POST[ 'op_btn_mg_b' ] ) : '';
		$op_btn_mg_l = isset( $_POST[ 'op_btn_mg_l' ] ) ? sanitize_text_field( $_POST[ 'op_btn_mg_l' ] ) : '';
		$op_btn_mg_r = isset( $_POST[ 'op_btn_mg_r' ] ) ? sanitize_text_field( $_POST[ 'op_btn_mg_r' ] ) : '';
		$op_btn_font_s = isset( $_POST[ 'op_btn_font_s' ] ) ? sanitize_text_field( $_POST[ 'op_btn_font_s' ] ) : '';
		$op_btn_font_w = isset( $_POST[ 'op_btn_font_w' ] ) ? sanitize_text_field( $_POST[ 'op_btn_font_w' ] ) : '';

		$op_title_f_s = isset( $_POST[ 'op_title_f_s' ] ) ? sanitize_text_field( $_POST[ 'op_title_f_s' ] ) : '';
		$op_title_f_w = isset( $_POST[ 'op_title_f_w' ] ) ? sanitize_text_field( $_POST[ 'op_title_f_w' ] ) : '';
		$op_subtitle_f_s = isset( $_POST[ 'op_subtitle_f_s' ] ) ? sanitize_text_field( $_POST[ 'op_subtitle_f_s' ] ) : '';
		$op_subtitle_f_w = isset( $_POST[ 'op_subtitle_f_w' ] ) ? sanitize_text_field( $_POST[ 'op_subtitle_f_w' ] ) : '';

		$cs_preview_size_show = true;

		if ( $cs_bars_type == 'bar_small' || $cs_bars_type == 'bar_large' ) {
			include( CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs-bar.php' );
		} else if ( $cs_bars_type == 'popup_small' || $cs_bars_type == 'popup_large' ) {
			include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs_popup.php';
		}

		$html = ob_get_contents();
		ob_end_clean();
		add_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );
		$data = array(
			'html' => wp_kses_post( $html )
		);
		remove_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );
		wp_send_json_success( $data );

		wp_die(); // ajax call must die to avoid trailing 0 in your response

	}

	function cs_preview_color_show() {
		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		ob_start();
		$active_rule_id = ConsentMagic()->get_preview_rule_id();
		$metas = get_post_meta( $active_rule_id );
		$id = $metas[ '_cs_theme' ][ 0 ];
		$cs_type = $metas[ '_cs_type' ][ 0 ];
		$cs_privacy_link = $metas[ '_cs_privacy_link' ][ 0 ];
		$cs_bars_position = $metas[ '_cs_bars_position' ][ 0 ];
		$cs_deny_all_btn = $metas[ '_cs_deny_all_btn' ][ 0 ];
		$cs_custom_button_btn = $metas[ '_cs_custom_button' ][ 0 ];
		$cs_bars_type = isset( $_POST[ 'bar_type' ] ) ? sanitize_text_field( $_POST[ 'bar_type' ] ) : '';
		$cs_hide_close_btn = $metas[ '_cs_hide_close_btn' ][ 0 ];
		$cs_hide_close_btn_admin = true;

		$style_array = array(
			'cs_backend_color'                    => array( isset( $_POST[ 'cs_backend_color' ] ) ? sanitize_text_field( $_POST[ 'cs_backend_color' ] ) : '' ),
			'cs_border_style'                     => array( isset( $_POST[ 'cs_border_style' ] ) ? sanitize_text_field( $_POST[ 'cs_border_style' ] ) : '' ),
			'cs_border_weight'                    => array( isset( $_POST[ 'cs_border_weight' ] ) ? sanitize_text_field( $_POST[ 'cs_border_weight' ] ) : '' ),
			'cs_border_color'                     => array( isset( $_POST[ 'cs_border_color' ] ) ? sanitize_text_field( $_POST[ 'cs_border_color' ] ) : '' ),
			'cs_text_color'                       => array( isset( $_POST[ 'cs_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_text_color' ] ) : '' ),
			'cs_links_color'                      => array( isset( $_POST[ 'cs_links_color' ] ) ? sanitize_text_field( $_POST[ 'cs_links_color' ] ) : '' ),
			'cs_titles_text_color'                => array( isset( $_POST[ 'cs_titles_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_titles_text_color' ] ) : '' ),
			'cs_subtitles_text_color'             => array( isset( $_POST[ 'cs_subtitles_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_subtitles_text_color' ] ) : '' ),
			'cs_accept_all_buttons_bg'            => array( isset( $_POST[ 'cs_accept_all_buttons_bg' ] ) ? sanitize_text_field( $_POST[ 'cs_accept_all_buttons_bg' ] ) : '' ),
			'cs_accept_all_buttons_text_color'    => array( isset( $_POST[ 'cs_accept_all_buttons_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_accept_all_buttons_text_color' ] ) : '' ),
			'cs_custom_button_buttons_bg'         => array( isset( $_POST[ 'cs_custom_button_buttons_bg' ] ) ? sanitize_text_field( $_POST[ 'cs_custom_button_buttons_bg' ] ) : '' ),
			'cs_custom_button_buttons_text_color' => array( isset( $_POST[ 'cs_custom_button_buttons_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_custom_button_buttons_text_color' ] ) : '' ),
			'cs_deny_all_buttons_bg'              => array( isset( $_POST[ 'cs_deny_all_buttons_bg' ] ) ? sanitize_text_field( $_POST[ 'cs_deny_all_buttons_bg' ] ) : '' ),
			'cs_deny_all_buttons_text_color'      => array( isset( $_POST[ 'cs_deny_all_buttons_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_deny_all_buttons_text_color' ] ) : '' ),
			'cs_options_buttons_text_color'       => array( isset( $_POST[ 'cs_options_buttons_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_options_buttons_text_color' ] ) : '' ),
			'cs_options_buttons_bg'               => array( isset( $_POST[ 'cs_options_buttons_bg' ] ) ? sanitize_text_field( $_POST[ 'cs_options_buttons_bg' ] ) : '' ),
			'cs_confirm_buttons_bg'               => array( isset( $_POST[ 'cs_confirm_buttons_bg' ] ) ? sanitize_text_field( $_POST[ 'cs_confirm_buttons_bg' ] ) : '' ),
			'cs_confirm_buttons_text_color'       => array( isset( $_POST[ 'cs_confirm_buttons_text_color' ] ) ? sanitize_text_field( $_POST[ 'cs_confirm_buttons_text_color' ] ) : '' ),
			'cs_sticky_bg'                        => array( isset( $_POST[ 'cs_sticky_bg' ] ) ? sanitize_text_field( $_POST[ 'cs_sticky_bg' ] ) : '' ),
			'cs_sticky_link_color'                => array( isset( $_POST[ 'cs_sticky_link_color' ] ) ? sanitize_text_field( $_POST[ 'cs_sticky_link_color' ] ) : '' ),
			'cs_logo'                             => array( isset( $_POST[ 'cs_logo' ] ) ? sanitize_text_field( $_POST[ 'cs_logo' ] ) : '' ),
			'cs_position_vertical_list'           => array( isset( $_POST[ 'cs_position_vertical_list' ] ) ? sanitize_text_field( $_POST[ 'cs_position_vertical_list' ] ) : '' ),
			'cs_position_horizontal_list'         => array( isset( $_POST[ 'cs_position_horizontal_list' ] ) ? sanitize_text_field( $_POST[ 'cs_position_horizontal_list' ] ) : '' ),
			'cs_logo_size'                        => array( isset( $_POST[ 'cs_logo_size' ] ) ? sanitize_text_field( $_POST[ 'cs_logo_size' ] ) : '' ),
			'cs_cat_color'                        => array( isset( $_POST[ 'cs_cat_color' ] ) ? sanitize_text_field( $_POST[ 'cs_cat_color' ] ) : '' ),
			'cs_active_toggle_color'              => array( isset( $_POST[ 'cs_active_toggle_color' ] ) ? sanitize_text_field( $_POST[ 'cs_active_toggle_color' ] ) : '' ),
		);

		if ( $cs_bars_type == 'bar_small' || $cs_bars_type == 'bar_large' ) {
			include( CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs-bar.php' );
		} else if ( $cs_bars_type == 'popup_small' || $cs_bars_type == 'popup_large' ) {
			include CMPRO_PLUGIN_VIEWS_PATH . 'templates/cs_popup.php';
		}
		$html = ob_get_contents();
		ob_end_clean();
		add_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );
		echo wp_kses_post( $html );
		remove_filter( 'safe_style_css', array(
			$this,
			'add_style_option'
		) );
		wp_die(); // ajax call must die to avoid trailing 0 in your response

	}

	function cs_renew_consent() {
		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );
		$this->renew_consent_run();
		wp_die(); // ajax call must die to avoid trailing 0 in your response
	}

	function renew_consent_run() {
		$consent_version = ConsentMagic()->cs_get_consent_version();
		if ( !empty( $consent_version ) ) {
			$consent_version = $consent_version + 1;
			update_option( 'wt_cs_consent_version', $consent_version );
		}
	}

	public function adminPageMain() {

		if ( ConsentMagic()->getOption( 'cs_geolocation' ) && ConsentMagic()->getOption( 'cs_geo_activated' ) && ConsentMagic()->getOption( 'cs_often_update' ) != 'never' ) {
			db_cron_update();
		} else {
			db_cron_deactivate();
		}

		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html( __( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) ) );
		}

		//check load translations for current plugin version
		if ( ConsentMagic()->getOption( 'cs_check_translations' ) != CMPRO_LATEST_VERSION_NUMBER ) {
			$this->loadTranslations( false, true );
		}

		// Get options:
		$the_options = ConsentMagic()->getCSOptions();
		$design_options = ConsentMagic()->getCSOptionsDesign();

		if ( isset( $_GET[ 'primary_rule_id' ] ) ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/primary-rules/edit-primary-rule-html.php';
		} else if ( isset( $_GET[ 'new_rule' ] ) ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/primary-rules/add-new-primary-rule-html.php';
		} else if ( isset( $_GET[ 'new_script' ] ) || isset( $_GET[ 'script_id' ] ) ) {
			if ( isset( $_GET[ 'script_id' ] ) ) {
				$id = sanitize_text_field( $_GET[ 'script_id' ] );
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/scripts/edit-script-html.php';
			} else {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/scripts/add-script-html.php';
			}
		} else if ( isset( $_GET[ 'new_cookie' ] ) || isset( $_GET[ 'cookie_id' ] ) ) {
			if ( isset( $_GET[ 'cookie_id' ] ) ) {
				$id = sanitize_text_field( $_GET[ 'cookie_id' ] );
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/cookies/edit-cookie-html.php';
			} else {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/cookies/add-cookie-html.php';
			}
		} else if ( isset( $_GET[ 'design_template' ] ) ) {
			$border_style = ConsentMagic()->getOption( 'cs_border_style_list' );

			$sizes_array = get_intermediate_image_sizes();

			$img_sizes_array = array();

			foreach ( $sizes_array as $key => $val ) {
				$img_sizes_array[ $val ] = $val;
			}

			if ( $_GET[ 'design_template' ] == 'add' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/add-design-template-html.php';
			} else {
				$id = isset( $_GET[ 'template_id' ] ) ? sanitize_text_field( $_GET[ 'template_id' ] ) : '';
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/edit-design-template-html.php';
			}
		} elseif ( isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( $_POST[ '_wpnonce' ], 'cs-update-' . CMPRO_SETTINGS_FIELD ) ) {

			// Check if form has been set:
			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {

				$cs_auto_scan_interval = ConsentMagic()->getOption( 'cs_auto_scan_interval' );
				if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] ) && ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] !== $cs_auto_scan_interval ) ) {
					if ( wp_next_scheduled( 'cs_cron_bulck_scan_hook' ) ) {
						wp_clear_scheduled_hook( 'cs_cron_bulck_scan_hook' );
						if ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] == "once_a_week" ) {
							wp_schedule_event( time(), 'weekly', 'cs_cron_bulck_scan_hook' );
						} else if ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_auto_scan_interval' ] == "once_a_month" ) {
							wp_schedule_event( time(), 'monthly', 'cs_cron_bulck_scan_hook' );
						} else {
							if ( wp_next_scheduled( 'cs_cron_bulck_scan_hook' ) ) {
								wp_clear_scheduled_hook( 'cs_cron_bulck_scan_hook' );
							}
						}
					}
				}

				if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_check_flow' ] ) ) {

					if ( isset( $_POST[ 'cs_active_rule_id_first' ] ) ) {
						$this->change_rule_order_admin( (int) sanitize_text_field( $_POST[ 'cs_active_rule_id_first' ] ) );
					}
					$user_id = get_current_user_id();
					add_user_meta( $user_id, 'cs_notice_dismissed', 'true', true );

					if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_block_googlefonts_enabled' ] ) ) {
						$term = get_term_by( 'slug', 'googlefonts', 'cs-cookies-category' );
						if ( $term ) {
							$val = !(bool) sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_block_googlefonts_enabled' ] );
							update_term_meta( $term->term_id, 'cs_ignore_this_category', $val );
						}
					}
				}

				foreach ( $the_options as $key => $value ) {
					if ( isset( $_POST[ 'cs' ][ $this->plugin_name ] ) && is_array( $_POST[ 'cs' ][ $this->plugin_name ] ) ) {

						$key_langs = array();
						$all_langs = get_language_list();
						$lang_save = false;
						foreach ( $_POST[ 'cs' ][ $this->plugin_name ] as $post_key => $post_val ) {
							$post_key = sanitize_text_field( $post_key );
							$post_val = sanitize_text_field( $post_val );
							if ( $post_key != $key . '_0' && !empty( $post_val ) ) {
								if ( strripos( $post_key, $key ) !== false ) {
									$lang = str_replace( $key . '_', '', $post_key );
									if ( $lang != $post_key && array_key_exists( $lang, $all_langs ) ) {

										if ( in_array( $key, get_text_editor_fields() ) ) {
											ConsentMagic()->updateLangOptions( array( $key => wp_kses_post( wp_unslash( $_POST[ 'cs' ][ $this->plugin_name ][ $post_key ] ) ) ), $lang );
										} else {
											ConsentMagic()->updateLangOptions( array( $key => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $post_key ] ) ), $lang );
										}

										array_push( $key_langs, $lang );
										$lang_save = true;
									}
								}
							}
						}

						if ( $lang_save && isset( $_POST[ 'cs' ][ $this->plugin_name ][ "{$key}_language_control" ] ) && $_POST[ 'cs' ][ $this->plugin_name ][ "{$key}_language_control" ] != 0 ) {
							ConsentMagic()->updateOptions( array( $key . '_lang' => $key_langs ) );
						}
					}

					if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
						ConsentMagic()->updateOptions( sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) );
					}


					if ( isset( $_POST[ '_cs_top_push' ] ) ) {
						$_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] = sanitize_text_field( $_POST[ '_cs_top_push' ] );
						ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] ) : '' );
					}
				}

				foreach ( $design_options as $key => $value ) {
					if ( isset( $_POST[ 'cs_d' ][ $this->plugin_name ][ $key ] ) ) {
						ConsentMagic()->updateOptionsDesign( sanitize_text_field( $_POST[ 'cs_d' ][ $this->plugin_name ][ $key ] ) );
					}
				}

				if ( isset( $_POST[ 'cs_post_name' ] ) && isset( $_POST[ 'cs_rule_id' ] ) ) {
					$rule_post = array();
					$rule_post[ 'ID' ] = isset( $_POST[ 'cs_rule_id' ] ) ? sanitize_text_field( $_POST[ 'cs_rule_id' ] ) : null;
					$rule_post[ 'post_title' ] = isset( $_POST[ 'cs_post_name' ] ) ? sanitize_text_field( $_POST[ 'cs_post_name' ] ) : null;
					wp_update_post( wp_slash( $rule_post ) );
				}

				if ( isset( $_POST[ 'cs_gdpr_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_gdpr_rule' );
					update_post_meta( $id, '_cs_enable_rule', isset( $_POST[ 'cs_gdpr_rule' ] ) ? sanitize_text_field( $_POST[ 'cs_gdpr_rule' ] ) : null );
				}
				if ( isset( $_POST[ 'cs_ccpa_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_ccpa_rule' );
					update_post_meta( $id, '_cs_enable_rule', isset( $_POST[ 'cs_ccpa_rule' ] ) ? sanitize_text_field( $_POST[ 'cs_ccpa_rule' ] ) : null );
				}
				if ( isset( $_POST[ 'cs_rest_of_world_rule' ] ) ) {
					$id = get_post_id_by_slug( 'cs_rest_of_world_rule' );
					update_post_meta( $id, '_cs_enable_rule', isset( $_POST[ 'cs_rest_of_world_rule' ] ) ? sanitize_text_field( $_POST[ 'cs_rest_of_world_rule' ] ) : null );
				}

				if ( isset( $_POST[ 'cs' ][ 'custom_enable' ] ) && !empty( $_POST[ 'cs' ][ 'custom_enable' ] ) ) {
					foreach ( $_POST[ 'cs' ][ 'custom_enable' ] as $key => $val ) {
						$data_arr = array(
							'cookie_enabled' => sanitize_text_field( $val ),
						);
						update_scan_cookie_data( sanitize_text_field( $key ), $data_arr );
					}
				}

				if ( isset( $_POST[ 'cs' ][ 'custom_cookie_cat' ] ) && !empty( $_POST[ 'cs' ][ 'custom_cookie_cat' ] ) ) {
					foreach ( $_POST[ 'cs' ][ 'custom_cookie_cat' ] as $key => $val ) {
						$category_id = get_term_by( 'slug', sanitize_text_field( $val ), 'cs-cookies-category' );
						$data_arr = array(
							'category'    => sanitize_text_field( $val ),
							'category_id' => $category_id->term_id
						);
						update_scan_cookie_data( sanitize_text_field( $key ), $data_arr );
					}
				}

				$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );

				foreach ( $_POST as $item_name => $val ) {
					$item_name = sanitize_text_field( $item_name );
					$val = sanitize_text_field( $val );

					if ( get_option( $item_name ) !== false ) {
						update_option( $item_name, $val );
					}
					if ( stripos( $item_name, '_cookie_cat' ) ) {
						$cookie_id = preg_replace( "/[^0-9]/", '', $item_name );
						wp_set_object_terms( $cookie_id, $val, 'cs-cookies-category' );
					}

					if ( stripos( $item_name, '_script_cat' ) ) {
						$cookie_id = preg_replace( "/[^0-9]/", '', $item_name );
						wp_set_object_terms( $cookie_id, $val, 'cs-cookies-category' );
					}

					if ( stripos( $item_name, 'category_' . $unassigned->term_id ) ) {
						$cookie_id = preg_replace( "/[^0-9]/", '', $item_name );
						if ( $cookie_id == $unassigned->term_id ) {
							update_term_meta( $cookie_id, 'cs_ignore_this_category', $val );
						}
					}

					if ( stripos( $item_name, '_script_enable' ) ) {
						update_option( $item_name, $val );
					}
					if ( stripos( $item_name, '_cookie_enable' ) ) {
						update_option( $item_name, $val );
					}
				}

				if ( isset( $_POST[ 'cs_rule_id' ] ) ) {

					$options = get_lang_meta_list();
					$all_langs = get_language_list();

					foreach ( $options as $option ) {
						$key_langs = array();
						foreach ( $_POST as $item_name => $val ) {
							$item_name = sanitize_text_field( $item_name );
							if ( strripos( $item_name, $option ) !== false ) {
								$lang = str_replace( $option . '_', '', $item_name );

								if ( $lang != $option && array_key_exists( $lang, $all_langs ) ) {
									array_push( $key_langs, $lang );
								}
							}
						}
						update_post_meta( sanitize_text_field( $_POST[ 'cs_rule_id' ] ), $option . '_lang', $key_langs );
					}

					foreach ( $_POST as $item_name => $val ) {
						if ( gettype( $val ) === 'string' ) {
							update_post_meta( sanitize_text_field( $_POST[ 'cs_rule_id' ] ), sanitize_text_field( $item_name ), wp_kses_post( wp_unslash( $val ) ) );
						}
					}

					$this->change_active_rule();
				}

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_design_template_form' ) {

				$post_data = array();
				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
				} );

				$template_data = array(
					'post_type'   => CMPRO_TEMPLATE_POST_TYPE,
					'post_title'  => $post_data[ 'cs_default_template_name' ],
					'post_status' => 'publish',
					'ping_status' => 'closed',
					'post_author' => 1,
					'meta_input'  => array(
						'cs_backend_color'                    => $post_data[ 'cs_backend_color' ],
						'cs_border_style'                     => $post_data[ 'cs_border_style' ],
						'cs_border_weight'                    => $post_data[ 'cs_border_weight' ],
						'cs_border_color'                     => $post_data[ 'cs_border_color' ],
						'cs_text_color'                       => $post_data[ 'cs_text_color' ],
						'cs_links_color'                      => $post_data[ 'cs_links_color' ],
						'cs_titles_text_color'                => $post_data[ 'cs_titles_text_color' ],
						'cs_subtitles_text_color'             => $post_data[ 'cs_subtitles_text_color' ],
						'cs_accept_all_buttons_bg'            => $post_data[ 'cs_accept_all_buttons_bg' ],
						'cs_accept_all_buttons_text_color'    => $post_data[ 'cs_accept_all_buttons_text_color' ],
						'cs_custom_button_buttons_bg'         => $post_data[ 'cs_custom_button_buttons_bg' ],
						'cs_custom_button_buttons_text_color' => $post_data[ 'cs_custom_button_buttons_text_color' ],
						'cs_deny_all_buttons_bg'              => $post_data[ 'cs_deny_all_buttons_bg' ],
						'cs_deny_all_buttons_text_color'      => $post_data[ 'cs_deny_all_buttons_text_color' ],
						'cs_options_buttons_text_color'       => $post_data[ 'cs_options_buttons_text_color' ],
						'cs_options_buttons_bg'               => $post_data[ 'cs_options_buttons_bg' ],
						'cs_confirm_buttons_bg'               => $post_data[ 'cs_confirm_buttons_bg' ],
						'cs_confirm_buttons_text_color'       => $post_data[ 'cs_confirm_buttons_text_color' ],
						'cs_sticky_bg'                        => $post_data[ 'cs_sticky_bg' ],
						'cs_sticky_link_color'                => $post_data[ 'cs_sticky_link_color' ],
						'cs_logo'                             => $post_data[ 'cs_logo' ],
						'cs_position_vertical_list'           => $post_data[ 'cs_position_vertical_list' ],
						'cs_position_horizontal_list'         => $post_data[ 'cs_position_horizontal_list' ],
						'cs_logo_size'                        => $post_data[ 'cs_logo_size' ],
						'cs_cat_color'                        => $post_data[ 'cs_cat_color' ],
						'cs_active_toggle_color'              => $post_data[ 'cs_active_toggle_color' ],
						'cs_main_template'                    => ''
					)
				);

				wp_insert_post( $template_data );

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_design_template_form' ) {

				$post_data = array();
				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
				} );

				$post_id = $post_data[ 'cs_template_id' ];

				$template_data = array(
					'ID'         => $post_id,
					'post_title' => $post_data[ 'cs_post_name' ],
					'meta_input' => array(
						'cs_backend_color'                    => $post_data[ 'cs_backend_color' ],
						'cs_border_style'                     => $post_data[ 'cs_border_style' ],
						'cs_border_weight'                    => $post_data[ 'cs_border_weight' ],
						'cs_border_color'                     => $post_data[ 'cs_border_color' ],
						'cs_text_color'                       => $post_data[ 'cs_text_color' ],
						'cs_links_color'                      => $post_data[ 'cs_links_color' ],
						'cs_titles_text_color'                => $post_data[ 'cs_titles_text_color' ],
						'cs_subtitles_text_color'             => $post_data[ 'cs_subtitles_text_color' ],
						'cs_accept_all_buttons_bg'            => $post_data[ 'cs_accept_all_buttons_bg' ],
						'cs_accept_all_buttons_text_color'    => $post_data[ 'cs_accept_all_buttons_text_color' ],
						'cs_custom_button_buttons_bg'         => $post_data[ 'cs_custom_button_buttons_bg' ],
						'cs_custom_button_buttons_text_color' => $post_data[ 'cs_custom_button_buttons_text_color' ],
						'cs_deny_all_buttons_bg'              => $post_data[ 'cs_deny_all_buttons_bg' ],
						'cs_deny_all_buttons_text_color'      => $post_data[ 'cs_deny_all_buttons_text_color' ],
						'cs_options_buttons_text_color'       => $post_data[ 'cs_options_buttons_text_color' ],
						'cs_options_buttons_bg'               => $post_data[ 'cs_options_buttons_bg' ],
						'cs_confirm_buttons_bg'               => $post_data[ 'cs_confirm_buttons_bg' ],
						'cs_confirm_buttons_text_color'       => $post_data[ 'cs_confirm_buttons_text_color' ],
						'cs_sticky_bg'                        => $post_data[ 'cs_sticky_bg' ],
						'cs_sticky_link_color'                => $post_data[ 'cs_sticky_link_color' ],
						'cs_logo'                             => $post_data[ 'cs_logo' ],
						'cs_position_vertical_list'           => $post_data[ 'cs_position_vertical_list' ],
						'cs_position_horizontal_list'         => $post_data[ 'cs_position_horizontal_list' ],
						'cs_logo_size'                        => $post_data[ 'cs_logo_size' ],
						'cs_cat_color'                        => $post_data[ 'cs_cat_color' ],
						'cs_active_toggle_color'              => $post_data[ 'cs_active_toggle_color' ],
						'cs_main_template'                    => ''
					)
				);

				wp_update_post( $template_data );

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'add_new_cookie_cat' ) {

				$new_slug = isset( $_POST[ 'cs_cookie_cat_name' ] ) ? sanitize_text_field( $_POST[ 'cs_cookie_cat_name' ] ) : null;

				$category = get_term_by( 'slug', $new_slug, 'cs-cookies-category' );

				if ( !$category ) {
					global $sitepress;
					$wpml_default_lang = 'en';
					$wpml_current_lang = 'en';
					if ( function_exists( 'icl_object_id' ) && $sitepress ) {
						$wpml_default_lang = $sitepress->get_default_language();
						$wpml_current_lang = ICL_LANGUAGE_CODE;
					}
					//check only in default language
					if ( $wpml_default_lang == $wpml_current_lang ) {
						$term = get_term_by( 'slug', $new_slug, 'cs-cookies-category' );
						if ( @!$term->term_id ) {
							$cid = wp_insert_term( $new_slug, 'cs-cookies-category', array(
								'slug' => $new_slug
							) );
							if ( !is_wp_error( $cid ) ) {
								$description = array(
									'name'  => $new_slug,
									'descr' => isset( $_POST[ 'cs_cookie_cat_descr' ] ) ? wp_kses_post( wp_unslash( $_POST[ 'cs_cookie_cat_descr' ] ) ) : '',
								);
								// Get term_id, set default as 0 if not set
								$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
								add_term_meta( $cat_id, 'cs_primary_term', 'custom', true );
								add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
								add_term_meta( $cat_id, 'cs_ignore_this_category', '0', true );
								add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description, true );
								add_term_meta( $cat_id, 'cs_edit_cat_description_lang', CMPRO_DEFAULT_LANGUAGE, true );
								update_option( $new_slug . '_cat_id', $cat_id );

								$return = array(
									'cat_id' => $cat_id
								);

								wp_send_json_success( $return );
							}
						}
					}
				}
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'update_cookie_cat' ) {

				foreach ( $the_options as $key => $value ) {
					if ( isset( $_POST[ 'cs_not_block_unassigned_cookies' ] ) && $key === 'cs_not_block_unassigned_cookies' ) {
						ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_not_block_unassigned_cookies' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_not_block_unassigned_cookies' ] ) : '' );
					}
					if ( isset( $_POST[ 'default_font' ] ) && $key === 'default_font' ) {
						ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'default_font' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'default_font' ] ) : '' );
					}
				}

				$cs_cookie_cat_id = sanitize_text_field( $_POST[ 'cs_cookie_cat_id' ] );
				if ( isset( $_POST[ 'cs_cookie_cat_id' ] ) && isset( $_POST[ 'cs_cookie_cat_fields' ] ) && isset( $_POST[ "cs_language_control_{$cs_cookie_cat_id}" ] ) ) {

					$fields = json_decode( wp_kses_post( stripslashes( $_POST[ 'cs_cookie_cat_fields' ] ) ) );
					if ( $fields !== false && is_array( $fields ) ) {
						$langs = array();
						foreach ( $fields as $field ) {

							$description = array(
								'name'  => sanitize_text_field( $field->name ),
								'descr' => $field->descr,
							);
							$langs[] = sanitize_text_field( $field->lang );
							update_term_meta( $cs_cookie_cat_id, 'cs_edit_cat_description_' . sanitize_text_field( $field->lang ), $description );
						}

						if ( $_POST[ "cs_language_control_{$cs_cookie_cat_id}" ] == 1 ) {
							update_term_meta( $cs_cookie_cat_id, 'cs_edit_cat_description_lang', $langs );
						}
						update_term_meta( isset( $_POST[ 'cs_cookie_cat_id' ] ) ? sanitize_text_field( $_POST[ 'cs_cookie_cat_id' ] ) : null, 'cs_ignore_this_category', isset( $_POST[ 'cs_ignore_this_category' ] ) ? sanitize_text_field( $_POST[ 'cs_ignore_this_category' ] ) : null );

					}
				}
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'delete_cookie_cat' ) {

				if ( isset( $_POST[ 'cs_cookie_cat_id' ] ) ) {

					$id = sanitize_text_field( $_POST[ 'cs_cookie_cat_id' ] );
					$term = get_term_by( 'ID', $id, 'cs-cookies-category' );

					$scripts = get_posts( array(
						'post_type'   => CMPRO_POST_TYPE_SCRIPTS,
						'numberposts' => -1,
						'post_status' => 'any',
						'tax_query'   => array(
							array(
								'taxonomy'         => 'cs-cookies-category',
								'field'            => 'term_id',
								'terms'            => $id,
								'include_children' => false
							)
						)
					) );

					$update_category = 'unassigned';
					$unassigned = get_term_by( 'slug', $update_category, 'cs-cookies-category' );

					if ( $scripts ) {
						foreach ( $scripts as $script ) {
							update_option( 'cs_' . $script->ID . '_cookie_cat', '' );
							update_option( 'cs_' . $script->ID . '_script_cat', $update_category );
							wp_set_object_terms( $script->ID, $unassigned->term_id, 'cs-cookies-category' );
						}
					}

					$script_list = get_predefined_script_pattern();
					foreach ( $script_list as $script ) {
						$category = ConsentMagic()->getOption( $script[ 'cat_key' ] );
						if ( $category == $term->slug ) {
							ConsentMagic()->updateOptions( array( $script[ 'cat_key' ] => $update_category ) );
						}
					}

					if ( $term ) {
						wp_delete_term( $id, 'cs-cookies-category', array(
							'default'       => $unassigned->term_id,
							'force_default' => true
						) );
						delete_option( $term->slug . '_cat_id' );
					}
				}
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'delete_template' ) {

				if ( isset( $_POST[ 'template_id' ] ) ) {

					$id = sanitize_text_field( $_POST[ 'template_id' ] );

					$scripts = get_posts( array(
						'post_type'   => CMPRO_POST_TYPE,
						'numberposts' => -1,
						'post_status' => 'any',
					) );
					if ( $scripts ) {
						foreach ( $scripts as $script ) {
							$script_theme = get_post_meta( $script->ID, '_cs_theme', true );
							if ( $script_theme == $id ) {
								update_post_meta( $script->ID, '_cs_theme', get_page_id_by_path( 'cs_light_theme', '', CMPRO_TEMPLATE_POST_TYPE ) );
							}
						}
					}

					wp_delete_post( $id, true );
				}
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'btn_restore_adjust' ) {
				delete_option( CMPRO_SETTINGS_DESIGN_FIELD );
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_rule_form' ) {

				$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
				$unassigned_id = $unassigned->term_id;
				$categories = get_cookies_terms_objects( null, false, $unassigned_id );
				$categories_options = array();

				if ( !empty( $categories ) ) {
					foreach ( $categories as $category ) {
						if ( isset( $_POST[ '_cs_smart_sticky_' . $category->term_id ] ) ) {
							$categories_options[ '_cs_smart_sticky_' . $category->term_id ] = sanitize_text_field( $_POST[ '_cs_smart_sticky_' . $category->term_id ] );
						}

						if ( isset( $_POST[ '_cs_smart_sticky_mobile_' . $category->term_id ] ) ) {
							$categories_options[ '_cs_smart_sticky_mobile_' . $category->term_id ] = sanitize_text_field( $_POST[ '_cs_smart_sticky_mobile_' . $category->term_id ] );
						}

						if ( isset( $_POST[ '_cs_custom_button_' . $category->term_id ] ) ) {
							$categories_options[ '_cs_custom_button_' . $category->term_id ] = sanitize_text_field( $_POST[ '_cs_custom_button_' . $category->term_id ] );
						}
					}
				}

				$post_data = array();
				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
				} );

				if ( !$this->cs_post_exists_by_slug( $post_data[ 'cs_default_rule_name' ], CMPRO_POST_TYPE ) ) {

					$category = get_term_by( 'slug', 'rules', 'cs-category' );
					if ( $category && is_object( $category ) ) {
						$posts_in_category = $category->count;
						$order = $posts_in_category;
						$category_id = $category->term_id;
						$cookie_data = array(
							'post_type'     => CMPRO_POST_TYPE,
							'post_title'    => $post_data[ 'cs_default_rule_name' ],
							'post_category' => array( $category_id ),
							'post_status'   => 'publish',
							'ping_status'   => 'closed',
							'post_author'   => 1,
							'meta_input'    => array(
								'_cs_type'                               => isset( $_POST[ '_cs_type' ] ) ? sanitize_text_field( $_POST[ '_cs_type' ] ) : null,
								'_cs_sticky'                             => isset( $_POST[ '_cs_sticky' ] ) ? sanitize_text_field( $_POST[ '_cs_sticky' ] ) : null,
								'_cs_smart_sticky'                       => isset( $_POST[ '_cs_smart_sticky' ] ) ? sanitize_text_field( $_POST[ '_cs_smart_sticky' ] ) : null,
								'_cs_smart_sticky_mobile'                => isset( $_POST[ '_cs_smart_sticky_mobile' ] ) ? sanitize_text_field( $_POST[ '_cs_smart_sticky_mobile' ] ) : null,
								'_cs_mobile_side_sticky'                 => isset( $_POST[ '_cs_mobile_side_sticky' ] ) ? sanitize_text_field( $_POST[ '_cs_mobile_side_sticky' ] ) : null,
								'_cs_custom_button'                      => isset( $_POST[ '_cs_custom_button' ] ) ? sanitize_text_field( $_POST[ '_cs_custom_button' ] ) : null,
								'_cs_bars_position'                      => isset( $_POST[ '_cs_bars_position' ] ) ? sanitize_text_field( $_POST[ '_cs_bars_position' ] ) : null,
								'_cs_bars_type'                          => isset( $_POST[ '_cs_bars_type' ] ) ? sanitize_text_field( $_POST[ '_cs_bars_type' ] ) : null,
								'_cs_top_push'                           => isset( $_POST[ '_cs_top_push' ] ) ? sanitize_text_field( $_POST[ '_cs_top_push' ] ) : null,
								'_cs_privacy_link'                       => isset( $_POST[ '_cs_privacy_link' ] ) ? sanitize_text_field( $_POST[ '_cs_privacy_link' ] ) : null,
								'_cs_close_on_scroll'                    => isset( $_POST[ '_cs_close_on_scroll' ] ) ? sanitize_text_field( $_POST[ '_cs_close_on_scroll' ] ) : null,
								'_cs_theme'                              => isset( $_POST[ '_cs_theme' ] ) ? sanitize_text_field( $_POST[ '_cs_theme' ] ) : null,
								'_cs_deny_all_btn'                       => isset( $_POST[ '_cs_deny_all_btn' ] ) ? sanitize_text_field( $_POST[ '_cs_deny_all_btn' ] ) : null,
								'_cs_hide_close_btn'                     => isset( $_POST[ '_cs_hide_close_btn' ] ) ? sanitize_text_field( $_POST[ '_cs_hide_close_btn' ] ) : null,
								'_cs_deny_consent_for_close'             => isset( $_POST[ '_cs_deny_consent_for_close' ] ) ? sanitize_text_field( $_POST[ '_cs_deny_consent_for_close' ] ) : null,
								'_cs_predefined_rule'                    => 0,
								'_cs_target'                             => isset( $_POST[ '_cs_target' ] ) ? sanitize_text_field( $_POST[ '_cs_target' ] ) : null,
								'_cs_custom_text'                        => isset( $_POST[ '_cs_custom_text' ] ) ? sanitize_text_field( $_POST[ '_cs_custom_text' ] ) : null,
								'_cs_order'                              => $order,
								'_cs_track_analytics'                    => isset( $_POST[ '_cs_track_analytics' ] ) ? sanitize_text_field( $_POST[ '_cs_track_analytics' ] ) : null,
								'_cs_block_content'                      => isset( $_POST[ '_cs_block_content' ] ) ? sanitize_text_field( $_POST[ '_cs_block_content' ] ) : null,
								'_cs_refresh_after_consent'              => isset( $_POST[ '_cs_refresh_after_consent' ] ) ? sanitize_text_field( $_POST[ '_cs_refresh_after_consent' ] ) : 0,
								'_cs_enable_rule'                        => isset( $_POST[ '_cs_enable_rule' ] ) ? sanitize_text_field( $_POST[ '_cs_enable_rule' ] ) : null,
								'_cs_no_ip_rule'                         => isset( $_POST[ '_cs_no_ip_rule' ] ) ? sanitize_text_field( $_POST[ '_cs_no_ip_rule' ] ) : null,
								'_excluded_from_consent_storing'         => isset( $_POST[ '_excluded_from_consent_storing' ] ) ? sanitize_text_field( $_POST[ '_excluded_from_consent_storing' ] ) : null,
								'_cs_showing_rule_until_express_consent' => isset( $_POST[ '_cs_showing_rule_until_express_consent' ] ) ? sanitize_text_field( $_POST[ '_cs_showing_rule_until_express_consent' ] ) : null,
							)
						);
						$cookie_data[ 'meta_input' ] = array_merge( $cookie_data[ 'meta_input' ], $categories_options );

						$post_id = wp_insert_post( $cookie_data );
						wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-category' );
						$options = get_lang_meta_list();
						$all_langs = get_language_list();
						foreach ( $options as $option ) {
							$key_langs = array();
							$lang_options[ $option ] = array();
							foreach ( $_POST as $item_name => $val ) {

								if ( gettype( $val ) === 'string' ) {
									$val = wp_kses_post( wp_unslash( $val ) );
								} else {
									continue;
								}
								$item_name = sanitize_text_field( $item_name );
								if ( strripos( $item_name, $option ) !== false ) {
									$lang = str_replace( $option . '_', '', $item_name );

									if ( $lang != $option && array_key_exists( $lang, $all_langs ) ) {
										array_push( $key_langs, $lang );
										update_post_meta( $post_id, $item_name, $val );
									}
								}
							}
							update_post_meta( $post_id, $option . '_lang', $key_langs );
						}
					}
				}

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_script_form' ) {

				$post_data = array();

				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$k = sanitize_text_field( $key );
					if ( in_array( $k, get_text_editor_fields() ) ) {
						$post_data[ sanitize_text_field( $k ) ] = wp_kses_post( wp_unslash( $value ) );
					} else {
						$post_data[ sanitize_text_field( $k ) ] = sanitize_text_field( $value );
					}
				} );

				if ( !$this->cs_post_exists_by_slug( $post_data[ 'cs_default_script_name' ], CMPRO_POST_TYPE_SCRIPTS ) ) {

					$category = get_term_by( 'slug', $post_data[ 'add_new_script_select' ], 'cs-cookies-category' );
					if ( $category && is_object( $category ) ) {
						$category_id = $category->term_id;
						$cookie_data = array(
							'post_type'     => CMPRO_POST_TYPE_SCRIPTS,
							'post_title'    => $post_data[ 'cs_default_script_name' ],
							'post_category' => array( $category_id ),
							'post_status'   => 'publish',
							'ping_status'   => 'closed',
							'post_author'   => 1,
							'meta_input'    => array(
								'cs_default_script_desc'      => $post_data[ 'cs_default_script_desc' ],
								'cs_default_script_js_heedle' => isset( $_POST[ 'heedle' ] ) ? sanitize_text_field( $_POST[ 'heedle' ] ) : null
							)
						);
						$post_id = wp_insert_post( $cookie_data );
						wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-cookies-category' );
						add_option( 'cs_' . sanitize_title( $post_data[ 'cs_default_script_name' ] ) . '_' . $post_id . '_script_enable', '1' );
						add_option( 'cs_' . $post_id . '_script_cat', $post_data[ 'add_new_script_select' ] );
					}
				}

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_script_form' ) {

				$post_data = array();

				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
				} );

				$post_id = $post_data[ 'cs_script_id' ];
				$script_cat = isset( $_POST[ 'cs_' . $post_id . '_script_cat' ] ) ? sanitize_text_field( $_POST[ 'cs_' . $post_id . '_script_cat' ] ) : null;
				$category = get_term_by( 'slug', $script_cat, 'cs-cookies-category' );
				if ( $category && is_object( $category ) ) {
					$category_id = $category->term_id;
					wp_set_object_terms( $post_id, $category_id, 'cs-cookies-category' );
					update_option( 'cs_' . $script_cat . '_' . $post_id . '_script_enable', true );
					update_option( 'cs_' . $post_id . '_script_cat', $script_cat );
				}
				$template_data = array(
					'ID'         => $post_id,
					'meta_input' => array(
						'cs_default_script_desc'      => isset( $_POST[ 'cs_default_script_desc' ] ) ? wp_kses_post( wp_unslash( $_POST[ 'cs_default_script_desc' ] ) ) : null,
						'cs_default_script_js_heedle' => isset( $_POST[ 'heedle' ] ) ? sanitize_text_field( $_POST[ 'heedle' ] ) : null
					)
				);

				wp_update_post( $template_data );

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'add_cookie_form' ) {

				$post_data = array();
				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
				} );

				if ( !$this->cs_post_exists_by_slug( $post_data[ 'cs_default_cookie_name' ], CMPRO_POST_TYPE_COOKIES ) ) {

					$category = get_term_by( 'slug', $post_data[ 'add_new_cookie_select' ], 'cs-cookies-category' );
					if ( $category && is_object( $category ) ) {
						$category_id = $category->term_id;
						$cookie_data = array(
							'post_type'     => CMPRO_POST_TYPE_COOKIES,
							'post_title'    => $post_data[ 'cs_default_cookie_name' ],
							'post_category' => array( $category_id ),
							'post_status'   => 'publish',
							'ping_status'   => 'closed',
							'post_author'   => 1,
							'meta_input'    => array(
								'cs_default_cookie_desc' => $post_data[ 'cs_default_cookie_desc' ],
							)
						);
						$post_id = wp_insert_post( $cookie_data );
						wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-cookies-category' );
						add_option( 'cs_' . sanitize_title( $post_data[ 'cs_default_cookie_name' ] ) . '_' . $post_id . '_cookie_enable', '1' );
						add_option( 'cs_' . $post_id . '_cookie_cat', $post_data[ 'add_new_cookie_select' ] );
					}
				}

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_cookie_form' ) {

				$post_data = array();
				array_walk( $_POST[ 'cs' ][ $this->plugin_name ], function ( &$value, $key ) use ( &$post_data ) {
					$post_data[ sanitize_text_field( $key ) ] = sanitize_text_field( $value );
				} );

				$post_id = $post_data[ 'cs_cookie_id' ];
				$script_cat = isset( $_POST[ 'cs_' . $post_id . '_cookie_cat' ] ) ? sanitize_text_field( $_POST[ 'cs_' . $post_id . '_cookie_cat' ] ) : null;
				$category = get_term_by( 'slug', $script_cat, 'cs-cookies-category' );
				if ( $category && is_object( $category ) ) {
					$category_id = $category->term_id;
					wp_set_object_terms( $post_id, $category_id, 'cs-cookies-category' );
					update_option( 'cs_' . $script_cat . '_' . $post_id . '_cookie_enable', true );
					update_option( 'cs_' . $post_id . '_cookie_cat', $script_cat );
				}
				$template_data = array(
					'ID'         => $post_id,
					'meta_input' => array(
						'cs_default_cookie_desc' => isset( $_POST[ 'cs_default_cookie_desc' ] ) ? sanitize_text_field( $_POST[ 'cs_default_cookie_desc' ] ) : null,
					)
				);

				wp_update_post( $template_data );

				echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
				if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
					exit();
				}
			}

			if ( isset( $_POST[ 'cs_settings_ajax_update' ] ) && $_POST[ 'cs_settings_ajax_update' ] == 'delete_custom_post' ) {

				if ( isset( $_POST[ 'post_id' ] ) ) {
					$post_id = isset( $_POST[ 'post_id' ] ) ? sanitize_text_field( $_POST[ 'post_id' ] ) : null;
					$data_cat = isset( $_POST[ 'data_cat' ] ) ? sanitize_text_field( $_POST[ 'data_cat' ] ) : null;
					wp_delete_post( $post_id, true );
					delete_option( 'cs_' . $data_cat . '_' . $post_id . '_cookie_enable' );
					delete_option( 'cs_' . $post_id . '_cookie_cat' );
					delete_option( 'cs_' . $data_cat . '_' . $post_id . '_script_enable' );
					delete_option( 'cs_' . $post_id . '_script_cat' );
				}
			}
		}

		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			settings_errors();

			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} elseif ( !isset( $_GET[ 'rule_id' ] ) && !isset( $_GET[ 'new_rule' ] ) && !isset( $_GET[ 'primary_rule_id' ] ) && !isset( $_GET[ 'new_cookie' ] ) && !isset( $_GET[ 'cookie_id' ] ) && !isset( $_GET[ 'new_script' ] ) && !isset( $_GET[ 'script_id' ] ) && !isset( $_GET[ 'design_template' ] ) ) {
			require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/general/html-wrapper-main.php';
		}
	}

	public function adminPageAdditionals() {
		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) );
		}
		$the_options = ConsentMagic()->getCSOptions();
		if ( isset( $_REQUEST[ '_wpnonce' ] ) && wp_verify_nonce( $_REQUEST[ '_wpnonce' ], 'cs-update-' . CMPRO_SETTINGS_FIELD ) && isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {

			foreach ( $the_options as $key => $value ) {
				if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
					ConsentMagic()->updateOptions( sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) );
				}
				if ( isset( $_POST[ '_cs_top_push' ] ) ) {
					$_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] = sanitize_text_field( $_POST[ '_cs_top_push' ] );
					ConsentMagic()->updateOptions( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] ) ? sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_top_push' ] ) : '' );
				}
			}

			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}
		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			settings_errors();
			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} else {
			include CMPRO_PLUGIN_VIEWS_PATH . 'admin/additionals/html-additionals.php';
		}
	}

	public function adminPageProofConsent() {
		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) );
		}
		$the_options = ConsentMagic()->getCSOptions();
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {
			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

			foreach ( $the_options as $key => $value ) {
				if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
					ConsentMagic()->updateOptions( sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) );
				}
			}

			foreach ( $_POST as $item_name => $val ) {
				if ( get_option( $item_name ) !== false ) {
					update_option( sanitize_text_field( $item_name ), sanitize_text_field( $val ) );
				}
			}
			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}

		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'delete_proof_consent' ) {
			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

			global $wpdb;
			$table = $wpdb->prefix . 'cs_proof_consent';
			$delete = $wpdb->query( $wpdb->prepare( 'DELETE FROM %1$s', $table ) );
			$this->renew_consent_run();
			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}

		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			settings_errors();
			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} else {
			include CMPRO_PLUGIN_VIEWS_PATH . 'admin/proofconsent/html-proofconsent.php';
		}
	}

	public function adminPageProofStatistics() {
		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) );
		}

		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			settings_errors();
			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} else {
			include CMPRO_PLUGIN_VIEWS_PATH . 'admin/statistics/html-statistics.php';
		}
	}

	public function adminPageSettings() {

		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) );
		}
		// Get options:
		$the_options = ConsentMagic()->getCSOptions();

		if ( isset( $_GET[ 'cs_update_action' ] ) && $_GET[ 'cs_update_action' ] == 'cs_test_mode_disable' ) {
			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

			$cs_test_mode = array(
				'cs_test_mode' => false
			);

			foreach ( $the_options as $key => $value ) {
				if ( $key == 'cs_test_mode' ) {
					ConsentMagic()->updateOptions( $cs_test_mode );
				}
			}

			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}

			wp_redirect( remove_query_arg( 'cs_update_action', false ) );
		}

		if ( isset( $_GET[ 'cs_update_action' ] ) && $_GET[ 'cs_update_action' ] == 'cs_test_consent_clear' ) {
			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );
			$consent_version_test = ConsentMagic()->cs_get_consent_version_test();
			if ( !empty( $consent_version_test ) ) {
				$consent_version_test = $consent_version_test + 1;
				update_option( 'wt_cs_consent_version_test', $consent_version_test );
			}

			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}

			wp_redirect( remove_query_arg( 'cs_update_action', false ) );
		}

		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {

			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );
			$permissions = ( isset( $_POST[ 'permissions' ] ) ? sanitize_text_field( $_POST[ 'permissions' ] ) : '' ) . ',administrator';
			$permissions = explode( ",", $permissions );

			$ignore_users = isset( $_POST[ 'ignore_users' ] ) ? sanitize_text_field( $_POST[ 'ignore_users' ] ) : '';
			$ignore_users = explode( ",", $ignore_users );

			$ignore_users_ip = isset( $_POST[ 'ignore_users_ip' ] ) ? sanitize_text_field( $_POST[ 'ignore_users_ip' ] ) : '';
			$ignore_users_ip = explode( ",", $ignore_users_ip );

			$important_emails = isset( $_POST[ 'important_emails' ] ) ? sanitize_text_field( $_POST[ 'important_emails' ] ) : '';
			$emails = explode( ",", $important_emails );

			foreach ( $the_options as $key => $value ) {
				if ( $key == 'cs_admin_permissions' ) {
					update_option( 'cs_admin_permissions', $permissions );
				} else if ( $key == 'cs_send_important_emails' ) {
					update_option( 'cs_send_important_emails', $emails );
				} else if ( $key == 'cs_admin_ignore_users' ) {
					update_option( 'cs_admin_ignore_users', $ignore_users );
				} else if ( $key == 'cs_admin_ignore_users_ip' ) {
					update_option( 'cs_admin_ignore_users_ip', $ignore_users_ip );
				} else if ( $key == 'cs_scanner_module' && isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
					$csmart_admin_modules = get_option( 'csmart_admin_modules' );
					if ( $csmart_admin_modules === false ) {
						$csmart_admin_modules = array();
					}
					$csmart_admin_modules[ 'scanner' ] = ( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_scanner_module' ] == true ) ? 1 : 0;
					update_option( 'csmart_admin_modules', $csmart_admin_modules );
				} else {
					if ( !isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key . '_0' ] ) && isset( $_POST[ 'cs' ][ $this->plugin_name ] ) ) {
						$key_langs = array();
						$all_langs = get_language_list();
						$lang_save = false;
						foreach ( $_POST[ 'cs' ][ $this->plugin_name ] as $post_key => $post_val ) {
							$post_key = sanitize_text_field( $post_key );
							$post_val = sanitize_text_field( $post_val );
							if ( strripos( $post_key, $key ) !== false ) {
								$lang = str_replace( $key . '_', '', $post_key );
								if ( $lang != $post_key && array_key_exists( $lang, $all_langs ) ) {

									ConsentMagic()->updateLangOptions( array( $key => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $post_key ] ) ), $lang );
									array_push( $key_langs, $lang );
									$lang_save = true;
								}
							}
						}

						if ( $lang_save ) {
							ConsentMagic()->updateOptions( array( $key . '_lang' => $key_langs ) );
						}
					}

					if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) ) {
						ConsentMagic()->updateOptions( sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ $key ] ) );
					}
				}
			}

			foreach ( $_POST as $item_name => $val ) {
				if ( get_option( sanitize_text_field( $item_name ) ) !== false ) {
					update_option( sanitize_text_field( $item_name ), sanitize_text_field( $val ) );
				}
			}
			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}

		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'cs_restore_translations' ) {
			$this->loadTranslations( true, true );
			echo '<div class="updated"><p><strong>' . esc_html__( 'Translations restored.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}

		//Restart Setup Process
		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'restart_setup_process' ) {

			if ( ConsentMagic()->getOption( 'cs_deactivation_db_clear' ) == 1 ) {
				require_once CMPRO_PLUGIN_PATH . 'includes/CS_Uninstall.php';
				require_once CMPRO_PLUGIN_PATH . 'includes/CS_Activator.php';

				CS_Uninstall::deactivation( false );

				ConsentMagic()->resetToDefaults();
				ConsentMagic()->check_tables();

				$this->create_taxonomy();
				$this->cs_insert_templates_lists();
				$this->cs_insert_cookie_lists();

				( new CS_Activator )->activate();

				//install tables
				$scanner_module = new CS_Scanner_Module;
				$scanner_module->install_tables();

			} else {

				$id = get_post_id_by_slug( 'cs_gdpr_rule' );
				wp_delete_post( $id, true );
				$id = get_post_id_by_slug( 'cs_ccpa_rule' );
				wp_delete_post( $id, true );
				$id = get_post_id_by_slug( 'cs_rest_of_world_rule' );
				wp_delete_post( $id, true );

				if ( !is_multisite() ) {
					delete_option( 'cs_policy_existing_page' );
				} else {

					global $wpdb;
					$blog_ids = $wpdb->get_col( $wpdb->prepare( 'SELECT blog_id FROM %1$s', $wpdb->blogs ) );
					$original_blog_id = get_current_blog_id();

					foreach ( $blog_ids as $blog_id ) {
						switch_to_blog( $blog_id );
						delete_site_option( 'cs_policy_existing_page' );
					}
					switch_to_blog( $original_blog_id );
				}

				ConsentMagic()->deleteOption( 'cs_script_blocking_enabled' );
				ConsentMagic()->updateOptions( array( 'default_font' => '' ) );
				ConsentMagic()->updateOptions( array( 'cs_check_flow' => false ) );

			}

			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}

		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} else {
			include CMPRO_PLUGIN_VIEWS_PATH . 'admin/settings/html-settings.php';
		}
	}

	public function adminPageGeolocation() {

		// Lock out non-admins:
		if ( !current_user_can( 'manage_cs' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permission to perform this operation', 'consent-magic' ) );
		}

		if ( isset( $_POST[ 'cs_update_action' ] ) && $_POST[ 'cs_update_action' ] == 'update_admin_settings_form' ) {

			// Check nonce:
			check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

			if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_geolocation' ] ) ) {
				ConsentMagic()->updateOptions( array( 'cs_geolocation' => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_geolocation' ] ) ) );
			}

			if ( isset( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_often_update' ] ) ) {
				$old_cs_often_update = ConsentMagic()->getOption( 'cs_often_update' );
				if ( $old_cs_often_update != $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_often_update' ] ) {
					ConsentMagic()->updateOptions( array( 'cs_often_update' => sanitize_text_field( $_POST[ 'cs' ][ $this->plugin_name ][ 'cs_often_update' ] ) ) );
					if ( $old_cs_often_update == 'never' ) {
						db_cron_change_recurrence();
					} else {
						db_cron_change_recurrence( true );
					}
				}
			}
			echo '<div class="updated"><p><strong>' . esc_html__( 'Settings Updated.', 'consent-magic' ) . '</strong></p></div>';
			if ( !empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) && strtolower( sanitize_text_field( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ) == 'xmlhttprequest' ) {
				exit();
			}
		}

		if ( ConsentMagic()->getOption( 'cs_geolocation' ) && ConsentMagic()->getOption( 'cs_geo_activated' ) && ConsentMagic()->getOption( 'cs_often_update' ) != 'never' ) {
			db_cron_update();
		} else {
			db_cron_deactivate();
		}
		settings_errors();

		$cs_often_update_list = ConsentMagic()->getOption( 'cs_often_update_list' );

		if ( !ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			settings_errors();
			if ( CMPRO_LICENSE_TYPE == 'edd' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-edd.php';
			} elseif ( CMPRO_LICENSE_TYPE == 'woo' ) {
				require_once CMPRO_PLUGIN_VIEWS_PATH . 'admin/html-first-flow-wc.php';
			}
		} else {
			include CMPRO_PLUGIN_VIEWS_PATH . 'admin/geolocation/html-geolocation.php';
		}
	}

	public function register_custom_post_type() {
		$labels = array(
			'name'               => esc_html__( 'ConsentMagic', 'consent-magic' ),
			'all_items'          => esc_html__( 'Rules List', 'consent-magic' ),
			'singular_name'      => esc_html__( 'Rule', 'consent-magic' ),
			'add_new'            => esc_html__( 'Add New', 'consent-magic' ),
			'add_new_item'       => esc_html__( 'Add New Rule', 'consent-magic' ),
			'edit_item'          => esc_html__( 'Edit Rule', 'consent-magic' ),
			'new_item'           => esc_html__( 'New Rule', 'consent-magic' ),
			'view_item'          => esc_html__( 'View Rule', 'consent-magic' ),
			'search_items'       => esc_html__( 'Search Rules', 'consent-magic' ),
			'not_found'          => esc_html__( 'Nothing found', 'consent-magic' ),
			'not_found_in_trash' => esc_html__( 'Nothing found in Trash', 'consent-magic' ),
			'parent_item_colon'  => ''
		);
		$args = array(
			'labels'              => $labels,
			'public'              => false,
			'publicly_queryable'  => false,
			'exclude_from_search' => true,
			'show_ui'             => false,
			'query_var'           => false,
			'rewrite'             => true,
			'show_in_menu'        => false,
			'menu_icon'           => '',
			'capabilities'        => array(
				'publish_posts'       => 'manage_cs',
				'edit_posts'          => 'manage_cs',
				'edit_others_posts'   => 'manage_cs',
				'delete_posts'        => 'manage_cs',
				'delete_others_posts' => 'manage_cs',
				'read_private_posts'  => 'manage_cs',
				'edit_post'           => 'manage_cs',
				'delete_post'         => 'manage_cs',
				'read_post'           => 'manage_cs',
			),
			'taxonomies'          => array( 'cs-category' ),
			'hierarchical'        => true,
			'menu_position'       => null,
			'supports'            => array(
				'title',
				'editor',
				'page-attributes'
			)
		);
		register_post_type( CMPRO_POST_TYPE, $args );

		$labels = array(
			'name' => esc_html__( 'CS Templates', 'consent-magic' ),
		);
		$args = array(
			'labels'              => $labels,
			'public'              => false,
			'publicly_queryable'  => false,
			'exclude_from_search' => true,
			'show_ui'             => false,
			'query_var'           => false,
			'rewrite'             => true,
			'show_in_menu'        => false,
			'menu_icon'           => '',
			'capabilities'        => array(
				'publish_posts'       => 'manage_cs',
				'edit_posts'          => 'manage_cs',
				'edit_others_posts'   => 'manage_cs',
				'delete_posts'        => 'manage_cs',
				'delete_others_posts' => 'manage_cs',
				'read_private_posts'  => 'manage_cs',
				'edit_post'           => 'manage_cs',
				'delete_post'         => 'manage_cs',
				'read_post'           => 'manage_cs',
			),
			'menu_position'       => null,
			'supports'            => array(
				'title',
				'editor',
				'page-attributes'
			)
		);
		register_post_type( CMPRO_TEMPLATE_POST_TYPE, $args );

		$labels = array(
			'name'               => esc_html__( 'CS Scripts', 'consent-magic' ),
			'all_items'          => esc_html__( 'Scripts List', 'consent-magic' ),
			'singular_name'      => esc_html__( 'Script', 'consent-magic' ),
			'add_new'            => esc_html__( 'Add New', 'consent-magic' ),
			'add_new_item'       => esc_html__( 'Add New Script', 'consent-magic' ),
			'edit_item'          => esc_html__( 'Edit Script', 'consent-magic' ),
			'new_item'           => esc_html__( 'New Script', 'consent-magic' ),
			'view_item'          => esc_html__( 'View Script', 'consent-magic' ),
			'search_items'       => esc_html__( 'Search Scripts', 'consent-magic' ),
			'not_found'          => esc_html__( 'Nothing found', 'consent-magic' ),
			'not_found_in_trash' => esc_html__( 'Nothing found in Trash', 'consent-magic' ),
			'parent_item_colon'  => ''
		);
		$args = array(
			'labels'              => $labels,
			'public'              => false,
			'publicly_queryable'  => false,
			'exclude_from_search' => true,
			'show_ui'             => false,
			'query_var'           => false,
			'rewrite'             => true,
			'show_in_menu'        => false,
			'menu_icon'           => '',
			'capabilities'        => array(
				'publish_posts'       => 'manage_cs',
				'edit_posts'          => 'manage_cs',
				'edit_others_posts'   => 'manage_cs',
				'delete_posts'        => 'manage_cs',
				'delete_others_posts' => 'manage_cs',
				'read_private_posts'  => 'manage_cs',
				'edit_post'           => 'manage_cs',
				'delete_post'         => 'manage_cs',
				'read_post'           => 'manage_cs',
			),
			'taxonomies'          => array( 'cs-cookies-category' ),
			'hierarchical'        => true,
			'menu_position'       => null,
			'supports'            => array(
				'title',
				'editor',
				'page-attributes'
			)
		);
		register_post_type( CMPRO_POST_TYPE_SCRIPTS, $args );

		$labels = array(
			'name'               => esc_html__( 'CS Cookies', 'consent-magic' ),
			'all_items'          => esc_html__( 'Cookies List', 'consent-magic' ),
			'singular_name'      => esc_html__( 'Cookie', 'consent-magic' ),
			'add_new'            => esc_html__( 'Add New', 'consent-magic' ),
			'add_new_item'       => esc_html__( 'Add New Cookie', 'consent-magic' ),
			'edit_item'          => esc_html__( 'Edit Cookie', 'consent-magic' ),
			'new_item'           => esc_html__( 'New Cookie', 'consent-magic' ),
			'view_item'          => esc_html__( 'View Cookie', 'consent-magic' ),
			'search_items'       => esc_html__( 'Search Cookies', 'consent-magic' ),
			'not_found'          => esc_html__( 'Nothing found', 'consent-magic' ),
			'not_found_in_trash' => esc_html__( 'Nothing found in Trash', 'consent-magic' ),
			'parent_item_colon'  => ''
		);
		$args = array(
			'labels'              => $labels,
			'public'              => false,
			'publicly_queryable'  => false,
			'exclude_from_search' => true,
			'show_ui'             => false,
			'query_var'           => false,
			'rewrite'             => true,
			'show_in_menu'        => false,
			'menu_icon'           => '',
			'capabilities'        => array(
				'publish_posts'       => 'manage_cs',
				'edit_posts'          => 'manage_cs',
				'edit_others_posts'   => 'manage_cs',
				'delete_posts'        => 'manage_cs',
				'delete_others_posts' => 'manage_cs',
				'read_private_posts'  => 'manage_cs',
				'edit_post'           => 'manage_cs',
				'delete_post'         => 'manage_cs',
				'read_post'           => 'manage_cs',
			),
			'taxonomies'          => array( 'cs-cookies-category' ),
			'hierarchical'        => true,
			'menu_position'       => null,
			'supports'            => array(
				'title',
				'editor',
				'page-attributes'
			)
		);
		register_post_type( CMPRO_POST_TYPE_COOKIES, $args );
	}

	/**
	 * Registering cookie category
	 *
	 */
	public function create_taxonomy() {
		register_taxonomy( 'cs-category', CMPRO_POST_TYPE, array(
			'label'        => esc_html__( 'Rules Category', 'consent-magic' ),
			'rewrite'      => array( 'slug' => 'cs-category' ),
			'hierarchical' => true,
			'show_in_menu' => true,
			'show_ui'      => true,
			'query_var'    => true,
		) );

		register_taxonomy( 'cs-cookies-category', array(
			CMPRO_POST_TYPE_COOKIES,
			CMPRO_POST_TYPE_SCRIPTS
		), array(
			'label'        => esc_html__( 'Scripts Category', 'consent-magic' ),
			'rewrite'      => array( 'slug' => 'cs-cookies-category' ),
			'hierarchical' => true,
			'show_in_menu' => true,
			'show_ui'      => true,
			'query_var'    => true,
		) );

		global $sitepress;
		$wpml_default_lang = 'en';
		$wpml_current_lang = 'en';
		if ( function_exists( 'icl_object_id' ) && $sitepress ) {
			$wpml_default_lang = $sitepress->get_default_language();
			$wpml_current_lang = ICL_LANGUAGE_CODE;
		}
		if ( $wpml_default_lang == $wpml_current_lang ) {
			$term = get_term_by( 'slug', 'rules', 'cs-category' );
			if ( @!$term->term_id ) {
				wp_insert_term( 'Rules', 'cs-category', array(
					'description' => '',
					'slug'        => 'rules'
				) );
			}

			$term = get_term_by( 'slug', 'necessary', 'cs-cookies-category' );
			if ( !$term ) {
				$cid = wp_insert_term( 'Necessary', 'cs-cookies-category', array(
					'slug' => 'necessary'
				) );
				if ( !is_wp_error( $cid ) ) {
					$description = array(
						'name'  => 'Necessary',
						'descr' => 'These cookies and scripts are necessary for the website to function and cannot be switched off. They are usually only set in response to actions made by you which amount to a request for services, suchas setting your privacy preferences, logging in or filling in forms. You can set your browser to block oralert you about these cookies, but some parts of the site will not then work. These cookies do notstore any personally identifiable information.',
					);
					// Get term_id, set default as 0 if not set
					$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
					add_term_meta( $cat_id, 'cs_primary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_necessary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_ignore_this_category', '0', true );
					add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description );
					add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					update_option( 'necessary_cat_id', $cat_id );
				} else {
					// Trouble in Paradise:
					echo esc_html( $cid->get_error_message() );
				}
			}

			$term = get_term_by( 'slug', 'analytics', 'cs-cookies-category' );
			if ( !$term ) {
				$cid = wp_insert_term( 'Analytics', 'cs-cookies-category', array(
					'slug' => 'analytics'
				) );
				if ( !is_wp_error( $cid ) ) {
					$description = array(
						'name'  => 'Analytics',
						'descr' => 'These cookies and scripts allow us to count visits and traffic sources, so we can measure and improve the performance of our site. They help us know which pages are the most and least popular and see how visitors move around the site. All information these cookies collect is aggregated and therefore anonymous. If you do not allow these cookies and scripts, we will not know when you have visited our site.',
					);
					// Get term_id, set default as 0 if not set
					$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
					add_term_meta( $cat_id, 'cs_primary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
					add_term_meta( $cat_id, 'cs_ignore_this_category', '0', true );
					add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description );
					add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					update_option( 'analytics_cat_id', $cat_id );
				} else {
					// Trouble in Paradise:
					echo esc_html( $cid->get_error_message() );
				}
			}

			$term = get_term_by( 'slug', 'marketing', 'cs-cookies-category' );
			if ( !$term ) {
				$cid = wp_insert_term( 'Marketing', 'cs-cookies-category', array(
					'slug' => 'marketing'
				) );
				if ( !is_wp_error( $cid ) ) {
					$description = array(
						'name'  => 'Marketing',
						'descr' => 'These cookies and scripts  may be set through our site by our advertising partners. They may be used by those companies to build a profile of your interests and show you relevant adverts on other sites. They do not store directly personal information, but are based on uniquely identifying your browser and internet device. If you do not allow these cookies and scripts, you will experience less targeted advertising.',
					);
					// Get term_id, set default as 0 if not set
					$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
					add_term_meta( $cat_id, 'cs_primary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
					add_term_meta( $cat_id, 'cs_ignore_this_category', '0', true );
					add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description );
					add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					update_option( 'marketing_cat_id', $cat_id );
				} else {
					// Trouble in Paradise:
					echo esc_html( $cid->get_error_message() );
				}
			}

			$term = get_term_by( 'slug', 'googlefonts', 'cs-cookies-category' );
			if ( !$term ) {
				$cid = wp_insert_term( 'Google Fonts', 'cs-cookies-category', array(
					'slug' => 'googlefonts'
				) );
				if ( !is_wp_error( $cid ) ) {
					$description = array(
						'name'  => 'Google Fonts',
						'descr' => 'Google Fonts is a font embedding service library. Google Fonts are stored on Google\'s CDN. The Google Fonts API is designed to limit the collection, storage, and use of end-user data to only what is needed to serve fonts efficiently. Use of Google Fonts API is unauthenticated. No cookies are sent by website visitors to the Google Fonts API. Requests to the Google Fonts API are made to resource-specific domains, such as fonts.googleapis.com or fonts.gstatic.com. This means your font requests are separate from and don\'t contain any credentials you send to google.com while using other Google services that are authenticated, such as Gmail.',
					);
					// Get term_id, set default as 0 if not set
					$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
					add_term_meta( $cat_id, 'cs_primary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
					add_term_meta( $cat_id, 'cs_ignore_this_category', '1', true );
					add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description );
					add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					update_option( 'googlefonts_cat_id', $cat_id );
				} else {
					// Trouble in Paradise:
					echo esc_html( $cid->get_error_message() );
				}
			}

			$term = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
			if ( !$term ) {
				$cid = wp_insert_term( 'Unassigned', 'cs-cookies-category', array(
					'slug' => 'unassigned'
				) );
				if ( !is_wp_error( $cid ) ) {
					$description = array(
						'name'  => 'Unassigned',
						'descr' => 'These cookies and scripts  may be set through our site by our advertising partners. They may be used by those companies to build a profile of your interests and show you relevant adverts on other sites. They do not store directly personal information, but are based on uniquely identifying your browser and internet device. If you do not allow these cookies and scripts, you will experience less targeted advertising.',
					);
					// Get term_id, set default as 0 if not set
					$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
					add_term_meta( $cat_id, 'cs_primary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
					add_term_meta( $cat_id, 'cs_ignore_this_category', '1', true );
					add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description );
					add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					update_option( 'unassigned_cat_id', $cat_id );
				} else {
					// Trouble in Paradise:
					echo esc_html( $cid->get_error_message() );
				}
			}

			$term = get_term_by( 'slug', 'embedded_video', 'cs-cookies-category' );
			if ( !$term ) {
				$cid = wp_insert_term( 'Embedded Videos', 'cs-cookies-category', array(
					'slug' => 'embedded_video'
				) );
				if ( !is_wp_error( $cid ) ) {
					$description = array(
						'name'  => 'Embedded Videos',
						'descr' => 'These cookies and scripts may be set through our site by external video hosting services likeYouTube or Vimeo. They may be used to deliver video content on our website. It’s possible for the video provider to build a profile of your interests and show you relevant adverts on this or other websites. They do not store directly personal information, but are based on uniquely identifying your browser and internet device. If you do not allow these cookies or scripts it is possible that embedded video will not function as expected.',
					);
					// Get term_id, set default as 0 if not set
					$cat_id = isset( $cid[ 'term_id' ] ) ? $cid[ 'term_id' ] : 0;
					add_term_meta( $cat_id, 'cs_primary_term', 'primary', true );
					add_term_meta( $cat_id, 'cs_necessary_term', 'custom', true );
					add_term_meta( $cat_id, 'cs_ignore_this_category', '0', true );
					add_term_meta( $cat_id, 'cs_edit_cat_description_' . CMPRO_DEFAULT_LANGUAGE, $description );
					add_term_meta( $cat_id, 'cs_edit_cat_description_lang', array( CMPRO_DEFAULT_LANGUAGE ) );
					update_option( 'embedded_video_cat_id', $cat_id );
				} else {
					// Trouble in Paradise:
					echo esc_html( $cid->get_error_message() );
				}
			}
		}
	}

	/**
	 * Insert Dummy post
	 *
	 */
	public function cs_insert_cookie_lists() {

		$not_enough_rule = false;
		foreach ( static::$default_rules as $default_rule ) {
			if ( !$this->cs_post_exists_by_slug( $default_rule, CMPRO_POST_TYPE ) ) {
				$not_enough_rule = true;
			}
		}

		if ( $not_enough_rule ) {

			$cs_light_theme_id = get_page_id_by_path( 'cs_light_theme', '', CMPRO_TEMPLATE_POST_TYPE );

			$default_cookies = array(
				array(
					'post_title'                            => 'GDPR Rule',
					'slug'                                  => 'cs_gdpr_rule',
					'post_content'                          => '',
					'post_category'                         => 'rules',
					'cs_type'                               => 'ask_before_tracking',
					//ask_before_tracking, just_inform, inform_and_opiout
					'cs_sticky'                             => 1,
					'cs_smart_sticky'                       => 0,
					'cs_smart_sticky_mobile'                => 0,
					'cs_custom_button'                      => 0,
					// 1 - sticky, 0 - not-sticky
					'cs_mobile_side_sticky'                 => 0,
					// 1 - true, 0 - false
					'cs_hide_close_btn'                     => 1,
					// 1 - true, 0 - false
					'cs_deny_consent_for_close'           => 0,
					// 1 - true, 0 - false
					'cs_deny_all_btn'                       => 0,
					// 1 - show, 0 - hide
					'cs_bars_position'                      => 'bottom',
					// bottom, top
					'cs_bars_type'                          => 'bar_large',
					// bar_small, bar_large, popup_small, popup_large
					'cs_privacy_link'                       => 1,
					// 1 - on, 0 - off
					'cs_close_on_scroll'                    => 0,
					// 1 - on, 0 - off
					'cs_theme'                              => $cs_light_theme_id,
					'cs_top_push'                           => 0,
					// 1 - on, 0 - off
					'cs_predefined_rule'                    => 1,
					// 1 - on, 0 - off
					'cs_target'                             => 'GDPR,AD,AT,BE,BG,CY,CZ,DK,EE,FI,FR,DE,GR,HU,IE,IT,LT,LU,LV,MT,NL,NO,PL,PT,RO,SE,SI,SK,ES,GB',
					'cs_order'                              => 0,
					'cs_enable_rule'                        => 1,
					'cs_no_ip_rule'                         => 1,
					'cs_track_analytics'                    => 0,
					'cs_custom_text'                        => 0,
					'cs_block_content'                      => 1,
					'cs_rule_status'                        => 'publish',
					'cs_refresh_after_consent'              => 1,
					'excluded_from_consent_storing'         => 0,
					'cs_showing_rule_until_express_consent' => 0,
				),
				array(
					'post_title'                            => 'CCPA Rule',
					'slug'                                  => 'cs_ccpa_rule',
					'post_content'                          => '',
					'post_category'                         => 'rules',
					'cs_type'                               => 'inform_and_opiout',
					//ask_before_tracking, just_inform, inform_and_opiout
					'cs_sticky'                             => 0,
					'cs_smart_sticky'                       => 0,
					'cs_smart_sticky_mobile'                => 0,
					'cs_custom_button'                      => 0,
					// 1 - sticky, 0 - not-sticky
					'cs_mobile_side_sticky'                 => 0,
					// 1 - true, 0 - false
					'cs_hide_close_btn'                     => 0,
					// 1 - true, 0 - false
					'cs_deny_consent_for_close'           => 0,
					// 1 - true, 0 - false
					'cs_deny_all_btn'                       => 0,
					// 1 - show, 0 - hide
					'cs_bars_position'                      => 'bottom',
					// bottom, top
					'cs_bars_type'                          => 'bar_small',
					// bar_small, bar_large, popup_small, popup_large
					'cs_privacy_link'                       => 1,
					// 1 - on, 0 - off
					'cs_close_on_scroll'                    => 0,
					// 1 - on, 0 - off
					'cs_theme'                              => $cs_light_theme_id,
					'cs_top_push'                           => 0,
					// 1 - on, 0 - off
					'cs_predefined_rule'                    => 1,
					// 1 - on, 0 - off
					'cs_target'                             => 'CCPA',
					'cs_order'                              => 1,
					'cs_enable_rule'                        => 0,
					'cs_no_ip_rule'                         => 0,
					'cs_track_analytics'                    => 0,
					'cs_custom_text'                        => 0,
					'cs_block_content'                      => 0,
					'cs_rule_status'                        => 'publish',
					'cs_refresh_after_consent'              => 0,
					'excluded_from_consent_storing'         => 0,
					'cs_showing_rule_until_express_consent' => 0
				),
				array(
					'post_title'                            => 'Rest of the world Rule',
					'slug'                                  => 'cs_rest_of_world_rule',
					'post_content'                          => '',
					'post_category'                         => 'rules',
					'cs_type'                               => 'just_inform',
					//ask_before_tracking, just_inform, inform_and_opiout
					'cs_sticky'                             => 0,
					'cs_smart_sticky'                       => 0,
					'cs_smart_sticky_mobile'                => 0,
					'cs_custom_button'                      => 0,
					// 1 - sticky, 0 - not-sticky
					'cs_mobile_side_sticky'                 => 0,
					// 1 - true, 0 - false
					'cs_hide_close_btn'                     => 0,
					// 1 - true, 0 - false
					'cs_deny_consent_for_close'           => 0,
					// 1 - true, 0 - false
					'cs_deny_all_btn'                       => 0,
					// 1 - show, 0 - hide
					'cs_bars_position'                      => 'bottom',
					// bottom, top
					'cs_bars_type'                          => 'bar_small',
					// bar_small, bar_large, popup_small, popup_large
					'cs_privacy_link'                       => 1,
					// 1 - on, 0 - off
					'cs_close_on_scroll'                    => 1,
					// 1 - on, 0 - off
					'cs_theme'                              => $cs_light_theme_id,
					'cs_top_push'                           => 0,
					// 1 - on, 0 - off
					'cs_predefined_rule'                    => 1,
					// 1 - on, 0 - off
					'cs_target'                             => 'NONGDPR,AF,AG,AI,AL,DZ,AM,AO,AQ,AR,AS,AU,AW,AX,AZ,BA,BB,BD,BF,BH,BI,BJ,BL,BM,BN,BO,BQ,BR,BS,BT,BV,BW,BY,BZ,CA,CC,CD,CF,CG,CI,CK,CL,CM,CN,CO,CR,CU,CV,CW,CX,HR,KH,KM,TD,KY,DJ,DM,DO,EZ,SV,SZ,EG,ER,GQ,ET,FG,FK,FO,GF,PF,TF,GA,GD,GE,GG,GH,GI,GL,GM,GN,GP,GT,GU,GW,GY,HK,VA,HM,HN,HT,ID,IL,IM,IN,IO,IQ,IR,IS,JE,JM,JO,JP,KE,KG,KI,KN,KP,KR,KW,KZ,LA,LB,LI,LR,LS,LY,MA,MC,MD,ME,MG,MH,ML,MM,MN,MO,MQ,MR,MS,MU,MV,MW,MX,MY,FM,YT,MZ,NM,NC,NE,NF,NG,NI,NO,NP,NR,NU,NZ,MK,MP,OM,PA,PE,PG,PH,PK,PN,PR,PS,PW,PY,QA,RE,RU,RW,PM,RS,SA,SB,SC,SD,SG,SH,SJ,SL,SM,SN,SO,SR,SS,ST,GS,MF,CH,LC,LK,SX,SY,VC,WS,ZA,TC,TG,TH,TJ,TK,TL,TM,TN,TO,TR,TT,TV,TW,TZ,UA,UG,AE,UM,US,UY,UZ,VE,VG,VI,VN,VU,EH,WF,YE,ZM,ZW',
					'cs_order'                              => 2,
					'cs_enable_rule'                        => 0,
					'cs_no_ip_rule'                         => 0,
					'cs_track_analytics'                    => 0,
					'cs_custom_text'                        => 0,
					'cs_block_content'                      => 0,
					'cs_rule_status'                        => 'publish',
					'cs_refresh_after_consent'              => 0,
					'excluded_from_consent_storing'         => 0,
					'cs_showing_rule_until_express_consent' => 0
				),
			);

			$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
			$unassigned_id = $unassigned->term_id;
			$categories = get_cookies_terms_objects( null, false, $unassigned_id );

			$categories_options = array();
			if ( !empty( $categories ) ) {
				foreach ( $categories as $category ) {
					$categories_options[ '_cs_smart_sticky_' . $category->term_id ] = '1';
					$categories_options[ '_cs_smart_sticky_mobile_' . $category->term_id ] = '1';
					$categories_options[ '_cs_custom_button_' . $category->term_id ] = '1';
				}
			}

			foreach ( $default_cookies as $cookie_data ) {
				if ( !$this->cs_post_exists_by_slug( $cookie_data[ 'slug' ], CMPRO_POST_TYPE ) ) {

					$category = get_term_by( 'slug', $cookie_data[ 'post_category' ], 'cs-category' );
					if ( $category && is_object( $category ) ) {

						$category_id = $category->term_id;
						$cookie_data = array(
							'post_type'     => CMPRO_POST_TYPE,
							'post_title'    => $cookie_data[ 'post_title' ],
							'post_name'     => $cookie_data[ 'slug' ],
							'post_content'  => $cookie_data[ 'post_content' ],
							'post_category' => array( $category_id ),
							'post_status'   => 'publish',
							'ping_status'   => 'closed',
							'post_author'   => 1,
							'meta_input'    => array(
								'_cs_type'                                       => $cookie_data[ 'cs_type' ],
								'_cs_sticky'                                     => $cookie_data[ 'cs_sticky' ],
								'_cs_smart_sticky'                               => $cookie_data[ 'cs_smart_sticky' ],
								'_cs_smart_sticky_mobile'                        => $cookie_data[ 'cs_smart_sticky_mobile' ],
								'_cs_mobile_side_sticky'                         => $cookie_data[ 'cs_mobile_side_sticky' ],
								'_cs_custom_button'                              => $cookie_data[ 'cs_custom_button' ],
								'_cs_bars_position'                              => $cookie_data[ 'cs_bars_position' ],
								'_cs_bars_type'                                  => $cookie_data[ 'cs_bars_type' ],
								'_cs_top_push'                                   => $cookie_data[ 'cs_top_push' ],
								'_cs_privacy_link'                               => $cookie_data[ 'cs_privacy_link' ],
								'_cs_close_on_scroll'                            => $cookie_data[ 'cs_close_on_scroll' ],
								'_cs_theme'                                      => $cookie_data[ 'cs_theme' ],
								'_cs_deny_all_btn'                               => $cookie_data[ 'cs_deny_all_btn' ],
								'_cs_hide_close_btn'                             => $cookie_data[ 'cs_hide_close_btn' ],
								'_cs_deny_consent_for_close'                     => $cookie_data[ 'cs_deny_consent_for_close' ],
								'_cs_predefined_rule'                            => $cookie_data[ 'cs_predefined_rule' ],
								'_cs_target'                                     => $cookie_data[ 'cs_target' ],
								'_cs_custom_text'                                => $cookie_data[ 'cs_custom_text' ],
								'_cs_text_in_small_bar_popup'                    => '',
								'_cs_text_in_small_bar_popup_lang'               => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_text_in_large_bar_popup'                    => '',
								'_cs_text_in_large_bar_popup_lang'               => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_allow_all'                         => '',
								'_cs_btn_text_allow_all_lang'                    => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_customize'                         => '',
								'_cs_btn_text_customize_lang'                    => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_privacy_cookie'                    => '',
								'_cs_btn_text_privacy_cookie_lang'               => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_sticky_cookie'                     => '',
								'_cs_btn_text_sticky_cookie_lang'                => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_custom_button'                     => '',
								'_cs_btn_text_custom_button_lang'                => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_title_in_options_popup'                     => '',
								'_cs_title_in_options_popup_lang'                => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_subtitle_in_options_popup'                  => '',
								'_cs_subtitle_in_options_popup_lang'             => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_allow_all_in_options_popup'        => '',
								'_cs_btn_text_allow_all_in_options_popup_lang'   => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_disable_all'                       => '',
								'_cs_btn_text_disable_all_lang'                  => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_text_in_options_popup'                      => '',
								'_cs_text_in_options_popup_lang'                 => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_disable_all_in_options_popup'      => '',
								'_cs_btn_text_disable_all_in_options_popup_lang' => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_btn_text_confirm_in_options_popup'          => '',
								'_cs_btn_text_confirm_in_options_popup_lang'     => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_always_on_in_options_popup'                 => '',
								'_cs_always_on_in_options_popup_lang'            => array( CMPRO_DEFAULT_LANGUAGE ),
								'_cs_order'                                      => $cookie_data[ 'cs_order' ],
								'_cs_enable_rule'                                => $cookie_data[ 'cs_enable_rule' ],
								'_cs_no_ip_rule'                                 => $cookie_data[ 'cs_no_ip_rule' ],
								'_cs_track_analytics'                            => $cookie_data[ 'cs_track_analytics' ],
								'_cs_block_content'                              => $cookie_data[ 'cs_block_content' ],
								'_cs_refresh_after_consent'                      => $cookie_data[ 'cs_refresh_after_consent' ],
								'_excluded_from_consent_storing'                 => $cookie_data[ 'excluded_from_consent_storing' ],
								'_cs_showing_rule_until_express_consent'         => $cookie_data[ 'cs_showing_rule_until_express_consent' ],
							)
						);

						$cookie_data[ 'meta_input' ] = array_merge( $cookie_data[ 'meta_input' ], $categories_options );
						$post_id = wp_insert_post( $cookie_data );

						//set option by default rule id (GDPR)
						if ( $cookie_data[ 'post_title' ] == 'GDPR Rule' ) {
							update_option( 'cs_active_rule_id_first', $post_id );
						}

						wp_set_object_terms( $post_id, $cookie_data[ 'post_category' ], 'cs-category' );
					}
				}
			}

			ConsentMagic()->updateOptions( array( 'cs_check_rule_settings' => CMPRO_LATEST_VERSION_NUMBER ) );
		}

		//check for new options
		if ( ConsentMagic()->getOption( 'cs_check_rule_settings' ) != CMPRO_LATEST_VERSION_NUMBER ) {

			$args = array(
				'post_type'      => CMPRO_POST_TYPE,
				'post_status'    => 'publish',
				'posts_per_page' => -1,
				'order'          => 'ASC',
			);
			$rules = get_posts( $args );

			$unassigned = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
			$unassigned_id = $unassigned->term_id;
			$options = get_cookies_terms_objects( null, false, $unassigned_id );

			if ( $rules ) {
				foreach ( $rules as $rule ) {
					$smart_sticky = get_post_meta( $rule->ID, '_cs_smart_sticky', true );
					if ( $smart_sticky === '' ) {
						update_post_meta( $rule->ID, '_cs_smart_sticky', 0 );
						foreach ( $options as $option ) {
							update_post_meta( $rule->ID, '_cs_smart_sticky_' . $option->term_id, 1 );
						}
					}
					$smart_sticky_mobile = get_post_meta( $rule->ID, '_cs_smart_sticky_mobile', true );
					if ( $smart_sticky_mobile === '' ) {
						update_post_meta( $rule->ID, '_cs_smart_sticky_mobile', 0 );
						foreach ( $options as $option ) {
							update_post_meta( $rule->ID, '_cs_smart_sticky_mobile_' . $option->term_id, 1 );
						}
					}
					$custom_button = get_post_meta( $rule->ID, '_cs_custom_button', true );
					if ( $custom_button === '' ) {
						update_post_meta( $rule->ID, '_cs_custom_button', 0 );
						foreach ( $options as $option ) {
							update_post_meta( $rule->ID, '_cs_custom_button_' . $option->term_id, 1 );
						}
					}

					$deny_consent_for_close = get_post_meta( $rule->ID, '_cs_deny_consent_for_close', true );
					if ( $deny_consent_for_close === '' ) {
						update_post_meta( $rule->ID, '_cs_deny_consent_for_close', 0 );
					}
				}
			}

			ConsentMagic()->updateOptions( array( 'cs_check_rule_settings' => CMPRO_LATEST_VERSION_NUMBER ) );
		}
	}

	public function cs_insert_templates_lists() {

		//check template changes for current plugin version
		if ( ConsentMagic()->getOption( 'cs_check_design' ) != CMPRO_LATEST_VERSION_NUMBER ) {

			$general_templates = array();
			$default = array(
				array(
					'post_title'                          => 'Light',
					'slug'                                => 'cs_light_theme',
					'cs_backend_color'                    => '#ffffff',
					'cs_border_style'                     => 'solid',
					'cs_border_weight'                    => '0',
					'cs_border_color'                     => '#333333',
					'cs_text_color'                       => '#444444',
					'cs_links_color'                      => '#212121',
					'cs_titles_text_color'                => '#444444',
					'cs_subtitles_text_color'             => '#444444',
					'cs_accept_all_buttons_bg'            => '#E16B43',
					'cs_accept_all_buttons_text_color'    => '#FFFFFF',
					'cs_custom_button_buttons_bg'         => '#F0F0F0',
					'cs_custom_button_buttons_text_color' => '#212121',
					'cs_deny_all_buttons_bg'              => '#F0F0F0',
					'cs_deny_all_buttons_text_color'      => '#212121',
					'cs_options_buttons_bg'               => '#F0F0F0',
					'cs_options_buttons_text_color'       => '#212121',
					'cs_confirm_buttons_bg'               => '#E16B43',
					'cs_confirm_buttons_text_color'       => '#FFFFFF',
					'cs_sticky_bg'                        => '#ffffff',
					'cs_sticky_link_color'                => '#212121',
					'cs_logo'                             => ' ',
					'cs_logo_size'                        => 'thumbnail',
					'cs_position_vertical_list'           => 'top',
					'cs_position_horizontal_list'         => 'left',
					'cs_cat_color'                        => '#219653',
					'cs_active_toggle_color'              => '#E16B43',
					'cs_main_template'                    => 'main'
				),
				array(
					'post_title'                          => 'Dark',
					'slug'                                => 'cs_dark_theme',
					'cs_backend_color'                    => '#333333',
					'cs_border_style'                     => 'solid',
					'cs_border_weight'                    => '0',
					'cs_border_color'                     => '#000000',
					'cs_text_color'                       => '#ffffff',
					'cs_links_color'                      => '#ffffff',
					'cs_titles_text_color'                => '#ffffff',
					'cs_subtitles_text_color'             => '#ffffff',
					'cs_accept_all_buttons_bg'            => '#E16B43',
					'cs_accept_all_buttons_text_color'    => '#ffffff',
					'cs_custom_button_buttons_bg'         => '#000000',
					'cs_custom_button_buttons_text_color' => '#ffffff',
					'cs_deny_all_buttons_bg'              => '#000000',
					'cs_deny_all_buttons_text_color'      => '#ffffff',
					'cs_options_buttons_bg'               => '#000000',
					'cs_options_buttons_text_color'       => '#ffffff',
					'cs_confirm_buttons_bg'               => '#E16B43',
					'cs_confirm_buttons_text_color'       => '#ffffff',
					'cs_sticky_bg'                        => '#000000',
					'cs_sticky_link_color'                => '#ffffff',
					'cs_logo'                             => ' ',
					'cs_logo_size'                        => 'thumbnail',
					'cs_position_vertical_list'           => 'top',
					'cs_position_horizontal_list'         => 'left',
					'cs_cat_color'                        => '#219653',
					'cs_active_toggle_color'              => '#E16B43',
					'cs_main_template'                    => ''
				),
				array(
					'post_title'                          => 'Orange',
					'slug'                                => 'cs_orange_theme',
					'cs_backend_color'                    => '#E16B43',
					'cs_border_style'                     => 'solid',
					'cs_border_weight'                    => '0',
					'cs_border_color'                     => '#000000',
					'cs_text_color'                       => '#ffffff',
					'cs_links_color'                      => '#472323',
					'cs_titles_text_color'                => '#ffffff',
					'cs_subtitles_text_color'             => '#ffffff',
					'cs_accept_all_buttons_bg'            => '#472323',
					'cs_accept_all_buttons_text_color'    => '#ffffff',
					'cs_custom_button_buttons_bg'         => 'transparent',
					'cs_custom_button_buttons_text_color' => '#ffffff',
					'cs_deny_all_buttons_bg'              => 'transparent',
					'cs_deny_all_buttons_text_color'      => '#ffffff',
					'cs_options_buttons_bg'               => 'transparent',
					'cs_options_buttons_text_color'       => '#ffffff',
					'cs_confirm_buttons_bg'               => '#472323',
					'cs_confirm_buttons_text_color'       => '#ffffff',
					'cs_sticky_bg'                        => '#E16B43',
					'cs_sticky_link_color'                => '#ffffff',
					'cs_logo'                             => ' ',
					'cs_logo_size'                        => 'thumbnail',
					'cs_position_vertical_list'           => 'top',
					'cs_position_horizontal_list'         => 'left',
					'cs_cat_color'                        => '#EBC686',
					'cs_active_toggle_color'              => '#472323',
					'cs_main_template'                    => ''
				),
			);

			foreach ( $default as $templates => $template_data ) {
				$meta = array(
					'cs_backend_color'                    => $template_data[ 'cs_backend_color' ],
					'cs_border_style'                     => $template_data[ 'cs_border_style' ],
					'cs_border_weight'                    => $template_data[ 'cs_border_weight' ],
					'cs_border_color'                     => $template_data[ 'cs_border_color' ],
					'cs_text_color'                       => $template_data[ 'cs_text_color' ],
					'cs_links_color'                      => $template_data[ 'cs_links_color' ],
					'cs_titles_text_color'                => $template_data[ 'cs_titles_text_color' ],
					'cs_subtitles_text_color'             => $template_data[ 'cs_subtitles_text_color' ],
					'cs_accept_all_buttons_bg'            => $template_data[ 'cs_accept_all_buttons_bg' ],
					'cs_accept_all_buttons_text_color'    => $template_data[ 'cs_accept_all_buttons_text_color' ],
					'cs_custom_button_buttons_bg'         => $template_data[ 'cs_custom_button_buttons_bg' ],
					'cs_custom_button_buttons_text_color' => $template_data[ 'cs_custom_button_buttons_text_color' ],
					'cs_deny_all_buttons_bg'              => $template_data[ 'cs_deny_all_buttons_bg' ],
					'cs_deny_all_buttons_text_color'      => $template_data[ 'cs_deny_all_buttons_text_color' ],
					'cs_options_buttons_text_color'       => $template_data[ 'cs_options_buttons_text_color' ],
					'cs_options_buttons_bg'               => $template_data[ 'cs_options_buttons_bg' ],
					'cs_confirm_buttons_bg'               => $template_data[ 'cs_confirm_buttons_bg' ],
					'cs_confirm_buttons_text_color'       => $template_data[ 'cs_confirm_buttons_text_color' ],
					'cs_sticky_bg'                        => $template_data[ 'cs_sticky_bg' ],
					'cs_sticky_link_color'                => $template_data[ 'cs_sticky_link_color' ],
					'cs_logo'                             => $template_data[ 'cs_logo' ],
					'cs_logo_size'                        => $template_data[ 'cs_logo_size' ],
					'cs_position_vertical_list'           => $template_data[ 'cs_position_vertical_list' ],
					'cs_position_horizontal_list'         => $template_data[ 'cs_position_horizontal_list' ],
					'cs_cat_color'                        => $template_data[ 'cs_cat_color' ],
					'cs_active_toggle_color'              => $template_data[ 'cs_active_toggle_color' ],
					'cs_main_template'                    => $template_data[ 'cs_main_template' ]
				);

				if ( !$this->cs_post_exists_by_slug( $template_data[ 'slug' ], CMPRO_TEMPLATE_POST_TYPE ) ) {

					$cookie_data = array(
						'post_type'   => CMPRO_TEMPLATE_POST_TYPE,
						'post_title'  => $template_data[ 'post_title' ],
						'post_name'   => $template_data[ 'slug' ],
						'post_status' => 'publish',
						'ping_status' => 'closed',
						'post_author' => 1,
						'meta_input'  => $meta
					);
					$id = wp_insert_post( $cookie_data );

					$general_templates[] = $id;

				} else {
					$template_id = get_post_id_by_slug( $template_data[ 'slug' ], CMPRO_TEMPLATE_POST_TYPE );
					if ( $template_id ) {
						foreach ( $meta as $key => $value ) {
							update_post_meta( $template_id, $key, $value );
						}
						$general_templates[] = $template_id;
					}
				}
			}

			$default_meta = array(
				'cs_backend_color',
				'cs_border_style',
				'cs_border_weight',
				'cs_border_color',
				'cs_text_color',
				'cs_links_color',
				'cs_titles_text_color',
				'cs_subtitles_text_color',
				'cs_accept_all_buttons_bg',
				'cs_accept_all_buttons_text_color',
				'cs_custom_button_buttons_bg',
				'cs_custom_button_buttons_text_color',
				'cs_deny_all_buttons_bg',
				'cs_deny_all_buttons_text_color',
				'cs_options_buttons_text_color',
				'cs_options_buttons_bg',
				'cs_confirm_buttons_bg',
				'cs_confirm_buttons_text_color',
				'cs_sticky_bg',
				'cs_sticky_link_color',
				'cs_logo',
				'cs_logo_size',
				'cs_position_vertical_list',
				'cs_position_horizontal_list',
				'cs_cat_color',
				'cs_active_toggle_color',
				'cs_main_template'
			);

			//check fields for user templates
			$all_templates = array_column( get_custom_theme_list(), 'option_value' );
			foreach ( $all_templates as $template ) {
				if ( !in_array( $template, $general_templates ) ) {
					foreach ( $default_meta as $value ) {
						if ( empty( get_post_meta( $template, $value, true ) ) ) {
							update_post_meta( $template, $value, ConsentMagic()->getOption( $value ) );
						}
					}
					update_post_meta( $template, 'cs_main_template', '' );
				}
			}

			ConsentMagic()->updateOptions( array( 'cs_check_design' => CMPRO_LATEST_VERSION_NUMBER ) );
		}
	}

	private function cs_post_exists_by_slug( $post_name, $post_type ) {
		global $wpdb;
		if ( $wpdb->query( $wpdb->prepare( "SELECT post_name FROM $wpdb->posts WHERE post_name = %s AND post_type = %s", $post_name, $post_type ) ) ) {
			return true;
		} else {
			return false;
		}
	}

	//delete lang ajax
	function cs_delete_lang() {

		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		if ( isset( $_POST[ 'lang' ] ) && isset( $_POST[ 'meta' ] ) && isset( $_POST[ 'key' ] ) && isset( $_POST[ 'term' ] ) ) {

			$id = sanitize_text_field( $_POST[ 'id' ] );
			$key = sanitize_text_field( $_POST[ 'key' ] );
			$lang = sanitize_text_field( $_POST[ 'lang' ] );

			if ( $_POST[ 'term' ] == 1 ) {
				if ( isset( $_POST[ 'id' ] ) && $_POST[ 'id' ] != false ) {

					$langs = get_term_meta( $id, $key . '_lang', true );

					$langs = array_flip( $langs );
					unset ( $langs[ $lang ] );
					$langs = array_flip( $langs );

					delete_term_meta( $id, $key . '_' . $lang );
					update_term_meta( $id, $key . '_lang', $langs );

				}
			} elseif ( $_POST[ 'meta' ] == 0 ) {
				ConsentMagic()->deleteOption( $key, $lang );
			} else {
				if ( isset( $_POST[ 'id' ] ) && $_POST[ 'id' ] != false ) {

					$langs = get_post_meta( $id, $key . '_lang', true );

					$langs = array_flip( $langs );
					unset ( $langs[ $lang ] );
					$langs = array_flip( $langs );

					delete_post_meta( $id, $key . '_' . $lang );
					update_post_meta( $id, $key . '_lang', $langs );
				}
			}
		}
		wp_die();
	}

	public function cs_cron_check_status_edd() {
		if ( !wp_next_scheduled( 'cs_cron_check_status_edd_hook' ) ) {
			wp_schedule_event( time(), 'daily', 'cs_cron_check_status_edd_hook' );
		}
	}

	public function cs_cron_check_edd_status() {
		if ( !class_exists( 'ConsentMagicPro\CS_EDD_Updater' ) ) {

			require_once 'CS_EDD_Updater.php';

			$license_edd = new CS_EDD_License_manager( 'consent-magic', CMPRO_LICENSE_TYPE, CMPRO_LATEST_VERSION_NUMBER, CMPRO_LICENSE_NAME );
			$license_key = get_option( $license_edd->edd_license_key );

			$plugin_updater = new CS_EDD_Updater( $license_edd->api_url, CMPRO_PLUGIN_FILENAME, array(
				'version'   => CMPRO_LATEST_VERSION_NUMBER,
				'license'   => $license_key,
				'item_name' => CMPRO_LICENSE_NAME,
				'author'    => CMPRO_LICENSE_NAME
			) );
			set_transient( $license_edd->edd_check_for_update_key, $license_edd->edd_check_for_update_key, DAY_IN_SECONDS );

		}
	}

	//check geolocation status and out message
	//out message for cache notification
	public function cs_admin_messages() {

		$url = admin_url( basename( sanitize_text_field( $_SERVER[ 'REQUEST_URI' ] ) ) );
		if ( strpos( $url, '?' ) === false ) {
			$url .= '?';
		} else {
			$url .= '&';
		}

		if ( ConsentMagic()->getOption( 'cs_check_flow' ) ) {
			if ( ( (int) ConsentMagic()->getOption( 'cs_geolocation' ) === 0 || (int) ConsentMagic()->getOption( 'cs_geo_activated' ) === 0 ) ) {
				if ( get_current_screen()->parent_base == 'consent-magic' ) {

					echo '<div class="notice notice-warning"><p>' . esc_html__( 'Consent Magic - Geolocation not configured. Please visit the ', 'consent-magic' ) . '<a href="' . admin_url( 'admin.php?page=cs-geolocation', 'consent-magic' ) . '">' . esc_html__( 'Geolocation settings page', 'consent-magic' ) . '</a>' . esc_html__( ' and configure geolocation.', 'consent-magic' ) . '</p></div>';
				} else {

					if ( !get_user_meta( get_current_user_id(), 'cs_geo_enabled', true ) ) {
						echo '<div class="notice notice-warning" style="position: relative"><p>' . esc_html__( 'Consent Magic - Geolocation not configured. Please visit the ', 'consent-magic' ) . '<a href="' . admin_url( 'admin.php?page=cs-geolocation' ) . '">' . esc_html__( 'Geolocation settings page', 'consent-magic' ) . '</a>' . esc_html__( ' and configure geolocation.', 'consent-magic' ) . '</p><a href="' . esc_attr( $url ) . 'cs_geo_disable_message"><button type="button" class="notice-dismiss"></button></a></div>';
					} else {
						if ( !get_transient( 'cs_geo_enabled' ) ) {
							echo '<div class="notice notice-warning" style="position: relative"><p>' . esc_html__( 'Consent Magic - Geolocation not configured. Please visit the ', 'consent-magic' ) . '<a href="' . admin_url( 'admin.php?page=cs-geolocation' ) . '">' . esc_html__( 'Geolocation settings page', 'consent-magic' ) . '</a>' . esc_html__( ' and configure geolocation.', 'consent-magic' ) . '</p><a href="' . esc_attr( $url ) . 'cs_geo_disable_message"><button type="button" class="notice-dismiss"></button></a></div>';
							delete_user_meta( get_current_user_id(), 'cs_geo_enabled' );
						}
					}
				}
			}
		}

		if ( get_current_screen()->parent_base == 'consent-magic' && (int) ConsentMagic()->getOption( 'cs_enable_site_cache' ) === 1 && !get_user_meta( get_current_user_id(), 'cs_cache_message', true ) ) {
			echo '<div class="notice notice-warning" style="position: relative"><p>' . esc_html__( 'Consent Magic - Usage cache: after updating the plugin settings, you need to clear the cache.', 'consent-magic' ) . '</p><a href="' . esc_attr( $url ) . 'cs_cache_disable_message"><button type="button" class="notice-dismiss"></button></a></div>';
		}
	}

	//delete notice for current user
	//delete notice for cache message
	public function cs_close_messages() {
		if ( isset( $_GET[ 'cs_geo_disable_message' ] ) ) {
			add_user_meta( get_current_user_id(), 'cs_geo_enabled', 'true', true );
			set_transient( 'cs_geo_enabled', '1', 2592000 );
		}

		if ( isset( $_GET[ 'cs_cache_disable_message' ] ) ) {
			add_user_meta( get_current_user_id(), 'cs_cache_message', 'true', true );
		}
	}


	function cs_check_geo_license() {

		// Check nonce:
		check_admin_referer( 'cs-update-' . CMPRO_SETTINGS_FIELD );

		if ( isset( $_POST[ 'key' ] ) && !empty( $_POST[ 'key' ] ) && isset( $_POST[ 'license_action' ] ) ) {

			if ( $_POST[ 'license_action' ] == 1 ) {
				$cs_geo = new CS_Geoip;
				$validate = $cs_geo->cs_validate_geo_license_key( sanitize_text_field( $_POST[ 'key' ] ) );

				if ( is_wp_error( $validate ) ) {
					ConsentMagic()->updateOptions( array( 'cs_geo_activated' => false ) );
					$message = $validate->get_error_message( 'geo_error' );
					$status = false;
				} else {
					ConsentMagic()->updateOptions( array( 'cs_geo_activated' => true ) );
					$message = esc_html__( 'License key activated.' );
					$status = true;
				}
				ConsentMagic()->updateOptions( array( 'cs_geo_licence_key' => sanitize_text_field( $_POST[ 'key' ] ) ) );

				if ( $status ) {
					db_cron_update_one_time( true );
				} else {
					db_cron_deactivate();
				}
			} else {
				ConsentMagic()->updateOptions( array( 'cs_geo_activated' => false ) );
				ConsentMagic()->updateOptions( array( 'cs_geo_licence_key' => '' ) );
				$message = esc_html__( 'License key deactivated.' );
				db_cron_deactivate();
				$status = false;
			}

			$license_action = sanitize_text_field( $_POST[ 'license_action' ] );

		} else {
			$message = esc_html__( 'An error occurred, please try again.' );
			$status = false;
			$license_action = '1';
		}

		wp_send_json_success( array(
			'status'         => $status,
			'message'        => $message,
			'license_action' => $license_action,
		) );
		wp_die();
	}

	public function loadTranslations( $all_translations = false, $load_categories = false ) {

		$translations = ConsentMagic()->loadDefaultTranslations();

		if ( !empty( $translations ) && is_array( $translations ) ) {
			if ( isset( $translations[ 'text' ] ) && is_array( $translations[ 'text' ] ) ) {
				foreach ( $translations[ 'text' ] as $key_field => $translation ) {
					$lang_list = array();
					foreach ( $translation as $key => $value ) {
						$lang_list[] = $key;

						if ( $all_translations ) {
							ConsentMagic()->updateLangOptions( array( $key_field => $value ), $key );
						} else {
							$old_lang = ConsentMagic()->getOption( $key_field . '_' . $key );
							if ( empty( $old_lang ) ) {
								ConsentMagic()->updateLangOptions( array( $key_field => $value ), $key );
							}
						}
					}
					if ( $all_translations ) {
						ConsentMagic()->updateOptions( array( $key_field . '_lang' => $lang_list ) );
					} else {
						$old_lang_list = ConsentMagic()->getOption( $key_field . '_lang' );
						if ( is_array( $old_lang_list ) ) {
							$add_langs = array_diff( $lang_list, $old_lang_list );
							ConsentMagic()->updateOptions( array(
								$key_field . '_lang' => array(
									...$old_lang_list,
									...$add_langs
								)
							) );
						} else {
							ConsentMagic()->updateOptions( array( $key_field . '_lang' => $lang_list ) );
						}
					}
				}
				ConsentMagic()->updateOptions( array( 'cs_check_translations' => CMPRO_LATEST_VERSION_NUMBER ) );
			}

			if ( $load_categories ) {
				if ( isset( $translations[ 'categories' ] ) && is_array( $translations[ 'categories' ] ) ) {
					$categories = get_default_categories();
					foreach ( $categories as $category ) {
						if ( isset( $translations[ 'categories' ][ $category ] ) && is_array( $translations[ 'categories' ][ $category ] ) ) {

							$lang_list = array();
							$category_id = get_option( $category . '_cat_id' );
							$category_id = ( $category_id !== false ) ? $category_id : update_cat_id_options( $category . '_cat_id' );

							foreach ( $translations[ 'categories' ][ $category ] as $key_lang => $translation ) {

								$lang_list[] = $key_lang;

								if ( $all_translations ) {
									update_term_meta( $category_id, 'cs_edit_cat_description_' . $key_lang, $translation );
								} else {
									$old_lang = get_term_meta( $category_id, 'cs_edit_cat_description_' . $key_lang, true );
									if ( empty( $old_lang ) ) {
										update_term_meta( $category_id, 'cs_edit_cat_description_' . $key_lang, $translation );
									}
								}
							}

							if ( $all_translations ) {
								update_term_meta( $category_id, 'cs_edit_cat_description_lang', $lang_list );
							} else {
								$old_lang_list = get_term_meta( $category_id, 'cs_edit_cat_description_lang', true );
								if ( is_array( $old_lang_list ) ) {
									$add_langs = array_diff( $lang_list, $old_lang_list );
									update_term_meta( $category_id, 'cs_edit_cat_description_lang', array(
										...$old_lang_list,
										...$add_langs
									) );
								} else {
									update_term_meta( $category_id, 'cs_edit_cat_description_lang', $lang_list );
								}
							}
						}
					}
					ConsentMagic()->updateOptions( array( 'cs_check_translations' => CMPRO_LATEST_VERSION_NUMBER ) );
				}
			}
		}
	}

	//load additional languages via ajax
	function cs_load_langs() {

		check_ajax_referer( 'cs-ajax-nonce', 'nonce_code' );

		$lang_list_out = array();

		if ( isset( $_POST[ 'current_lang' ] ) && isset( $_POST[ 'key' ] ) && isset( $_POST[ 'term' ] ) ) {

			$current_lang = sanitize_text_field( $_POST[ 'current_lang' ] );
			$key = sanitize_text_field( $_POST[ 'key' ] );

			if ( $_POST[ 'term' ] == 1 ) {
				$lang_list = get_term_meta( $key, 'cs_edit_cat_description_lang', true );
			} else {
				$lang_list = ConsentMagic()->getOption( $key . '_lang' );
			}

			if ( is_array( $lang_list ) ) {

				$key_to_del = array_search( $current_lang, $lang_list );
				if ( $key_to_del !== false ) {
					unset( $lang_list[ $key_to_del ] );
				}

				if ( !empty( $lang_list ) ) {
					foreach ( $lang_list as $lang ) {
						if ( $_POST[ 'term' ] == 1 ) {
							$lang_list_out[ $lang ] = get_term_meta( $key, 'cs_edit_cat_description_' . $lang, true );
						} else {
							$lang_list_out[ $lang ] = ConsentMagic()->getOption( $key . '_' . $lang );
						}
					}
				}
			}

			wp_send_json_success( array(
				'message'   => ( empty( $lang_list_out ) ) ? esc_html__( 'Additional languages not found', 'consent-magic' ) : null,
				'lang_list' => $lang_list_out,
			) );

		} else {
			wp_send_json_error( array(
				'lang_list' => $lang_list_out,
				'message'   => esc_html__( 'An error occurred in the request', 'consent-magic' ),
			) );

		}
		wp_die();
	}

	public function cs_migrate_to_pro() {

		$gdpr_rule = get_post_id_by_slug_from_db( 'cs_gdpr_rule' );
		if ( $gdpr_rule ) {
			$args = array(
				'ID'         => $gdpr_rule,
				'post_title' => 'GDPR Rule',
			);
			wp_update_post( $args );
			update_post_meta( $gdpr_rule, '_cs_deny_all_btn', 0 );
			update_post_meta( $gdpr_rule, '_cs_target', 'GDPR,AD,AT,BE,BG,CY,CZ,DK,EE,FI,FR,DE,GR,HU,IE,IT,LT,LU,LV,MT,NL,NO,PL,PT,RO,SE,SI,SK,ES,GB' );
			update_post_meta( $gdpr_rule, '_cs_no_ip_rule', 1 );
			update_post_meta( $gdpr_rule, '_excluded_from_consent_storing', 0 );
			update_post_meta( $gdpr_rule, '_cs_custom_text', 0 );
		}

		$ccpa_rule = get_post_id_by_slug_from_db( 'cs_ccpa_rule' );
		if ( $ccpa_rule ) {
			$args = array(
				'ID'         => $ccpa_rule,
				'post_title' => 'CCPA Rule',
			);
			wp_update_post( $args );
			update_post_meta( $ccpa_rule, '_cs_deny_all_btn', 0 );
			update_post_meta( $ccpa_rule, '_cs_target', 'CCPA' );
			update_post_meta( $ccpa_rule, '_cs_no_ip_rule', 0 );
			update_post_meta( $ccpa_rule, '_excluded_from_consent_storing', 0 );
			update_post_meta( $ccpa_rule, '_cs_custom_text', 0 );
		}

		$rest_rule = get_post_id_by_slug_from_db( 'cs_rest_of_world_rule' );
		if ( $rest_rule ) {
			$args = [
				'ID'         => $rest_rule,
				'post_title' => 'Rest of the world Rule',
			];
			wp_update_post( $args );
			update_post_meta( $rest_rule, '_cs_deny_all_btn', 0 );
			update_post_meta( $rest_rule, '_cs_target', 'NONGDPR,AF,AG,AI,AL,DZ,AM,AO,AQ,AR,AS,AU,AW,AX,AZ,BA,BB,BD,BF,BH,BI,BJ,BL,BM,BN,BO,BQ,BR,BS,BT,BV,BW,BY,BZ,CA,CC,CD,CF,CG,CI,CK,CL,CM,CN,CO,CR,CU,CV,CW,CX,HR,KH,KM,TD,KY,DJ,DM,DO,EZ,SV,SZ,EG,ER,GQ,ET,FG,FK,FO,GF,PF,TF,GA,GD,GE,GG,GH,GI,GL,GM,GN,GP,GT,GU,GW,GY,HK,VA,HM,HN,HT,ID,IL,IM,IN,IO,IQ,IR,IS,JE,JM,JO,JP,KE,KG,KI,KN,KP,KR,KW,KZ,LA,LB,LI,LR,LS,LY,MA,MC,MD,ME,MG,MH,ML,MM,MN,MO,MQ,MR,MS,MU,MV,MW,MX,MY,FM,YT,MZ,NM,NC,NE,NF,NG,NI,NO,NP,NR,NU,NZ,MK,MP,OM,PA,PE,PG,PH,PK,PN,PR,PS,PW,PY,QA,RE,RU,RW,PM,RS,SA,SB,SC,SD,SG,SH,SJ,SL,SM,SN,SO,SR,SS,ST,GS,MF,CH,LC,LK,SX,SY,VC,WS,ZA,TC,TG,TH,TJ,TK,TL,TM,TN,TO,TR,TT,TV,TW,TZ,UA,UG,AE,UM,US,UY,UZ,VE,VG,VI,VN,VU,EH,WF,YE,ZM,ZW' );
			update_post_meta( $rest_rule, '_cs_no_ip_rule', 0 );
			update_post_meta( $rest_rule, '_excluded_from_consent_storing', 0 );
			update_post_meta( $rest_rule, '_cs_custom_text', 0 );
		}

		ConsentMagic()->deleteOption( 'cs_free' );
	}

	public function add_style_option( $styles ) {
		$styles[] = 'display';
		return $styles;
	}
}
